# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupCriterionServiceBiddableAdGroupCriterion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'smartphone_final_url': 'str',
        'final_url': 'str',
        'approval_status': 'AdGroupCriterionServiceApprovalStatus',
        'bid': 'AdGroupCriterionServiceBid',
        'custom_parameters': 'AdGroupCriterionServiceCustomParameters',
        'destination_url': 'str',
        'disapproval_reason_codes': 'list[str]',
        'review_smartphone_final_url': 'str',
        'review_final_url': 'str',
        'review_custom_parameters': 'AdGroupCriterionServiceCustomParameters',
        'review_destination_url': 'str',
        'review_tracking_url': 'str',
        'tracking_url': 'str',
        'user_status': 'AdGroupCriterionServiceUserStatus'
    }

    attribute_map = {
        'smartphone_final_url': 'smartphoneFinalUrl',
        'final_url': 'finalUrl',
        'approval_status': 'approvalStatus',
        'bid': 'bid',
        'custom_parameters': 'customParameters',
        'destination_url': 'destinationUrl',
        'disapproval_reason_codes': 'disapprovalReasonCodes',
        'review_smartphone_final_url': 'reviewSmartphoneFinalUrl',
        'review_final_url': 'reviewFinalUrl',
        'review_custom_parameters': 'reviewCustomParameters',
        'review_destination_url': 'reviewDestinationUrl',
        'review_tracking_url': 'reviewTrackingUrl',
        'tracking_url': 'trackingUrl',
        'user_status': 'userStatus'
    }

    def __init__(self, smartphone_final_url=None, final_url=None, approval_status=None, bid=None, custom_parameters=None, destination_url=None, disapproval_reason_codes=None, review_smartphone_final_url=None, review_final_url=None, review_custom_parameters=None, review_destination_url=None, review_tracking_url=None, tracking_url=None, user_status=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupCriterionServiceBiddableAdGroupCriterion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._smartphone_final_url = None
        self._final_url = None
        self._approval_status = None
        self._bid = None
        self._custom_parameters = None
        self._destination_url = None
        self._disapproval_reason_codes = None
        self._review_smartphone_final_url = None
        self._review_final_url = None
        self._review_custom_parameters = None
        self._review_destination_url = None
        self._review_tracking_url = None
        self._tracking_url = None
        self._user_status = None
        self.discriminator = None

        self.smartphone_final_url = smartphone_final_url
        self.final_url = final_url
        self.approval_status = approval_status
        self.bid = bid
        self.custom_parameters = custom_parameters
        self.destination_url = destination_url
        self.disapproval_reason_codes = disapproval_reason_codes
        self.review_smartphone_final_url = review_smartphone_final_url
        self.review_final_url = review_final_url
        self.review_custom_parameters = review_custom_parameters
        self.review_destination_url = review_destination_url
        self.review_tracking_url = review_tracking_url
        self.tracking_url = tracking_url
        self.user_status = user_status

    @property
    def smartphone_final_url(self):
        """Gets the smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存の最終リンク先URL（スマートフォン）は削除されます。</div> <div lang=\"en\">Upgraded final URL (Smartphone).<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing upgraded Final URL (Smartphone) will be deleted.</div>   # noqa: E501

        :return: The smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._smartphone_final_url

    @smartphone_final_url.setter
    def smartphone_final_url(self, smartphone_final_url):
        """Sets the smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存の最終リンク先URL（スマートフォン）は削除されます。</div> <div lang=\"en\">Upgraded final URL (Smartphone).<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing upgraded Final URL (Smartphone) will be deleted.</div>   # noqa: E501

        :param smartphone_final_url: The smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._smartphone_final_url = smartphone_final_url

    @property
    def final_url(self):
        """Gets the final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">移行後の最終リンク先URLです。<br> ADDおよびSET時、このフィールドは省略可能となります。※ADD時、移行してtracking Urlを指定している場合は必須となります。<br> ※空で設定すると、既存の移行後の最終リンク先URLは削除されます。</div> <div lang=\"en\">Upgraded final URL.<br> This field is optional in ADD and SET operation. *If upgraded and tracking Url is specified, it is required in ADD operation.<br> *When this is set blank, existing upgraded Final URL will be deleted.</div>   # noqa: E501

        :return: The final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._final_url

    @final_url.setter
    def final_url(self, final_url):
        """Sets the final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">移行後の最終リンク先URLです。<br> ADDおよびSET時、このフィールドは省略可能となります。※ADD時、移行してtracking Urlを指定している場合は必須となります。<br> ※空で設定すると、既存の移行後の最終リンク先URLは削除されます。</div> <div lang=\"en\">Upgraded final URL.<br> This field is optional in ADD and SET operation. *If upgraded and tracking Url is specified, it is required in ADD operation.<br> *When this is set blank, existing upgraded Final URL will be deleted.</div>   # noqa: E501

        :param final_url: The final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._final_url = final_url

    @property
    def approval_status(self):
        """Gets the approval_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The approval_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param approval_status: The approval_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def bid(self):
        """Gets the bid of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The bid of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceBid
        """
        return self._bid

    @bid.setter
    def bid(self, bid):
        """Sets the bid of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param bid: The bid of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceBid
        """

        self._bid = bid

    @property
    def custom_parameters(self):
        """Gets the custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceCustomParameters
        """
        return self._custom_parameters

    @custom_parameters.setter
    def custom_parameters(self, custom_parameters):
        """Sets the custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param custom_parameters: The custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceCustomParameters
        """

        self._custom_parameters = custom_parameters

    @property
    def destination_url(self):
        """Gets the destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">移行前のカスタムURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存の移行前のカスタムURLは削除されます。</div> <div lang=\"en\">Custom URL of before upgrading.<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing Custom URL before upgrade will be deleted.</div>   # noqa: E501

        :return: The destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._destination_url

    @destination_url.setter
    def destination_url(self, destination_url):
        """Sets the destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">移行前のカスタムURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存の移行前のカスタムURLは削除されます。</div> <div lang=\"en\">Custom URL of before upgrading.<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing Custom URL before upgrade will be deleted.</div>   # noqa: E501

        :param destination_url: The destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._destination_url = destination_url

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">審査否認コードです。<br> (コード詳細は、DictionaryServiceのgetDisapprovalReasonのレスポンスを参照)</div> <div lang=\"en\">Code of disapproval reason.<br> (Refer to DictionaryService getDisapprovalReason response for details)</div>   # noqa: E501

        :return: The disapproval_reason_codes of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">審査否認コードです。<br> (コード詳細は、DictionaryServiceのgetDisapprovalReasonのレスポンスを参照)</div> <div lang=\"en\">Code of disapproval reason.<br> (Refer to DictionaryService getDisapprovalReason response for details)</div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    @property
    def review_smartphone_final_url(self):
        """Gets the review_smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">配信審査中の最終リンク先URL（スマートフォン）です。</div> <div lang=\"en\">Upgraded final URL (Smartphone), in review.</div>   # noqa: E501

        :return: The review_smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._review_smartphone_final_url

    @review_smartphone_final_url.setter
    def review_smartphone_final_url(self, review_smartphone_final_url):
        """Sets the review_smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">配信審査中の最終リンク先URL（スマートフォン）です。</div> <div lang=\"en\">Upgraded final URL (Smartphone), in review.</div>   # noqa: E501

        :param review_smartphone_final_url: The review_smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._review_smartphone_final_url = review_smartphone_final_url

    @property
    def review_final_url(self):
        """Gets the review_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">移行後の配信審査中の最終リンク先URLです。</div> <div lang=\"en\">Upgraded final URL, in review.</div>   # noqa: E501

        :return: The review_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._review_final_url

    @review_final_url.setter
    def review_final_url(self, review_final_url):
        """Sets the review_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">移行後の配信審査中の最終リンク先URLです。</div> <div lang=\"en\">Upgraded final URL, in review.</div>   # noqa: E501

        :param review_final_url: The review_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._review_final_url = review_final_url

    @property
    def review_custom_parameters(self):
        """Gets the review_custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The review_custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceCustomParameters
        """
        return self._review_custom_parameters

    @review_custom_parameters.setter
    def review_custom_parameters(self, review_custom_parameters):
        """Sets the review_custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param review_custom_parameters: The review_custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceCustomParameters
        """

        self._review_custom_parameters = review_custom_parameters

    @property
    def review_destination_url(self):
        """Gets the review_destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">移行前の配信審査中のカスタムURLです。</div> <div lang=\"en\">Custom URL of before upgrading, in review.</div>   # noqa: E501

        :return: The review_destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._review_destination_url

    @review_destination_url.setter
    def review_destination_url(self, review_destination_url):
        """Sets the review_destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">移行前の配信審査中のカスタムURLです。</div> <div lang=\"en\">Custom URL of before upgrading, in review.</div>   # noqa: E501

        :param review_destination_url: The review_destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._review_destination_url = review_destination_url

    @property
    def review_tracking_url(self):
        """Gets the review_tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">配信審査中のトラッキングURLです。</div> <div lang=\"en\">Tracking URL, in review.</div>   # noqa: E501

        :return: The review_tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._review_tracking_url

    @review_tracking_url.setter
    def review_tracking_url(self, review_tracking_url):
        """Sets the review_tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">配信審査中のトラッキングURLです。</div> <div lang=\"en\">Tracking URL, in review.</div>   # noqa: E501

        :param review_tracking_url: The review_tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._review_tracking_url = review_tracking_url

    @property
    def tracking_url(self):
        """Gets the tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">トラッキングURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存のトラッキングURLは削除されます。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing Tracking URL will be deleted.</div>   # noqa: E501

        :return: The tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._tracking_url

    @tracking_url.setter
    def tracking_url(self, tracking_url):
        """Sets the tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">トラッキングURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存のトラッキングURLは削除されます。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing Tracking URL will be deleted.</div>   # noqa: E501

        :param tracking_url: The tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._tracking_url = tracking_url

    @property
    def user_status(self):
        """Gets the user_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The user_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceUserStatus
        """
        return self._user_status

    @user_status.setter
    def user_status(self, user_status):
        """Sets the user_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param user_status: The user_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceUserStatus
        """

        self._user_status = user_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupCriterionServiceBiddableAdGroupCriterion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupCriterionServiceBiddableAdGroupCriterion):
            return True

        return self.to_dict() != other.to_dict()
