# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignTargetServiceLocationTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'city_name_en': 'str',
        'city_name_ja': 'str',
        'excluded_type': 'CampaignTargetServiceExcludedType',
        'province_name_en': 'str',
        'province_name_ja': 'str',
        'targeting_status': 'CampaignTargetServiceTargetingStatus'
    }

    attribute_map = {
        'city_name_en': 'cityNameEN',
        'city_name_ja': 'cityNameJA',
        'excluded_type': 'excludedType',
        'province_name_en': 'provinceNameEN',
        'province_name_ja': 'provinceNameJA',
        'targeting_status': 'targetingStatus'
    }

    def __init__(self, city_name_en=None, city_name_ja=None, excluded_type=None, province_name_en=None, province_name_ja=None, targeting_status=None, local_vars_configuration=None):  # noqa: E501
        """CampaignTargetServiceLocationTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._city_name_en = None
        self._city_name_ja = None
        self._excluded_type = None
        self._province_name_en = None
        self._province_name_ja = None
        self._targeting_status = None
        self.discriminator = None

        self.city_name_en = city_name_en
        self.city_name_ja = city_name_ja
        self.excluded_type = excluded_type
        self.province_name_en = province_name_en
        self.province_name_ja = province_name_ja
        self.targeting_status = targeting_status

    @property
    def city_name_en(self):
        """Gets the city_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501

        <div lang=\"ja\">市区町村名（英語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">City(English).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The city_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: str
        """
        return self._city_name_en

    @city_name_en.setter
    def city_name_en(self, city_name_en):
        """Sets the city_name_en of this CampaignTargetServiceLocationTarget.

        <div lang=\"ja\">市区町村名（英語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">City(English).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param city_name_en: The city_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: str
        """

        self._city_name_en = city_name_en

    @property
    def city_name_ja(self):
        """Gets the city_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501

        <div lang=\"ja\">市区町村名（日本語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">City(Japanese).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The city_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: str
        """
        return self._city_name_ja

    @city_name_ja.setter
    def city_name_ja(self, city_name_ja):
        """Sets the city_name_ja of this CampaignTargetServiceLocationTarget.

        <div lang=\"ja\">市区町村名（日本語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">City(Japanese).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param city_name_ja: The city_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: str
        """

        self._city_name_ja = city_name_ja

    @property
    def excluded_type(self):
        """Gets the excluded_type of this CampaignTargetServiceLocationTarget.  # noqa: E501


        :return: The excluded_type of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: CampaignTargetServiceExcludedType
        """
        return self._excluded_type

    @excluded_type.setter
    def excluded_type(self, excluded_type):
        """Sets the excluded_type of this CampaignTargetServiceLocationTarget.


        :param excluded_type: The excluded_type of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: CampaignTargetServiceExcludedType
        """

        self._excluded_type = excluded_type

    @property
    def province_name_en(self):
        """Gets the province_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501

        <div lang=\"ja\">都道府県名（英語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Prefecture(English).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The province_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: str
        """
        return self._province_name_en

    @province_name_en.setter
    def province_name_en(self, province_name_en):
        """Sets the province_name_en of this CampaignTargetServiceLocationTarget.

        <div lang=\"ja\">都道府県名（英語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Prefecture(English).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param province_name_en: The province_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: str
        """

        self._province_name_en = province_name_en

    @property
    def province_name_ja(self):
        """Gets the province_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501

        <div lang=\"ja\">都道府県名（日本語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Prefecture(Japanese).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The province_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: str
        """
        return self._province_name_ja

    @province_name_ja.setter
    def province_name_ja(self, province_name_ja):
        """Sets the province_name_ja of this CampaignTargetServiceLocationTarget.

        <div lang=\"ja\">都道府県名（日本語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Prefecture(Japanese).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param province_name_ja: The province_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: str
        """

        self._province_name_ja = province_name_ja

    @property
    def targeting_status(self):
        """Gets the targeting_status of this CampaignTargetServiceLocationTarget.  # noqa: E501


        :return: The targeting_status of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: CampaignTargetServiceTargetingStatus
        """
        return self._targeting_status

    @targeting_status.setter
    def targeting_status(self, targeting_status):
        """Sets the targeting_status of this CampaignTargetServiceLocationTarget.


        :param targeting_status: The targeting_status of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: CampaignTargetServiceTargetingStatus
        """

        self._targeting_status = targeting_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignTargetServiceLocationTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignTargetServiceLocationTarget):
            return True

        return self.to_dict() != other.to_dict()
