# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupAdServiceResponsiveSearchAd(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'headlines': 'list[AdGroupAdServiceHeadlineTextAsset]',
        'descriptions': 'list[AdGroupAdServiceDescriptionTextAsset]',
        'path1': 'str',
        'is_remove_path1': 'AdGroupAdServiceIsRemove',
        'path2': 'str',
        'is_remove_path2': 'AdGroupAdServiceIsRemove',
        'review_headlines': 'list[AdGroupAdServiceHeadlineTextAsset]',
        'review_descriptions': 'list[AdGroupAdServiceDescriptionTextAsset]',
        'review_path1': 'str',
        'review_path2': 'str'
    }

    attribute_map = {
        'headlines': 'headlines',
        'descriptions': 'descriptions',
        'path1': 'path1',
        'is_remove_path1': 'isRemovePath1',
        'path2': 'path2',
        'is_remove_path2': 'isRemovePath2',
        'review_headlines': 'reviewHeadlines',
        'review_descriptions': 'reviewDescriptions',
        'review_path1': 'reviewPath1',
        'review_path2': 'reviewPath2'
    }

    def __init__(self, headlines=None, descriptions=None, path1=None, is_remove_path1=None, path2=None, is_remove_path2=None, review_headlines=None, review_descriptions=None, review_path1=None, review_path2=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceResponsiveSearchAd - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._headlines = None
        self._descriptions = None
        self._path1 = None
        self._is_remove_path1 = None
        self._path2 = None
        self._is_remove_path2 = None
        self._review_headlines = None
        self._review_descriptions = None
        self._review_path1 = None
        self._review_path2 = None
        self.discriminator = None

        self.headlines = headlines
        self.descriptions = descriptions
        self.path1 = path1
        self.is_remove_path1 = is_remove_path1
        self.path2 = path2
        self.is_remove_path2 = is_remove_path2
        self.review_headlines = review_headlines
        self.review_descriptions = review_descriptions
        self.review_path1 = review_path1
        self.review_path2 = review_path2

    @property
    def headlines(self):
        """Gets the headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">レスポンシブ検索広告で指定するタイトルのテキストアセットを表します。<br> headlines[]には、3~15件の指定が可能です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Text asset for the headline that specify in responsive ads for search.<br> 3 to 15 items can be specified for headlines[].<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :return: The headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceHeadlineTextAsset]
        """
        return self._headlines

    @headlines.setter
    def headlines(self, headlines):
        """Sets the headlines of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">レスポンシブ検索広告で指定するタイトルのテキストアセットを表します。<br> headlines[]には、3~15件の指定が可能です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Text asset for the headline that specify in responsive ads for search.<br> 3 to 15 items can be specified for headlines[].<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :param headlines: The headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: list[AdGroupAdServiceHeadlineTextAsset]
        """

        self._headlines = headlines

    @property
    def descriptions(self):
        """Gets the descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">レスポンシブ検索広告で指定する説明文のテキストアセットを表します。<br> descriptions[]には、2~4件の指定が可能です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Text asset for the description that specify in responsive ads for search.<br> 2 to 4 items can be specified for descriptions[].<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :return: The descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceDescriptionTextAsset]
        """
        return self._descriptions

    @descriptions.setter
    def descriptions(self, descriptions):
        """Sets the descriptions of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">レスポンシブ検索広告で指定する説明文のテキストアセットを表します。<br> descriptions[]には、2~4件の指定が可能です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Text asset for the description that specify in responsive ads for search.<br> 2 to 4 items can be specified for descriptions[].<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :param descriptions: The descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: list[AdGroupAdServiceDescriptionTextAsset]
        """

        self._descriptions = descriptions

    @property
    def path1(self):
        """Gets the path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADDおよびSET時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path2を指定する場合は、path1は必須です。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD and SET operation. The default value will be null.<br>*To specify path2, path1 is required.</div>   # noqa: E501

        :return: The path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: str
        """
        return self._path1

    @path1.setter
    def path1(self, path1):
        """Sets the path1 of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADDおよびSET時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path2を指定する場合は、path1は必須です。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD and SET operation. The default value will be null.<br>*To specify path2, path1 is required.</div>   # noqa: E501

        :param path1: The path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: str
        """

        self._path1 = path1

    @property
    def is_remove_path1(self):
        """Gets the is_remove_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501


        :return: The is_remove_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemove
        """
        return self._is_remove_path1

    @is_remove_path1.setter
    def is_remove_path1(self, is_remove_path1):
        """Sets the is_remove_path1 of this AdGroupAdServiceResponsiveSearchAd.


        :param is_remove_path1: The is_remove_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemove
        """

        self._is_remove_path1 = is_remove_path1

    @property
    def path2(self):
        """Gets the path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADDおよびSET時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path1を指定していない場合、path2は無視されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD and SET operation. The default value will be null.<br>*If path1 is not specified, path2 will be ignored.</div>   # noqa: E501

        :return: The path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: str
        """
        return self._path2

    @path2.setter
    def path2(self, path2):
        """Sets the path2 of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADDおよびSET時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path1を指定していない場合、path2は無視されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD and SET operation. The default value will be null.<br>*If path1 is not specified, path2 will be ignored.</div>   # noqa: E501

        :param path2: The path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: str
        """

        self._path2 = path2

    @property
    def is_remove_path2(self):
        """Gets the is_remove_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501


        :return: The is_remove_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemove
        """
        return self._is_remove_path2

    @is_remove_path2.setter
    def is_remove_path2(self, is_remove_path2):
        """Sets the is_remove_path2 of this AdGroupAdServiceResponsiveSearchAd.


        :param is_remove_path2: The is_remove_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemove
        """

        self._is_remove_path2 = is_remove_path2

    @property
    def review_headlines(self):
        """Gets the review_headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">審査中のタイトルのテキストアセットを表します。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Text asset for the headline under review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceHeadlineTextAsset]
        """
        return self._review_headlines

    @review_headlines.setter
    def review_headlines(self, review_headlines):
        """Sets the review_headlines of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">審査中のタイトルのテキストアセットを表します。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Text asset for the headline under review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_headlines: The review_headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: list[AdGroupAdServiceHeadlineTextAsset]
        """

        self._review_headlines = review_headlines

    @property
    def review_descriptions(self):
        """Gets the review_descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">審査中の説明文のテキストアセットを表します。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Text asset for the description under review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceDescriptionTextAsset]
        """
        return self._review_descriptions

    @review_descriptions.setter
    def review_descriptions(self, review_descriptions):
        """Sets the review_descriptions of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">審査中の説明文のテキストアセットを表します。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Text asset for the description under review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_descriptions: The review_descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: list[AdGroupAdServiceDescriptionTextAsset]
        """

        self._review_descriptions = review_descriptions

    @property
    def review_path1(self):
        """Gets the review_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">審査中の自動作成される表示URLを補足するパスです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically (Under review).<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: str
        """
        return self._review_path1

    @review_path1.setter
    def review_path1(self, review_path1):
        """Sets the review_path1 of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">審査中の自動作成される表示URLを補足するパスです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically (Under review).<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_path1: The review_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: str
        """

        self._review_path1 = review_path1

    @property
    def review_path2(self):
        """Gets the review_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">審査中の自動作成される表示URLを補足するパスです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically (Under review).<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: str
        """
        return self._review_path2

    @review_path2.setter
    def review_path2(self, review_path2):
        """Sets the review_path2 of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">審査中の自動作成される表示URLを補足するパスです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically (Under review).<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_path2: The review_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: str
        """

        self._review_path2 = review_path2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceResponsiveSearchAd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceResponsiveSearchAd):
            return True

        return self.to_dict() != other.to_dict()
