# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class PageFeedAssetServiceReviewSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'approved_count': 'int',
        'approved_with_review_count': 'int',
        'entity_count': 'int',
        'page_feed_asset_set_id': 'int',
        'post_disapproved_count': 'int',
        'pre_disapproved_count': 'int',
        'review_count': 'int'
    }

    attribute_map = {
        'account_id': 'accountId',
        'approved_count': 'approvedCount',
        'approved_with_review_count': 'approvedWithReviewCount',
        'entity_count': 'entityCount',
        'page_feed_asset_set_id': 'pageFeedAssetSetId',
        'post_disapproved_count': 'postDisapprovedCount',
        'pre_disapproved_count': 'preDisapprovedCount',
        'review_count': 'reviewCount'
    }

    def __init__(self, account_id=None, approved_count=None, approved_with_review_count=None, entity_count=None, page_feed_asset_set_id=None, post_disapproved_count=None, pre_disapproved_count=None, review_count=None, local_vars_configuration=None):  # noqa: E501
        """PageFeedAssetServiceReviewSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._approved_count = None
        self._approved_with_review_count = None
        self._entity_count = None
        self._page_feed_asset_set_id = None
        self._post_disapproved_count = None
        self._pre_disapproved_count = None
        self._review_count = None
        self.discriminator = None

        self.account_id = account_id
        self.approved_count = approved_count
        self.approved_with_review_count = approved_with_review_count
        self.entity_count = entity_count
        self.page_feed_asset_set_id = page_feed_asset_set_id
        self.post_disapproved_count = post_disapproved_count
        self.pre_disapproved_count = pre_disapproved_count
        self.review_count = review_count

    @property
    def account_id(self):
        """Gets the account_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def approved_count(self):
        """Gets the approved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">承認済みの件数</div> <div lang=\"en\">Count of approved.</div>   # noqa: E501

        :return: The approved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._approved_count

    @approved_count.setter
    def approved_count(self, approved_count):
        """Sets the approved_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">承認済みの件数</div> <div lang=\"en\">Count of approved.</div>   # noqa: E501

        :param approved_count: The approved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._approved_count = approved_count

    @property
    def approved_with_review_count(self):
        """Gets the approved_with_review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">編集内容審査中の件数</div> <div lang=\"en\">Count of approved with review.</div>   # noqa: E501

        :return: The approved_with_review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._approved_with_review_count

    @approved_with_review_count.setter
    def approved_with_review_count(self, approved_with_review_count):
        """Sets the approved_with_review_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">編集内容審査中の件数</div> <div lang=\"en\">Count of approved with review.</div>   # noqa: E501

        :param approved_with_review_count: The approved_with_review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._approved_with_review_count = approved_with_review_count

    @property
    def entity_count(self):
        """Gets the entity_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットセット内にあるページフィードアセットの総件数</div> <div lang=\"en\">Total count of page feed asset in page feed asset set.</div>   # noqa: E501

        :return: The entity_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._entity_count

    @entity_count.setter
    def entity_count(self, entity_count):
        """Sets the entity_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">ページフィードアセットセット内にあるページフィードアセットの総件数</div> <div lang=\"en\">Total count of page feed asset in page feed asset set.</div>   # noqa: E501

        :param entity_count: The entity_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._entity_count = entity_count

    @property
    def page_feed_asset_set_id(self):
        """Gets the page_feed_asset_set_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットセットID</div> <div lang=\"en\">PageFeedAssetSet ID.</div>   # noqa: E501

        :return: The page_feed_asset_set_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._page_feed_asset_set_id

    @page_feed_asset_set_id.setter
    def page_feed_asset_set_id(self, page_feed_asset_set_id):
        """Sets the page_feed_asset_set_id of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">ページフィードアセットセットID</div> <div lang=\"en\">PageFeedAssetSet ID.</div>   # noqa: E501

        :param page_feed_asset_set_id: The page_feed_asset_set_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._page_feed_asset_set_id = page_feed_asset_set_id

    @property
    def post_disapproved_count(self):
        """Gets the post_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">配信停止の件数</div> <div lang=\"en\">Count of distribution cancelled.</div>   # noqa: E501

        :return: The post_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._post_disapproved_count

    @post_disapproved_count.setter
    def post_disapproved_count(self, post_disapproved_count):
        """Sets the post_disapproved_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">配信停止の件数</div> <div lang=\"en\">Count of distribution cancelled.</div>   # noqa: E501

        :param post_disapproved_count: The post_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._post_disapproved_count = post_disapproved_count

    @property
    def pre_disapproved_count(self):
        """Gets the pre_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">掲載不可の件数</div> <div lang=\"en\">Count of disapproved.</div>   # noqa: E501

        :return: The pre_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._pre_disapproved_count

    @pre_disapproved_count.setter
    def pre_disapproved_count(self, pre_disapproved_count):
        """Sets the pre_disapproved_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">掲載不可の件数</div> <div lang=\"en\">Count of disapproved.</div>   # noqa: E501

        :param pre_disapproved_count: The pre_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._pre_disapproved_count = pre_disapproved_count

    @property
    def review_count(self):
        """Gets the review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">審査中の件数</div> <div lang=\"en\">Count of review.</div>   # noqa: E501

        :return: The review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._review_count

    @review_count.setter
    def review_count(self, review_count):
        """Sets the review_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">審査中の件数</div> <div lang=\"en\">Count of review.</div>   # noqa: E501

        :param review_count: The review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._review_count = review_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageFeedAssetServiceReviewSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PageFeedAssetServiceReviewSummary):
            return True

        return self.to_dict() != other.to_dict()
