# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupAdServiceExtendedTextAd(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'headline': 'str',
        'headline2': 'str',
        'headline3': 'str',
        'description': 'str',
        'description2': 'str',
        'path1': 'str',
        'path2': 'str'
    }

    attribute_map = {
        'headline': 'headline',
        'headline2': 'headline2',
        'headline3': 'headline3',
        'description': 'description',
        'description2': 'description2',
        'path1': 'path1',
        'path2': 'path2'
    }

    def __init__(self, headline=None, headline2=None, headline3=None, description=None, description2=None, path1=None, path2=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceExtendedTextAd - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._headline = None
        self._headline2 = None
        self._headline3 = None
        self._description = None
        self._description2 = None
        self._path1 = None
        self._path2 = None
        self.discriminator = None

        self.headline = headline
        self.headline2 = headline2
        self.headline3 = headline3
        self.description = description
        self.description2 = description2
        self.path1 = path1
        self.path2 = path2

    @property
    def headline(self):
        """Gets the headline of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">タイトル文です。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Title of ad.<br> This field is required in ADD operation. *If adType is DYNAMIC_SEARCH_LINKED_AD or RESPONSIVE_SEARCH_AD, this field will be ignored.</div>   # noqa: E501

        :return: The headline of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._headline

    @headline.setter
    def headline(self, headline):
        """Sets the headline of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">タイトル文です。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Title of ad.<br> This field is required in ADD operation. *If adType is DYNAMIC_SEARCH_LINKED_AD or RESPONSIVE_SEARCH_AD, this field will be ignored.</div>   # noqa: E501

        :param headline: The headline of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._headline = headline

    @property
    def headline2(self):
        """Gets the headline2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">2行目のタイトルです。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Title on the second line.<br> This field is required in ADD operation.</div>   # noqa: E501

        :return: The headline2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._headline2

    @headline2.setter
    def headline2(self, headline2):
        """Sets the headline2 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">2行目のタイトルです。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Title on the second line.<br> This field is required in ADD operation.</div>   # noqa: E501

        :param headline2: The headline2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._headline2 = headline2

    @property
    def headline3(self):
        """Gets the headline3 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">3行目のタイトルです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。</div> <div lang=\"en\">Title on the second line.<br> This field is optional in ADD operation. The default value will be null.</div>   # noqa: E501

        :return: The headline3 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._headline3

    @headline3.setter
    def headline3(self, headline3):
        """Sets the headline3 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">3行目のタイトルです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。</div> <div lang=\"en\">Title on the second line.<br> This field is optional in ADD operation. The default value will be null.</div>   # noqa: E501

        :param headline3: The headline3 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._headline3 = headline3

    @property
    def description(self):
        """Gets the description of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">説明文です。<br> ADD時、このフィールドは必須となります。<br>自動挿入をサポートしていません。</div> <div lang=\"en\">Description of ad.<br> This field is required in ADD operation. *If adType is RESPONSIVE_SEARCH_AD, this field will be ignored.<br>Does not support Data Auto Insertion.</div>   # noqa: E501

        :return: The description of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">説明文です。<br> ADD時、このフィールドは必須となります。<br>自動挿入をサポートしていません。</div> <div lang=\"en\">Description of ad.<br> This field is required in ADD operation. *If adType is RESPONSIVE_SEARCH_AD, this field will be ignored.<br>Does not support Data Auto Insertion.</div>   # noqa: E501

        :param description: The description of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def description2(self):
        """Gets the description2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">2行目の説明文です。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。</div> <div lang=\"en\">Description on the second line.<br> This field is optional in ADD operation. The default value will be null.</div>   # noqa: E501

        :return: The description2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._description2

    @description2.setter
    def description2(self, description2):
        """Sets the description2 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">2行目の説明文です。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。</div> <div lang=\"en\">Description on the second line.<br> This field is optional in ADD operation. The default value will be null.</div>   # noqa: E501

        :param description2: The description2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._description2 = description2

    @property
    def path1(self):
        """Gets the path1 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path2を指定する場合は、path1は必須です。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD operation. The default value will be null.<br>*To specify path2, path1 is required.</div>   # noqa: E501

        :return: The path1 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._path1

    @path1.setter
    def path1(self, path1):
        """Sets the path1 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path2を指定する場合は、path1は必須です。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD operation. The default value will be null.<br>*To specify path2, path1 is required.</div>   # noqa: E501

        :param path1: The path1 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._path1 = path1

    @property
    def path2(self):
        """Gets the path2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path1を指定していない場合、path2は無視されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD operation. The default value will be null.<br>*If path1 is not specified, path2 will be ignored.</div>   # noqa: E501

        :return: The path2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._path2

    @path2.setter
    def path2(self, path2):
        """Sets the path2 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path1を指定していない場合、path2は無視されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD operation. The default value will be null.<br>*If path1 is not specified, path2 will be ignored.</div>   # noqa: E501

        :param path2: The path2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._path2 = path2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceExtendedTextAd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceExtendedTextAd):
            return True

        return self.to_dict() != other.to_dict()
