# coding: utf-8

# flake8: noqa

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from yahoo_search_api_v12.api.account_customizer_service_api import AccountCustomizerServiceApi
from yahoo_search_api_v12.api.account_link_service_api import AccountLinkServiceApi
from yahoo_search_api_v12.api.account_management_service_api import AccountManagementServiceApi
from yahoo_search_api_v12.api.account_service_api import AccountServiceApi
from yahoo_search_api_v12.api.account_shared_service_api import AccountSharedServiceApi
from yahoo_search_api_v12.api.account_tracking_url_service_api import AccountTrackingUrlServiceApi
from yahoo_search_api_v12.api.ad_group_ad_label_service_api import AdGroupAdLabelServiceApi
from yahoo_search_api_v12.api.ad_group_ad_service_api import AdGroupAdServiceApi
from yahoo_search_api_v12.api.ad_group_asset_service_api import AdGroupAssetServiceApi
from yahoo_search_api_v12.api.ad_group_bid_multiplier_service_api import AdGroupBidMultiplierServiceApi
from yahoo_search_api_v12.api.ad_group_criterion_customizer_service_api import AdGroupCriterionCustomizerServiceApi
from yahoo_search_api_v12.api.ad_group_criterion_label_service_api import AdGroupCriterionLabelServiceApi
from yahoo_search_api_v12.api.ad_group_criterion_service_api import AdGroupCriterionServiceApi
from yahoo_search_api_v12.api.ad_group_customizer_service_api import AdGroupCustomizerServiceApi
from yahoo_search_api_v12.api.ad_group_label_service_api import AdGroupLabelServiceApi
from yahoo_search_api_v12.api.ad_group_retargeting_list_service_api import AdGroupRetargetingListServiceApi
from yahoo_search_api_v12.api.ad_group_service_api import AdGroupServiceApi
from yahoo_search_api_v12.api.ad_group_webpage_service_api import AdGroupWebpageServiceApi
from yahoo_search_api_v12.api.app_link_service_api import AppLinkServiceApi
from yahoo_search_api_v12.api.asset_service_api import AssetServiceApi
from yahoo_search_api_v12.api.audit_log_service_api import AuditLogServiceApi
from yahoo_search_api_v12.api.balance_service_api import BalanceServiceApi
from yahoo_search_api_v12.api.base_account_service_api import BaseAccountServiceApi
from yahoo_search_api_v12.api.bidding_seasonality_adjustment_service_api import BiddingSeasonalityAdjustmentServiceApi
from yahoo_search_api_v12.api.bidding_strategy_service_api import BiddingStrategyServiceApi
from yahoo_search_api_v12.api.budget_order_service_api import BudgetOrderServiceApi
from yahoo_search_api_v12.api.campaign_asset_service_api import CampaignAssetServiceApi
from yahoo_search_api_v12.api.campaign_budget_service_api import CampaignBudgetServiceApi
from yahoo_search_api_v12.api.campaign_criterion_service_api import CampaignCriterionServiceApi
from yahoo_search_api_v12.api.campaign_customizer_service_api import CampaignCustomizerServiceApi
from yahoo_search_api_v12.api.campaign_export_service_api import CampaignExportServiceApi
from yahoo_search_api_v12.api.campaign_label_service_api import CampaignLabelServiceApi
from yahoo_search_api_v12.api.campaign_retargeting_list_service_api import CampaignRetargetingListServiceApi
from yahoo_search_api_v12.api.campaign_service_api import CampaignServiceApi
from yahoo_search_api_v12.api.campaign_shared_set_service_api import CampaignSharedSetServiceApi
from yahoo_search_api_v12.api.campaign_target_service_api import CampaignTargetServiceApi
from yahoo_search_api_v12.api.campaign_webpage_service_api import CampaignWebpageServiceApi
from yahoo_search_api_v12.api.conversion_tracker_service_api import ConversionTrackerServiceApi
from yahoo_search_api_v12.api.customizer_attribute_service_api import CustomizerAttributeServiceApi
from yahoo_search_api_v12.api.dictionary_service_api import DictionaryServiceApi
from yahoo_search_api_v12.api.feed_item_service_api import FeedItemServiceApi
from yahoo_search_api_v12.api.feed_service_api import FeedServiceApi
from yahoo_search_api_v12.api.keyword_forecast_metrics_service_api import KeywordForecastMetricsServiceApi
from yahoo_search_api_v12.api.keyword_plan_idea_service_api import KeywordPlanIdeaServiceApi
from yahoo_search_api_v12.api.label_service_api import LabelServiceApi
from yahoo_search_api_v12.api.offline_conversion_service_api import OfflineConversionServiceApi
from yahoo_search_api_v12.api.page_feed_asset_service_api import PageFeedAssetServiceApi
from yahoo_search_api_v12.api.page_feed_asset_set_service_api import PageFeedAssetSetServiceApi
from yahoo_search_api_v12.api.report_definition_service_api import ReportDefinitionServiceApi
from yahoo_search_api_v12.api.retargeting_list_service_api import RetargetingListServiceApi
from yahoo_search_api_v12.api.shared_criterion_service_api import SharedCriterionServiceApi

# import ApiClient
from yahoo_search_api_v12.api_client import ApiClient
from yahoo_search_api_v12.configuration import Configuration
from yahoo_search_api_v12.exceptions import OpenApiException
from yahoo_search_api_v12.exceptions import ApiTypeError
from yahoo_search_api_v12.exceptions import ApiValueError
from yahoo_search_api_v12.exceptions import ApiKeyError
from yahoo_search_api_v12.exceptions import ApiException
# import models into sdk package
from yahoo_search_api_v12.models.account import Account
from yahoo_search_api_v12.models.account_customizer import AccountCustomizer
from yahoo_search_api_v12.models.account_customizer_service_approval_status import AccountCustomizerServiceApprovalStatus
from yahoo_search_api_v12.models.account_customizer_service_get_response import AccountCustomizerServiceGetResponse
from yahoo_search_api_v12.models.account_customizer_service_mutate_response import AccountCustomizerServiceMutateResponse
from yahoo_search_api_v12.models.account_customizer_service_operation import AccountCustomizerServiceOperation
from yahoo_search_api_v12.models.account_customizer_service_page import AccountCustomizerServicePage
from yahoo_search_api_v12.models.account_customizer_service_return_value import AccountCustomizerServiceReturnValue
from yahoo_search_api_v12.models.account_customizer_service_selector import AccountCustomizerServiceSelector
from yahoo_search_api_v12.models.account_customizer_service_type import AccountCustomizerServiceType
from yahoo_search_api_v12.models.account_customizer_service_value import AccountCustomizerServiceValue
from yahoo_search_api_v12.models.account_link import AccountLink
from yahoo_search_api_v12.models.account_link_service_account_status import AccountLinkServiceAccountStatus
from yahoo_search_api_v12.models.account_link_service_get_response import AccountLinkServiceGetResponse
from yahoo_search_api_v12.models.account_link_service_owner_ship_type import AccountLinkServiceOwnerShipType
from yahoo_search_api_v12.models.account_link_service_page import AccountLinkServicePage
from yahoo_search_api_v12.models.account_link_service_selector import AccountLinkServiceSelector
from yahoo_search_api_v12.models.account_link_service_value import AccountLinkServiceValue
from yahoo_search_api_v12.models.account_management import AccountManagement
from yahoo_search_api_v12.models.account_management_service_auto_tagging_enabled import AccountManagementServiceAutoTaggingEnabled
from yahoo_search_api_v12.models.account_management_service_client import AccountManagementServiceClient
from yahoo_search_api_v12.models.account_management_service_client_type import AccountManagementServiceClientType
from yahoo_search_api_v12.models.account_management_service_delivery_status import AccountManagementServiceDeliveryStatus
from yahoo_search_api_v12.models.account_management_service_enterprise_type import AccountManagementServiceEnterpriseType
from yahoo_search_api_v12.models.account_management_service_enterprise_type_position import AccountManagementServiceEnterpriseTypePosition
from yahoo_search_api_v12.models.account_management_service_get_response import AccountManagementServiceGetResponse
from yahoo_search_api_v12.models.account_management_service_include_test_account import AccountManagementServiceIncludeTestAccount
from yahoo_search_api_v12.models.account_management_service_invoice import AccountManagementServiceInvoice
from yahoo_search_api_v12.models.account_management_service_is_adult_account import AccountManagementServiceIsAdultAccount
from yahoo_search_api_v12.models.account_management_service_is_test_account import AccountManagementServiceIsTestAccount
from yahoo_search_api_v12.models.account_management_service_mutate_response import AccountManagementServiceMutateResponse
from yahoo_search_api_v12.models.account_management_service_operation import AccountManagementServiceOperation
from yahoo_search_api_v12.models.account_management_service_page import AccountManagementServicePage
from yahoo_search_api_v12.models.account_management_service_payment import AccountManagementServicePayment
from yahoo_search_api_v12.models.account_management_service_payment_type import AccountManagementServicePaymentType
from yahoo_search_api_v12.models.account_management_service_prefecture_code import AccountManagementServicePrefectureCode
from yahoo_search_api_v12.models.account_management_service_return_value import AccountManagementServiceReturnValue
from yahoo_search_api_v12.models.account_management_service_selector import AccountManagementServiceSelector
from yahoo_search_api_v12.models.account_management_service_status import AccountManagementServiceStatus
from yahoo_search_api_v12.models.account_management_service_url_type import AccountManagementServiceUrlType
from yahoo_search_api_v12.models.account_management_service_value import AccountManagementServiceValue
from yahoo_search_api_v12.models.account_service_auto_tagging_enabled import AccountServiceAutoTaggingEnabled
from yahoo_search_api_v12.models.account_service_delivery_status import AccountServiceDeliveryStatus
from yahoo_search_api_v12.models.account_service_get_response import AccountServiceGetResponse
from yahoo_search_api_v12.models.account_service_include_mcc_account import AccountServiceIncludeMccAccount
from yahoo_search_api_v12.models.account_service_include_test_account import AccountServiceIncludeTestAccount
from yahoo_search_api_v12.models.account_service_is_mcc_account import AccountServiceIsMccAccount
from yahoo_search_api_v12.models.account_service_is_test_account import AccountServiceIsTestAccount
from yahoo_search_api_v12.models.account_service_mutate_response import AccountServiceMutateResponse
from yahoo_search_api_v12.models.account_service_operation import AccountServiceOperation
from yahoo_search_api_v12.models.account_service_page import AccountServicePage
from yahoo_search_api_v12.models.account_service_return_value import AccountServiceReturnValue
from yahoo_search_api_v12.models.account_service_selector import AccountServiceSelector
from yahoo_search_api_v12.models.account_service_status import AccountServiceStatus
from yahoo_search_api_v12.models.account_service_type import AccountServiceType
from yahoo_search_api_v12.models.account_service_value import AccountServiceValue
from yahoo_search_api_v12.models.account_shared import AccountShared
from yahoo_search_api_v12.models.account_shared_service_get_response import AccountSharedServiceGetResponse
from yahoo_search_api_v12.models.account_shared_service_mutate_response import AccountSharedServiceMutateResponse
from yahoo_search_api_v12.models.account_shared_service_operation import AccountSharedServiceOperation
from yahoo_search_api_v12.models.account_shared_service_page import AccountSharedServicePage
from yahoo_search_api_v12.models.account_shared_service_return_value import AccountSharedServiceReturnValue
from yahoo_search_api_v12.models.account_shared_service_selector import AccountSharedServiceSelector
from yahoo_search_api_v12.models.account_shared_service_value import AccountSharedServiceValue
from yahoo_search_api_v12.models.account_tracking_url import AccountTrackingUrl
from yahoo_search_api_v12.models.account_tracking_url_service_get_response import AccountTrackingUrlServiceGetResponse
from yahoo_search_api_v12.models.account_tracking_url_service_mutate_response import AccountTrackingUrlServiceMutateResponse
from yahoo_search_api_v12.models.account_tracking_url_service_operation import AccountTrackingUrlServiceOperation
from yahoo_search_api_v12.models.account_tracking_url_service_page import AccountTrackingUrlServicePage
from yahoo_search_api_v12.models.account_tracking_url_service_return_value import AccountTrackingUrlServiceReturnValue
from yahoo_search_api_v12.models.account_tracking_url_service_selector import AccountTrackingUrlServiceSelector
from yahoo_search_api_v12.models.account_tracking_url_service_url_approval_status import AccountTrackingUrlServiceUrlApprovalStatus
from yahoo_search_api_v12.models.account_tracking_url_service_value import AccountTrackingUrlServiceValue
from yahoo_search_api_v12.models.ad_group import AdGroup
from yahoo_search_api_v12.models.ad_group_ad import AdGroupAd
from yahoo_search_api_v12.models.ad_group_ad_label import AdGroupAdLabel
from yahoo_search_api_v12.models.ad_group_ad_label_service_mutate_response import AdGroupAdLabelServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_ad_label_service_operation import AdGroupAdLabelServiceOperation
from yahoo_search_api_v12.models.ad_group_ad_label_service_return_value import AdGroupAdLabelServiceReturnValue
from yahoo_search_api_v12.models.ad_group_ad_label_service_value import AdGroupAdLabelServiceValue
from yahoo_search_api_v12.models.ad_group_ad_service_ad import AdGroupAdServiceAd
from yahoo_search_api_v12.models.ad_group_ad_service_ad_type import AdGroupAdServiceAdType
from yahoo_search_api_v12.models.ad_group_ad_service_app_ad import AdGroupAdServiceAppAd
from yahoo_search_api_v12.models.ad_group_ad_service_app_store import AdGroupAdServiceAppStore
from yahoo_search_api_v12.models.ad_group_ad_service_approval_status import AdGroupAdServiceApprovalStatus
from yahoo_search_api_v12.models.ad_group_ad_service_created_date_range import AdGroupAdServiceCreatedDateRange
from yahoo_search_api_v12.models.ad_group_ad_service_custom_parameter import AdGroupAdServiceCustomParameter
from yahoo_search_api_v12.models.ad_group_ad_service_custom_parameters import AdGroupAdServiceCustomParameters
from yahoo_search_api_v12.models.ad_group_ad_service_description_pinned_field import AdGroupAdServiceDescriptionPinnedField
from yahoo_search_api_v12.models.ad_group_ad_service_description_text_asset import AdGroupAdServiceDescriptionTextAsset
from yahoo_search_api_v12.models.ad_group_ad_service_device_preference import AdGroupAdServiceDevicePreference
from yahoo_search_api_v12.models.ad_group_ad_service_dynamic_search_linked_ad import AdGroupAdServiceDynamicSearchLinkedAd
from yahoo_search_api_v12.models.ad_group_ad_service_extended_text_ad import AdGroupAdServiceExtendedTextAd
from yahoo_search_api_v12.models.ad_group_ad_service_get_response import AdGroupAdServiceGetResponse
from yahoo_search_api_v12.models.ad_group_ad_service_headline_pinned_field import AdGroupAdServiceHeadlinePinnedField
from yahoo_search_api_v12.models.ad_group_ad_service_headline_text_asset import AdGroupAdServiceHeadlineTextAsset
from yahoo_search_api_v12.models.ad_group_ad_service_is_remove import AdGroupAdServiceIsRemove
from yahoo_search_api_v12.models.ad_group_ad_service_label import AdGroupAdServiceLabel
from yahoo_search_api_v12.models.ad_group_ad_service_mutate_response import AdGroupAdServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_ad_service_operation import AdGroupAdServiceOperation
from yahoo_search_api_v12.models.ad_group_ad_service_page import AdGroupAdServicePage
from yahoo_search_api_v12.models.ad_group_ad_service_responsive_search_ad import AdGroupAdServiceResponsiveSearchAd
from yahoo_search_api_v12.models.ad_group_ad_service_return_value import AdGroupAdServiceReturnValue
from yahoo_search_api_v12.models.ad_group_ad_service_selector import AdGroupAdServiceSelector
from yahoo_search_api_v12.models.ad_group_ad_service_set_trademark_status import AdGroupAdServiceSetTrademarkStatus
from yahoo_search_api_v12.models.ad_group_ad_service_set_trademark_status_operation import AdGroupAdServiceSetTrademarkStatusOperation
from yahoo_search_api_v12.models.ad_group_ad_service_set_trademark_status_response import AdGroupAdServiceSetTrademarkStatusResponse
from yahoo_search_api_v12.models.ad_group_ad_service_text_ad2 import AdGroupAdServiceTextAd2
from yahoo_search_api_v12.models.ad_group_ad_service_text_asset_active_status import AdGroupAdServiceTextAssetActiveStatus
from yahoo_search_api_v12.models.ad_group_ad_service_trademark_status import AdGroupAdServiceTrademarkStatus
from yahoo_search_api_v12.models.ad_group_ad_service_user_status import AdGroupAdServiceUserStatus
from yahoo_search_api_v12.models.ad_group_ad_service_value import AdGroupAdServiceValue
from yahoo_search_api_v12.models.ad_group_asset import AdGroupAsset
from yahoo_search_api_v12.models.ad_group_asset_service_get_response import AdGroupAssetServiceGetResponse
from yahoo_search_api_v12.models.ad_group_asset_service_list import AdGroupAssetServiceList
from yahoo_search_api_v12.models.ad_group_asset_service_mutate_response import AdGroupAssetServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_asset_service_operation import AdGroupAssetServiceOperation
from yahoo_search_api_v12.models.ad_group_asset_service_page import AdGroupAssetServicePage
from yahoo_search_api_v12.models.ad_group_asset_service_replace_operation import AdGroupAssetServiceReplaceOperation
from yahoo_search_api_v12.models.ad_group_asset_service_replace_response import AdGroupAssetServiceReplaceResponse
from yahoo_search_api_v12.models.ad_group_asset_service_replace_return_value import AdGroupAssetServiceReplaceReturnValue
from yahoo_search_api_v12.models.ad_group_asset_service_replace_value import AdGroupAssetServiceReplaceValue
from yahoo_search_api_v12.models.ad_group_asset_service_return_value import AdGroupAssetServiceReturnValue
from yahoo_search_api_v12.models.ad_group_asset_service_selector import AdGroupAssetServiceSelector
from yahoo_search_api_v12.models.ad_group_asset_service_type import AdGroupAssetServiceType
from yahoo_search_api_v12.models.ad_group_asset_service_user_status import AdGroupAssetServiceUserStatus
from yahoo_search_api_v12.models.ad_group_asset_service_value import AdGroupAssetServiceValue
from yahoo_search_api_v12.models.ad_group_bid_multiplier import AdGroupBidMultiplier
from yahoo_search_api_v12.models.ad_group_bid_multiplier_service_get_response import AdGroupBidMultiplierServiceGetResponse
from yahoo_search_api_v12.models.ad_group_bid_multiplier_service_mutate_response import AdGroupBidMultiplierServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_bid_multiplier_service_operation import AdGroupBidMultiplierServiceOperation
from yahoo_search_api_v12.models.ad_group_bid_multiplier_service_page import AdGroupBidMultiplierServicePage
from yahoo_search_api_v12.models.ad_group_bid_multiplier_service_platform_type import AdGroupBidMultiplierServicePlatformType
from yahoo_search_api_v12.models.ad_group_bid_multiplier_service_return_value import AdGroupBidMultiplierServiceReturnValue
from yahoo_search_api_v12.models.ad_group_bid_multiplier_service_selector import AdGroupBidMultiplierServiceSelector
from yahoo_search_api_v12.models.ad_group_bid_multiplier_service_value import AdGroupBidMultiplierServiceValue
from yahoo_search_api_v12.models.ad_group_criterion import AdGroupCriterion
from yahoo_search_api_v12.models.ad_group_criterion_customizer import AdGroupCriterionCustomizer
from yahoo_search_api_v12.models.ad_group_criterion_customizer_service_approval_status import AdGroupCriterionCustomizerServiceApprovalStatus
from yahoo_search_api_v12.models.ad_group_criterion_customizer_service_get_response import AdGroupCriterionCustomizerServiceGetResponse
from yahoo_search_api_v12.models.ad_group_criterion_customizer_service_mutate_response import AdGroupCriterionCustomizerServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_criterion_customizer_service_operation import AdGroupCriterionCustomizerServiceOperation
from yahoo_search_api_v12.models.ad_group_criterion_customizer_service_page import AdGroupCriterionCustomizerServicePage
from yahoo_search_api_v12.models.ad_group_criterion_customizer_service_return_value import AdGroupCriterionCustomizerServiceReturnValue
from yahoo_search_api_v12.models.ad_group_criterion_customizer_service_selector import AdGroupCriterionCustomizerServiceSelector
from yahoo_search_api_v12.models.ad_group_criterion_customizer_service_type import AdGroupCriterionCustomizerServiceType
from yahoo_search_api_v12.models.ad_group_criterion_customizer_service_value import AdGroupCriterionCustomizerServiceValue
from yahoo_search_api_v12.models.ad_group_criterion_label import AdGroupCriterionLabel
from yahoo_search_api_v12.models.ad_group_criterion_label_service_mutate_response import AdGroupCriterionLabelServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_criterion_label_service_operation import AdGroupCriterionLabelServiceOperation
from yahoo_search_api_v12.models.ad_group_criterion_label_service_return_value import AdGroupCriterionLabelServiceReturnValue
from yahoo_search_api_v12.models.ad_group_criterion_label_service_value import AdGroupCriterionLabelServiceValue
from yahoo_search_api_v12.models.ad_group_criterion_service_approval_status import AdGroupCriterionServiceApprovalStatus
from yahoo_search_api_v12.models.ad_group_criterion_service_bid import AdGroupCriterionServiceBid
from yahoo_search_api_v12.models.ad_group_criterion_service_bid_source import AdGroupCriterionServiceBidSource
from yahoo_search_api_v12.models.ad_group_criterion_service_biddable_ad_group_criterion import AdGroupCriterionServiceBiddableAdGroupCriterion
from yahoo_search_api_v12.models.ad_group_criterion_service_bidding_keyword_cpc_range import AdGroupCriterionServiceBiddingKeywordCpcRange
from yahoo_search_api_v12.models.ad_group_criterion_service_contains_label_id import AdGroupCriterionServiceContainsLabelId
from yahoo_search_api_v12.models.ad_group_criterion_service_criterion import AdGroupCriterionServiceCriterion
from yahoo_search_api_v12.models.ad_group_criterion_service_criterion_type import AdGroupCriterionServiceCriterionType
from yahoo_search_api_v12.models.ad_group_criterion_service_custom_parameter import AdGroupCriterionServiceCustomParameter
from yahoo_search_api_v12.models.ad_group_criterion_service_custom_parameters import AdGroupCriterionServiceCustomParameters
from yahoo_search_api_v12.models.ad_group_criterion_service_get_response import AdGroupCriterionServiceGetResponse
from yahoo_search_api_v12.models.ad_group_criterion_service_is_remove import AdGroupCriterionServiceIsRemove
from yahoo_search_api_v12.models.ad_group_criterion_service_keyword import AdGroupCriterionServiceKeyword
from yahoo_search_api_v12.models.ad_group_criterion_service_keyword_match_type import AdGroupCriterionServiceKeywordMatchType
from yahoo_search_api_v12.models.ad_group_criterion_service_label import AdGroupCriterionServiceLabel
from yahoo_search_api_v12.models.ad_group_criterion_service_mutate_response import AdGroupCriterionServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_criterion_service_operation import AdGroupCriterionServiceOperation
from yahoo_search_api_v12.models.ad_group_criterion_service_page import AdGroupCriterionServicePage
from yahoo_search_api_v12.models.ad_group_criterion_service_return_value import AdGroupCriterionServiceReturnValue
from yahoo_search_api_v12.models.ad_group_criterion_service_selector import AdGroupCriterionServiceSelector
from yahoo_search_api_v12.models.ad_group_criterion_service_trademark_status import AdGroupCriterionServiceTrademarkStatus
from yahoo_search_api_v12.models.ad_group_criterion_service_use import AdGroupCriterionServiceUse
from yahoo_search_api_v12.models.ad_group_criterion_service_user_status import AdGroupCriterionServiceUserStatus
from yahoo_search_api_v12.models.ad_group_criterion_service_value import AdGroupCriterionServiceValue
from yahoo_search_api_v12.models.ad_group_customizer import AdGroupCustomizer
from yahoo_search_api_v12.models.ad_group_customizer_service_approval_status import AdGroupCustomizerServiceApprovalStatus
from yahoo_search_api_v12.models.ad_group_customizer_service_get_response import AdGroupCustomizerServiceGetResponse
from yahoo_search_api_v12.models.ad_group_customizer_service_mutate_response import AdGroupCustomizerServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_customizer_service_operation import AdGroupCustomizerServiceOperation
from yahoo_search_api_v12.models.ad_group_customizer_service_page import AdGroupCustomizerServicePage
from yahoo_search_api_v12.models.ad_group_customizer_service_return_value import AdGroupCustomizerServiceReturnValue
from yahoo_search_api_v12.models.ad_group_customizer_service_selector import AdGroupCustomizerServiceSelector
from yahoo_search_api_v12.models.ad_group_customizer_service_type import AdGroupCustomizerServiceType
from yahoo_search_api_v12.models.ad_group_customizer_service_value import AdGroupCustomizerServiceValue
from yahoo_search_api_v12.models.ad_group_label import AdGroupLabel
from yahoo_search_api_v12.models.ad_group_label_service_mutate_response import AdGroupLabelServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_label_service_operation import AdGroupLabelServiceOperation
from yahoo_search_api_v12.models.ad_group_label_service_return_value import AdGroupLabelServiceReturnValue
from yahoo_search_api_v12.models.ad_group_label_service_value import AdGroupLabelServiceValue
from yahoo_search_api_v12.models.ad_group_retargeting_list import AdGroupRetargetingList
from yahoo_search_api_v12.models.ad_group_retargeting_list_service_criterion_target_list import AdGroupRetargetingListServiceCriterionTargetList
from yahoo_search_api_v12.models.ad_group_retargeting_list_service_excluded_type import AdGroupRetargetingListServiceExcludedType
from yahoo_search_api_v12.models.ad_group_retargeting_list_service_get_response import AdGroupRetargetingListServiceGetResponse
from yahoo_search_api_v12.models.ad_group_retargeting_list_service_mutate_response import AdGroupRetargetingListServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_retargeting_list_service_operation import AdGroupRetargetingListServiceOperation
from yahoo_search_api_v12.models.ad_group_retargeting_list_service_page import AdGroupRetargetingListServicePage
from yahoo_search_api_v12.models.ad_group_retargeting_list_service_return_value import AdGroupRetargetingListServiceReturnValue
from yahoo_search_api_v12.models.ad_group_retargeting_list_service_selector import AdGroupRetargetingListServiceSelector
from yahoo_search_api_v12.models.ad_group_retargeting_list_service_value import AdGroupRetargetingListServiceValue
from yahoo_search_api_v12.models.ad_group_service_bidding_keyword_cpc_range import AdGroupServiceBiddingKeywordCpcRange
from yahoo_search_api_v12.models.ad_group_service_bidding_scheme import AdGroupServiceBiddingScheme
from yahoo_search_api_v12.models.ad_group_service_bidding_strategy_configuration import AdGroupServiceBiddingStrategyConfiguration
from yahoo_search_api_v12.models.ad_group_service_campaign_bidding_strategy_type import AdGroupServiceCampaignBiddingStrategyType
from yahoo_search_api_v12.models.ad_group_service_cpc_bidding_scheme import AdGroupServiceCpcBiddingScheme
from yahoo_search_api_v12.models.ad_group_service_created_date_range import AdGroupServiceCreatedDateRange
from yahoo_search_api_v12.models.ad_group_service_criterion_type import AdGroupServiceCriterionType
from yahoo_search_api_v12.models.ad_group_service_custom_parameter import AdGroupServiceCustomParameter
from yahoo_search_api_v12.models.ad_group_service_custom_parameters import AdGroupServiceCustomParameters
from yahoo_search_api_v12.models.ad_group_service_frequently_run_better_performing_ads_mode import AdGroupServiceFrequentlyRunBetterPerformingAdsMode
from yahoo_search_api_v12.models.ad_group_service_get_response import AdGroupServiceGetResponse
from yahoo_search_api_v12.models.ad_group_service_is_remove import AdGroupServiceIsRemove
from yahoo_search_api_v12.models.ad_group_service_is_remove_flg import AdGroupServiceIsRemoveFlg
from yahoo_search_api_v12.models.ad_group_service_label import AdGroupServiceLabel
from yahoo_search_api_v12.models.ad_group_service_maximize_conversion_value_bidding_scheme import AdGroupServiceMaximizeConversionValueBiddingScheme
from yahoo_search_api_v12.models.ad_group_service_maximize_conversions_bidding_scheme import AdGroupServiceMaximizeConversionsBiddingScheme
from yahoo_search_api_v12.models.ad_group_service_mutate_response import AdGroupServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_service_operation import AdGroupServiceOperation
from yahoo_search_api_v12.models.ad_group_service_page import AdGroupServicePage
from yahoo_search_api_v12.models.ad_group_service_return_value import AdGroupServiceReturnValue
from yahoo_search_api_v12.models.ad_group_service_review_url import AdGroupServiceReviewUrl
from yahoo_search_api_v12.models.ad_group_service_selector import AdGroupServiceSelector
from yahoo_search_api_v12.models.ad_group_service_settings import AdGroupServiceSettings
from yahoo_search_api_v12.models.ad_group_service_target_all import AdGroupServiceTargetAll
from yahoo_search_api_v12.models.ad_group_service_target_cpa_bidding_scheme import AdGroupServiceTargetCpaBiddingScheme
from yahoo_search_api_v12.models.ad_group_service_target_roas_bidding_scheme import AdGroupServiceTargetRoasBiddingScheme
from yahoo_search_api_v12.models.ad_group_service_targeting_setting import AdGroupServiceTargetingSetting
from yahoo_search_api_v12.models.ad_group_service_url_approval_status import AdGroupServiceUrlApprovalStatus
from yahoo_search_api_v12.models.ad_group_service_url_review_data import AdGroupServiceUrlReviewData
from yahoo_search_api_v12.models.ad_group_service_user_status import AdGroupServiceUserStatus
from yahoo_search_api_v12.models.ad_group_service_value import AdGroupServiceValue
from yahoo_search_api_v12.models.ad_group_webpage import AdGroupWebpage
from yahoo_search_api_v12.models.ad_group_webpage_service_bid import AdGroupWebpageServiceBid
from yahoo_search_api_v12.models.ad_group_webpage_service_bid_source import AdGroupWebpageServiceBidSource
from yahoo_search_api_v12.models.ad_group_webpage_service_excluded_type import AdGroupWebpageServiceExcludedType
from yahoo_search_api_v12.models.ad_group_webpage_service_get_response import AdGroupWebpageServiceGetResponse
from yahoo_search_api_v12.models.ad_group_webpage_service_mutate_response import AdGroupWebpageServiceMutateResponse
from yahoo_search_api_v12.models.ad_group_webpage_service_operation import AdGroupWebpageServiceOperation
from yahoo_search_api_v12.models.ad_group_webpage_service_operator import AdGroupWebpageServiceOperator
from yahoo_search_api_v12.models.ad_group_webpage_service_page import AdGroupWebpageServicePage
from yahoo_search_api_v12.models.ad_group_webpage_service_return_value import AdGroupWebpageServiceReturnValue
from yahoo_search_api_v12.models.ad_group_webpage_service_selector import AdGroupWebpageServiceSelector
from yahoo_search_api_v12.models.ad_group_webpage_service_user_status import AdGroupWebpageServiceUserStatus
from yahoo_search_api_v12.models.ad_group_webpage_service_value import AdGroupWebpageServiceValue
from yahoo_search_api_v12.models.ad_group_webpage_service_webpage import AdGroupWebpageServiceWebpage
from yahoo_search_api_v12.models.ad_group_webpage_service_webpage_condition import AdGroupWebpageServiceWebpageCondition
from yahoo_search_api_v12.models.ad_group_webpage_service_webpage_condition_type import AdGroupWebpageServiceWebpageConditionType
from yahoo_search_api_v12.models.ad_group_webpage_service_webpage_parameter import AdGroupWebpageServiceWebpageParameter
from yahoo_search_api_v12.models.app_link import AppLink
from yahoo_search_api_v12.models.app_link_service_app_link_platform import AppLinkServiceAppLinkPlatform
from yahoo_search_api_v12.models.app_link_service_get_response import AppLinkServiceGetResponse
from yahoo_search_api_v12.models.app_link_service_link_status import AppLinkServiceLinkStatus
from yahoo_search_api_v12.models.app_link_service_mutate_response import AppLinkServiceMutateResponse
from yahoo_search_api_v12.models.app_link_service_operation import AppLinkServiceOperation
from yahoo_search_api_v12.models.app_link_service_page import AppLinkServicePage
from yahoo_search_api_v12.models.app_link_service_return_value import AppLinkServiceReturnValue
from yahoo_search_api_v12.models.app_link_service_selector import AppLinkServiceSelector
from yahoo_search_api_v12.models.app_link_service_sync_status import AppLinkServiceSyncStatus
from yahoo_search_api_v12.models.app_link_service_value import AppLinkServiceValue
from yahoo_search_api_v12.models.asset import Asset
from yahoo_search_api_v12.models.asset_service_approval_status import AssetServiceApprovalStatus
from yahoo_search_api_v12.models.asset_service_asset_data import AssetServiceAssetData
from yahoo_search_api_v12.models.asset_service_call_asset import AssetServiceCallAsset
from yahoo_search_api_v12.models.asset_service_callout_asset import AssetServiceCalloutAsset
from yahoo_search_api_v12.models.asset_service_custom_parameter import AssetServiceCustomParameter
from yahoo_search_api_v12.models.asset_service_custom_parameters import AssetServiceCustomParameters
from yahoo_search_api_v12.models.asset_service_day_of_week import AssetServiceDayOfWeek
from yahoo_search_api_v12.models.asset_service_get_response import AssetServiceGetResponse
from yahoo_search_api_v12.models.asset_service_is_remove import AssetServiceIsRemove
from yahoo_search_api_v12.models.asset_service_minute_of_hour import AssetServiceMinuteOfHour
from yahoo_search_api_v12.models.asset_service_mutate_response import AssetServiceMutateResponse
from yahoo_search_api_v12.models.asset_service_operation import AssetServiceOperation
from yahoo_search_api_v12.models.asset_service_page import AssetServicePage
from yahoo_search_api_v12.models.asset_service_quick_link_asset import AssetServiceQuickLinkAsset
from yahoo_search_api_v12.models.asset_service_return_value import AssetServiceReturnValue
from yahoo_search_api_v12.models.asset_service_schedule import AssetServiceSchedule
from yahoo_search_api_v12.models.asset_service_selector import AssetServiceSelector
from yahoo_search_api_v12.models.asset_service_set_trademark_status import AssetServiceSetTrademarkStatus
from yahoo_search_api_v12.models.asset_service_set_trademark_status_operation import AssetServiceSetTrademarkStatusOperation
from yahoo_search_api_v12.models.asset_service_structured_snippet_asset import AssetServiceStructuredSnippetAsset
from yahoo_search_api_v12.models.asset_service_trademark_status import AssetServiceTrademarkStatus
from yahoo_search_api_v12.models.asset_service_type import AssetServiceType
from yahoo_search_api_v12.models.asset_service_value import AssetServiceValue
from yahoo_search_api_v12.models.audit_log_service_add_response import AuditLogServiceAddResponse
from yahoo_search_api_v12.models.audit_log_service_date_range import AuditLogServiceDateRange
from yahoo_search_api_v12.models.audit_log_service_download_selector import AuditLogServiceDownloadSelector
from yahoo_search_api_v12.models.audit_log_service_encoding import AuditLogServiceEncoding
from yahoo_search_api_v12.models.audit_log_service_event_selector import AuditLogServiceEventSelector
from yahoo_search_api_v12.models.audit_log_service_event_types import AuditLogServiceEventTypes
from yahoo_search_api_v12.models.audit_log_service_get_response import AuditLogServiceGetResponse
from yahoo_search_api_v12.models.audit_log_service_job import AuditLogServiceJob
from yahoo_search_api_v12.models.audit_log_service_job_status import AuditLogServiceJobStatus
from yahoo_search_api_v12.models.audit_log_service_lang import AuditLogServiceLang
from yahoo_search_api_v12.models.audit_log_service_operation import AuditLogServiceOperation
from yahoo_search_api_v12.models.audit_log_service_output import AuditLogServiceOutput
from yahoo_search_api_v12.models.audit_log_service_page import AuditLogServicePage
from yahoo_search_api_v12.models.audit_log_service_return_value import AuditLogServiceReturnValue
from yahoo_search_api_v12.models.audit_log_service_selector import AuditLogServiceSelector
from yahoo_search_api_v12.models.audit_log_service_source_type import AuditLogServiceSourceType
from yahoo_search_api_v12.models.audit_log_service_value import AuditLogServiceValue
from yahoo_search_api_v12.models.balance import Balance
from yahoo_search_api_v12.models.balance_service_get_response import BalanceServiceGetResponse
from yahoo_search_api_v12.models.balance_service_page import BalanceServicePage
from yahoo_search_api_v12.models.balance_service_selector import BalanceServiceSelector
from yahoo_search_api_v12.models.balance_service_value import BalanceServiceValue
from yahoo_search_api_v12.models.base_account import BaseAccount
from yahoo_search_api_v12.models.base_account_service_account_status import BaseAccountServiceAccountStatus
from yahoo_search_api_v12.models.base_account_service_auth_type import BaseAccountServiceAuthType
from yahoo_search_api_v12.models.base_account_service_get_response import BaseAccountServiceGetResponse
from yahoo_search_api_v12.models.base_account_service_has_admin_auth import BaseAccountServiceHasAdminAuth
from yahoo_search_api_v12.models.base_account_service_include_admin_auth import BaseAccountServiceIncludeAdminAuth
from yahoo_search_api_v12.models.base_account_service_include_mcc_account import BaseAccountServiceIncludeMccAccount
from yahoo_search_api_v12.models.base_account_service_include_test_account import BaseAccountServiceIncludeTestAccount
from yahoo_search_api_v12.models.base_account_service_is_mcc_account import BaseAccountServiceIsMccAccount
from yahoo_search_api_v12.models.base_account_service_is_root_mcc_account import BaseAccountServiceIsRootMccAccount
from yahoo_search_api_v12.models.base_account_service_is_test_account import BaseAccountServiceIsTestAccount
from yahoo_search_api_v12.models.base_account_service_page import BaseAccountServicePage
from yahoo_search_api_v12.models.base_account_service_selector import BaseAccountServiceSelector
from yahoo_search_api_v12.models.base_account_service_value import BaseAccountServiceValue
from yahoo_search_api_v12.models.bidding_seasonality_adjustment import BiddingSeasonalityAdjustment
from yahoo_search_api_v12.models.bidding_seasonality_adjustment_service_devices import BiddingSeasonalityAdjustmentServiceDevices
from yahoo_search_api_v12.models.bidding_seasonality_adjustment_service_get_response import BiddingSeasonalityAdjustmentServiceGetResponse
from yahoo_search_api_v12.models.bidding_seasonality_adjustment_service_mutate_response import BiddingSeasonalityAdjustmentServiceMutateResponse
from yahoo_search_api_v12.models.bidding_seasonality_adjustment_service_operation import BiddingSeasonalityAdjustmentServiceOperation
from yahoo_search_api_v12.models.bidding_seasonality_adjustment_service_page import BiddingSeasonalityAdjustmentServicePage
from yahoo_search_api_v12.models.bidding_seasonality_adjustment_service_return_value import BiddingSeasonalityAdjustmentServiceReturnValue
from yahoo_search_api_v12.models.bidding_seasonality_adjustment_service_selector import BiddingSeasonalityAdjustmentServiceSelector
from yahoo_search_api_v12.models.bidding_seasonality_adjustment_service_value import BiddingSeasonalityAdjustmentServiceValue
from yahoo_search_api_v12.models.bidding_strategy import BiddingStrategy
from yahoo_search_api_v12.models.bidding_strategy_service_bidding_scheme import BiddingStrategyServiceBiddingScheme
from yahoo_search_api_v12.models.bidding_strategy_service_get_response import BiddingStrategyServiceGetResponse
from yahoo_search_api_v12.models.bidding_strategy_service_maximize_clicks_bidding_scheme import BiddingStrategyServiceMaximizeClicksBiddingScheme
from yahoo_search_api_v12.models.bidding_strategy_service_mutate_response import BiddingStrategyServiceMutateResponse
from yahoo_search_api_v12.models.bidding_strategy_service_operation import BiddingStrategyServiceOperation
from yahoo_search_api_v12.models.bidding_strategy_service_page import BiddingStrategyServicePage
from yahoo_search_api_v12.models.bidding_strategy_service_return_value import BiddingStrategyServiceReturnValue
from yahoo_search_api_v12.models.bidding_strategy_service_selector import BiddingStrategyServiceSelector
from yahoo_search_api_v12.models.bidding_strategy_service_target_cpa_bidding_scheme import BiddingStrategyServiceTargetCpaBiddingScheme
from yahoo_search_api_v12.models.bidding_strategy_service_target_impression_share_location import BiddingStrategyServiceTargetImpressionShareLocation
from yahoo_search_api_v12.models.bidding_strategy_service_target_impression_share_scheme import BiddingStrategyServiceTargetImpressionShareScheme
from yahoo_search_api_v12.models.bidding_strategy_service_target_roas_bidding_scheme import BiddingStrategyServiceTargetRoasBiddingScheme
from yahoo_search_api_v12.models.bidding_strategy_service_type import BiddingStrategyServiceType
from yahoo_search_api_v12.models.bidding_strategy_service_value import BiddingStrategyServiceValue
from yahoo_search_api_v12.models.budget_order import BudgetOrder
from yahoo_search_api_v12.models.budget_order_service_account_type import BudgetOrderServiceAccountType
from yahoo_search_api_v12.models.budget_order_service_get_response import BudgetOrderServiceGetResponse
from yahoo_search_api_v12.models.budget_order_service_limit_charge_type import BudgetOrderServiceLimitChargeType
from yahoo_search_api_v12.models.budget_order_service_mutate_response import BudgetOrderServiceMutateResponse
from yahoo_search_api_v12.models.budget_order_service_operation import BudgetOrderServiceOperation
from yahoo_search_api_v12.models.budget_order_service_page import BudgetOrderServicePage
from yahoo_search_api_v12.models.budget_order_service_return_value import BudgetOrderServiceReturnValue
from yahoo_search_api_v12.models.budget_order_service_selector import BudgetOrderServiceSelector
from yahoo_search_api_v12.models.budget_order_service_value import BudgetOrderServiceValue
from yahoo_search_api_v12.models.campaign import Campaign
from yahoo_search_api_v12.models.campaign_asset import CampaignAsset
from yahoo_search_api_v12.models.campaign_asset_service_get_response import CampaignAssetServiceGetResponse
from yahoo_search_api_v12.models.campaign_asset_service_list import CampaignAssetServiceList
from yahoo_search_api_v12.models.campaign_asset_service_mutate_response import CampaignAssetServiceMutateResponse
from yahoo_search_api_v12.models.campaign_asset_service_operation import CampaignAssetServiceOperation
from yahoo_search_api_v12.models.campaign_asset_service_page import CampaignAssetServicePage
from yahoo_search_api_v12.models.campaign_asset_service_replace_operation import CampaignAssetServiceReplaceOperation
from yahoo_search_api_v12.models.campaign_asset_service_replace_response import CampaignAssetServiceReplaceResponse
from yahoo_search_api_v12.models.campaign_asset_service_replace_return_value import CampaignAssetServiceReplaceReturnValue
from yahoo_search_api_v12.models.campaign_asset_service_replace_value import CampaignAssetServiceReplaceValue
from yahoo_search_api_v12.models.campaign_asset_service_return_value import CampaignAssetServiceReturnValue
from yahoo_search_api_v12.models.campaign_asset_service_selector import CampaignAssetServiceSelector
from yahoo_search_api_v12.models.campaign_asset_service_type import CampaignAssetServiceType
from yahoo_search_api_v12.models.campaign_asset_service_user_status import CampaignAssetServiceUserStatus
from yahoo_search_api_v12.models.campaign_asset_service_value import CampaignAssetServiceValue
from yahoo_search_api_v12.models.campaign_budget import CampaignBudget
from yahoo_search_api_v12.models.campaign_budget_service_get_response import CampaignBudgetServiceGetResponse
from yahoo_search_api_v12.models.campaign_budget_service_mutate_response import CampaignBudgetServiceMutateResponse
from yahoo_search_api_v12.models.campaign_budget_service_operation import CampaignBudgetServiceOperation
from yahoo_search_api_v12.models.campaign_budget_service_page import CampaignBudgetServicePage
from yahoo_search_api_v12.models.campaign_budget_service_return_value import CampaignBudgetServiceReturnValue
from yahoo_search_api_v12.models.campaign_budget_service_selector import CampaignBudgetServiceSelector
from yahoo_search_api_v12.models.campaign_budget_service_value import CampaignBudgetServiceValue
from yahoo_search_api_v12.models.campaign_criterion import CampaignCriterion
from yahoo_search_api_v12.models.campaign_criterion_service_criterion import CampaignCriterionServiceCriterion
from yahoo_search_api_v12.models.campaign_criterion_service_criterion_type import CampaignCriterionServiceCriterionType
from yahoo_search_api_v12.models.campaign_criterion_service_get_response import CampaignCriterionServiceGetResponse
from yahoo_search_api_v12.models.campaign_criterion_service_keyword import CampaignCriterionServiceKeyword
from yahoo_search_api_v12.models.campaign_criterion_service_keyword_match_type import CampaignCriterionServiceKeywordMatchType
from yahoo_search_api_v12.models.campaign_criterion_service_mutate_response import CampaignCriterionServiceMutateResponse
from yahoo_search_api_v12.models.campaign_criterion_service_operation import CampaignCriterionServiceOperation
from yahoo_search_api_v12.models.campaign_criterion_service_page import CampaignCriterionServicePage
from yahoo_search_api_v12.models.campaign_criterion_service_return_value import CampaignCriterionServiceReturnValue
from yahoo_search_api_v12.models.campaign_criterion_service_selector import CampaignCriterionServiceSelector
from yahoo_search_api_v12.models.campaign_criterion_service_use import CampaignCriterionServiceUse
from yahoo_search_api_v12.models.campaign_criterion_service_value import CampaignCriterionServiceValue
from yahoo_search_api_v12.models.campaign_customizer import CampaignCustomizer
from yahoo_search_api_v12.models.campaign_customizer_service_approval_status import CampaignCustomizerServiceApprovalStatus
from yahoo_search_api_v12.models.campaign_customizer_service_get_response import CampaignCustomizerServiceGetResponse
from yahoo_search_api_v12.models.campaign_customizer_service_mutate_response import CampaignCustomizerServiceMutateResponse
from yahoo_search_api_v12.models.campaign_customizer_service_operation import CampaignCustomizerServiceOperation
from yahoo_search_api_v12.models.campaign_customizer_service_page import CampaignCustomizerServicePage
from yahoo_search_api_v12.models.campaign_customizer_service_return_value import CampaignCustomizerServiceReturnValue
from yahoo_search_api_v12.models.campaign_customizer_service_selector import CampaignCustomizerServiceSelector
from yahoo_search_api_v12.models.campaign_customizer_service_type import CampaignCustomizerServiceType
from yahoo_search_api_v12.models.campaign_customizer_service_value import CampaignCustomizerServiceValue
from yahoo_search_api_v12.models.campaign_export_service_add_response import CampaignExportServiceAddResponse
from yahoo_search_api_v12.models.campaign_export_service_approval_status import CampaignExportServiceApprovalStatus
from yahoo_search_api_v12.models.campaign_export_service_download_selector import CampaignExportServiceDownloadSelector
from yahoo_search_api_v12.models.campaign_export_service_encoding import CampaignExportServiceEncoding
from yahoo_search_api_v12.models.campaign_export_service_entity_type import CampaignExportServiceEntityType
from yahoo_search_api_v12.models.campaign_export_service_export_setting import CampaignExportServiceExportSetting
from yahoo_search_api_v12.models.campaign_export_service_field_attribute import CampaignExportServiceFieldAttribute
from yahoo_search_api_v12.models.campaign_export_service_field_value import CampaignExportServiceFieldValue
from yahoo_search_api_v12.models.campaign_export_service_get_export_fields_response import CampaignExportServiceGetExportFieldsResponse
from yahoo_search_api_v12.models.campaign_export_service_get_response import CampaignExportServiceGetResponse
from yahoo_search_api_v12.models.campaign_export_service_job import CampaignExportServiceJob
from yahoo_search_api_v12.models.campaign_export_service_job_operation import CampaignExportServiceJobOperation
from yahoo_search_api_v12.models.campaign_export_service_job_status import CampaignExportServiceJobStatus
from yahoo_search_api_v12.models.campaign_export_service_lang import CampaignExportServiceLang
from yahoo_search_api_v12.models.campaign_export_service_output import CampaignExportServiceOutput
from yahoo_search_api_v12.models.campaign_export_service_page import CampaignExportServicePage
from yahoo_search_api_v12.models.campaign_export_service_return_value import CampaignExportServiceReturnValue
from yahoo_search_api_v12.models.campaign_export_service_selector import CampaignExportServiceSelector
from yahoo_search_api_v12.models.campaign_export_service_user_status import CampaignExportServiceUserStatus
from yahoo_search_api_v12.models.campaign_export_service_value import CampaignExportServiceValue
from yahoo_search_api_v12.models.campaign_label import CampaignLabel
from yahoo_search_api_v12.models.campaign_label_service_mutate_response import CampaignLabelServiceMutateResponse
from yahoo_search_api_v12.models.campaign_label_service_operation import CampaignLabelServiceOperation
from yahoo_search_api_v12.models.campaign_label_service_return_value import CampaignLabelServiceReturnValue
from yahoo_search_api_v12.models.campaign_label_service_value import CampaignLabelServiceValue
from yahoo_search_api_v12.models.campaign_retargeting_list import CampaignRetargetingList
from yahoo_search_api_v12.models.campaign_retargeting_list_service_criterion_target_list import CampaignRetargetingListServiceCriterionTargetList
from yahoo_search_api_v12.models.campaign_retargeting_list_service_excluded_type import CampaignRetargetingListServiceExcludedType
from yahoo_search_api_v12.models.campaign_retargeting_list_service_get_response import CampaignRetargetingListServiceGetResponse
from yahoo_search_api_v12.models.campaign_retargeting_list_service_mutate_response import CampaignRetargetingListServiceMutateResponse
from yahoo_search_api_v12.models.campaign_retargeting_list_service_operation import CampaignRetargetingListServiceOperation
from yahoo_search_api_v12.models.campaign_retargeting_list_service_page import CampaignRetargetingListServicePage
from yahoo_search_api_v12.models.campaign_retargeting_list_service_return_value import CampaignRetargetingListServiceReturnValue
from yahoo_search_api_v12.models.campaign_retargeting_list_service_selector import CampaignRetargetingListServiceSelector
from yahoo_search_api_v12.models.campaign_retargeting_list_service_value import CampaignRetargetingListServiceValue
from yahoo_search_api_v12.models.campaign_service_app_os_type import CampaignServiceAppOsType
from yahoo_search_api_v12.models.campaign_service_bidding_scheme import CampaignServiceBiddingScheme
from yahoo_search_api_v12.models.campaign_service_bidding_strategy import CampaignServiceBiddingStrategy
from yahoo_search_api_v12.models.campaign_service_bidding_strategy_failed_reason import CampaignServiceBiddingStrategyFailedReason
from yahoo_search_api_v12.models.campaign_service_bidding_strategy_source import CampaignServiceBiddingStrategySource
from yahoo_search_api_v12.models.campaign_service_bidding_strategy_type import CampaignServiceBiddingStrategyType
from yahoo_search_api_v12.models.campaign_service_budget import CampaignServiceBudget
from yahoo_search_api_v12.models.campaign_service_budget_amount_range import CampaignServiceBudgetAmountRange
from yahoo_search_api_v12.models.campaign_service_conversion_optimizer_eligibility import CampaignServiceConversionOptimizerEligibility
from yahoo_search_api_v12.models.campaign_service_cpc_bidding_scheme import CampaignServiceCpcBiddingScheme
from yahoo_search_api_v12.models.campaign_service_created_date_range import CampaignServiceCreatedDateRange
from yahoo_search_api_v12.models.campaign_service_custom_parameter import CampaignServiceCustomParameter
from yahoo_search_api_v12.models.campaign_service_custom_parameters import CampaignServiceCustomParameters
from yahoo_search_api_v12.models.campaign_service_das_use_urls_type import CampaignServiceDasUseUrlsType
from yahoo_search_api_v12.models.campaign_service_dynamic_ads_for_search_setting import CampaignServiceDynamicAdsForSearchSetting
from yahoo_search_api_v12.models.campaign_service_enhanced_cpc_enabled import CampaignServiceEnhancedCpcEnabled
from yahoo_search_api_v12.models.campaign_service_geo_target_type import CampaignServiceGeoTargetType
from yahoo_search_api_v12.models.campaign_service_geo_target_type_setting import CampaignServiceGeoTargetTypeSetting
from yahoo_search_api_v12.models.campaign_service_get_response import CampaignServiceGetResponse
from yahoo_search_api_v12.models.campaign_service_is_remove import CampaignServiceIsRemove
from yahoo_search_api_v12.models.campaign_service_label import CampaignServiceLabel
from yahoo_search_api_v12.models.campaign_service_maximize_clicks_bidding_scheme import CampaignServiceMaximizeClicksBiddingScheme
from yahoo_search_api_v12.models.campaign_service_maximize_conversion_value_bidding_scheme import CampaignServiceMaximizeConversionValueBiddingScheme
from yahoo_search_api_v12.models.campaign_service_maximize_conversions_bidding_scheme import CampaignServiceMaximizeConversionsBiddingScheme
from yahoo_search_api_v12.models.campaign_service_mutate_response import CampaignServiceMutateResponse
from yahoo_search_api_v12.models.campaign_service_operation import CampaignServiceOperation
from yahoo_search_api_v12.models.campaign_service_page import CampaignServicePage
from yahoo_search_api_v12.models.campaign_service_return_value import CampaignServiceReturnValue
from yahoo_search_api_v12.models.campaign_service_review_url import CampaignServiceReviewUrl
from yahoo_search_api_v12.models.campaign_service_selector import CampaignServiceSelector
from yahoo_search_api_v12.models.campaign_service_serving_status import CampaignServiceServingStatus
from yahoo_search_api_v12.models.campaign_service_setting_type import CampaignServiceSettingType
from yahoo_search_api_v12.models.campaign_service_settings import CampaignServiceSettings
from yahoo_search_api_v12.models.campaign_service_target_all import CampaignServiceTargetAll
from yahoo_search_api_v12.models.campaign_service_target_cpa_bidding_scheme import CampaignServiceTargetCpaBiddingScheme
from yahoo_search_api_v12.models.campaign_service_target_impression_share_location import CampaignServiceTargetImpressionShareLocation
from yahoo_search_api_v12.models.campaign_service_target_impression_share_scheme import CampaignServiceTargetImpressionShareScheme
from yahoo_search_api_v12.models.campaign_service_target_roas_bidding_scheme import CampaignServiceTargetRoasBiddingScheme
from yahoo_search_api_v12.models.campaign_service_targeting_setting import CampaignServiceTargetingSetting
from yahoo_search_api_v12.models.campaign_service_type import CampaignServiceType
from yahoo_search_api_v12.models.campaign_service_url_approval_status import CampaignServiceUrlApprovalStatus
from yahoo_search_api_v12.models.campaign_service_url_review_data import CampaignServiceUrlReviewData
from yahoo_search_api_v12.models.campaign_service_user_status import CampaignServiceUserStatus
from yahoo_search_api_v12.models.campaign_service_value import CampaignServiceValue
from yahoo_search_api_v12.models.campaign_shared_set import CampaignSharedSet
from yahoo_search_api_v12.models.campaign_shared_set_service_get_response import CampaignSharedSetServiceGetResponse
from yahoo_search_api_v12.models.campaign_shared_set_service_mutate_response import CampaignSharedSetServiceMutateResponse
from yahoo_search_api_v12.models.campaign_shared_set_service_operation import CampaignSharedSetServiceOperation
from yahoo_search_api_v12.models.campaign_shared_set_service_page import CampaignSharedSetServicePage
from yahoo_search_api_v12.models.campaign_shared_set_service_return_value import CampaignSharedSetServiceReturnValue
from yahoo_search_api_v12.models.campaign_shared_set_service_selector import CampaignSharedSetServiceSelector
from yahoo_search_api_v12.models.campaign_shared_set_service_value import CampaignSharedSetServiceValue
from yahoo_search_api_v12.models.campaign_target import CampaignTarget
from yahoo_search_api_v12.models.campaign_target_service_day_of_week import CampaignTargetServiceDayOfWeek
from yahoo_search_api_v12.models.campaign_target_service_excluded_type import CampaignTargetServiceExcludedType
from yahoo_search_api_v12.models.campaign_target_service_get_response import CampaignTargetServiceGetResponse
from yahoo_search_api_v12.models.campaign_target_service_location_target import CampaignTargetServiceLocationTarget
from yahoo_search_api_v12.models.campaign_target_service_minute_of_hour import CampaignTargetServiceMinuteOfHour
from yahoo_search_api_v12.models.campaign_target_service_mutate_response import CampaignTargetServiceMutateResponse
from yahoo_search_api_v12.models.campaign_target_service_network_coverage_type import CampaignTargetServiceNetworkCoverageType
from yahoo_search_api_v12.models.campaign_target_service_network_target import CampaignTargetServiceNetworkTarget
from yahoo_search_api_v12.models.campaign_target_service_operation import CampaignTargetServiceOperation
from yahoo_search_api_v12.models.campaign_target_service_page import CampaignTargetServicePage
from yahoo_search_api_v12.models.campaign_target_service_platform_target import CampaignTargetServicePlatformTarget
from yahoo_search_api_v12.models.campaign_target_service_platform_type import CampaignTargetServicePlatformType
from yahoo_search_api_v12.models.campaign_target_service_return_value import CampaignTargetServiceReturnValue
from yahoo_search_api_v12.models.campaign_target_service_schedule_target import CampaignTargetServiceScheduleTarget
from yahoo_search_api_v12.models.campaign_target_service_selector import CampaignTargetServiceSelector
from yahoo_search_api_v12.models.campaign_target_service_target import CampaignTargetServiceTarget
from yahoo_search_api_v12.models.campaign_target_service_target_type import CampaignTargetServiceTargetType
from yahoo_search_api_v12.models.campaign_target_service_targeting_status import CampaignTargetServiceTargetingStatus
from yahoo_search_api_v12.models.campaign_target_service_value import CampaignTargetServiceValue
from yahoo_search_api_v12.models.campaign_webpage import CampaignWebpage
from yahoo_search_api_v12.models.campaign_webpage_service_get_response import CampaignWebpageServiceGetResponse
from yahoo_search_api_v12.models.campaign_webpage_service_mutate_response import CampaignWebpageServiceMutateResponse
from yahoo_search_api_v12.models.campaign_webpage_service_operation import CampaignWebpageServiceOperation
from yahoo_search_api_v12.models.campaign_webpage_service_page import CampaignWebpageServicePage
from yahoo_search_api_v12.models.campaign_webpage_service_return_value import CampaignWebpageServiceReturnValue
from yahoo_search_api_v12.models.campaign_webpage_service_selector import CampaignWebpageServiceSelector
from yahoo_search_api_v12.models.campaign_webpage_service_value import CampaignWebpageServiceValue
from yahoo_search_api_v12.models.campaign_webpage_service_webpage import CampaignWebpageServiceWebpage
from yahoo_search_api_v12.models.campaign_webpage_service_webpage_condition import CampaignWebpageServiceWebpageCondition
from yahoo_search_api_v12.models.campaign_webpage_service_webpage_condition_type import CampaignWebpageServiceWebpageConditionType
from yahoo_search_api_v12.models.campaign_webpage_service_webpage_operator import CampaignWebpageServiceWebpageOperator
from yahoo_search_api_v12.models.campaign_webpage_service_webpage_parameter import CampaignWebpageServiceWebpageParameter
from yahoo_search_api_v12.models.conversion_tracker import ConversionTracker
from yahoo_search_api_v12.models.conversion_tracker_service_app_conversion import ConversionTrackerServiceAppConversion
from yahoo_search_api_v12.models.conversion_tracker_service_app_conversion_type import ConversionTrackerServiceAppConversionType
from yahoo_search_api_v12.models.conversion_tracker_service_app_event import ConversionTrackerServiceAppEvent
from yahoo_search_api_v12.models.conversion_tracker_service_app_event_type_page import ConversionTrackerServiceAppEventTypePage
from yahoo_search_api_v12.models.conversion_tracker_service_app_event_type_selector import ConversionTrackerServiceAppEventTypeSelector
from yahoo_search_api_v12.models.conversion_tracker_service_app_event_type_value import ConversionTrackerServiceAppEventTypeValue
from yahoo_search_api_v12.models.conversion_tracker_service_app_link_conversion import ConversionTrackerServiceAppLinkConversion
from yahoo_search_api_v12.models.conversion_tracker_service_app_link_platform import ConversionTrackerServiceAppLinkPlatform
from yahoo_search_api_v12.models.conversion_tracker_service_app_platform import ConversionTrackerServiceAppPlatform
from yahoo_search_api_v12.models.conversion_tracker_service_app_postback_url import ConversionTrackerServiceAppPostbackUrl
from yahoo_search_api_v12.models.conversion_tracker_service_category import ConversionTrackerServiceCategory
from yahoo_search_api_v12.models.conversion_tracker_service_conversion_counting_type import ConversionTrackerServiceConversionCountingType
from yahoo_search_api_v12.models.conversion_tracker_service_conversion_date_range import ConversionTrackerServiceConversionDateRange
from yahoo_search_api_v12.models.conversion_tracker_service_conversion_tracker_type import ConversionTrackerServiceConversionTrackerType
from yahoo_search_api_v12.models.conversion_tracker_service_exclude_from_bidding import ConversionTrackerServiceExcludeFromBidding
from yahoo_search_api_v12.models.conversion_tracker_service_get_app_event_type_response import ConversionTrackerServiceGetAppEventTypeResponse
from yahoo_search_api_v12.models.conversion_tracker_service_get_response import ConversionTrackerServiceGetResponse
from yahoo_search_api_v12.models.conversion_tracker_service_is_remove_url import ConversionTrackerServiceIsRemoveUrl
from yahoo_search_api_v12.models.conversion_tracker_service_markup_language import ConversionTrackerServiceMarkupLanguage
from yahoo_search_api_v12.models.conversion_tracker_service_mutate_response import ConversionTrackerServiceMutateResponse
from yahoo_search_api_v12.models.conversion_tracker_service_operation import ConversionTrackerServiceOperation
from yahoo_search_api_v12.models.conversion_tracker_service_page import ConversionTrackerServicePage
from yahoo_search_api_v12.models.conversion_tracker_service_return_value import ConversionTrackerServiceReturnValue
from yahoo_search_api_v12.models.conversion_tracker_service_selector import ConversionTrackerServiceSelector
from yahoo_search_api_v12.models.conversion_tracker_service_status import ConversionTrackerServiceStatus
from yahoo_search_api_v12.models.conversion_tracker_service_tracking_code_type import ConversionTrackerServiceTrackingCodeType
from yahoo_search_api_v12.models.conversion_tracker_service_value import ConversionTrackerServiceValue
from yahoo_search_api_v12.models.conversion_tracker_service_web_conversion import ConversionTrackerServiceWebConversion
from yahoo_search_api_v12.models.customizer_attribute import CustomizerAttribute
from yahoo_search_api_v12.models.customizer_attribute_service_get_response import CustomizerAttributeServiceGetResponse
from yahoo_search_api_v12.models.customizer_attribute_service_mutate_response import CustomizerAttributeServiceMutateResponse
from yahoo_search_api_v12.models.customizer_attribute_service_operation import CustomizerAttributeServiceOperation
from yahoo_search_api_v12.models.customizer_attribute_service_page import CustomizerAttributeServicePage
from yahoo_search_api_v12.models.customizer_attribute_service_return_value import CustomizerAttributeServiceReturnValue
from yahoo_search_api_v12.models.customizer_attribute_service_selector import CustomizerAttributeServiceSelector
from yahoo_search_api_v12.models.customizer_attribute_service_type import CustomizerAttributeServiceType
from yahoo_search_api_v12.models.customizer_attribute_service_value import CustomizerAttributeServiceValue
from yahoo_search_api_v12.models.dictionary_service_app_link_vendor import DictionaryServiceAppLinkVendor
from yahoo_search_api_v12.models.dictionary_service_app_link_vendor_page import DictionaryServiceAppLinkVendorPage
from yahoo_search_api_v12.models.dictionary_service_app_link_vendor_selector import DictionaryServiceAppLinkVendorSelector
from yahoo_search_api_v12.models.dictionary_service_app_link_vendor_value import DictionaryServiceAppLinkVendorValue
from yahoo_search_api_v12.models.dictionary_service_disapproval_reason import DictionaryServiceDisapprovalReason
from yahoo_search_api_v12.models.dictionary_service_disapproval_reason_page import DictionaryServiceDisapprovalReasonPage
from yahoo_search_api_v12.models.dictionary_service_disapproval_reason_selector import DictionaryServiceDisapprovalReasonSelector
from yahoo_search_api_v12.models.dictionary_service_disapproval_reason_value import DictionaryServiceDisapprovalReasonValue
from yahoo_search_api_v12.models.dictionary_service_geographic_location import DictionaryServiceGeographicLocation
from yahoo_search_api_v12.models.dictionary_service_geographic_location_page import DictionaryServiceGeographicLocationPage
from yahoo_search_api_v12.models.dictionary_service_geographic_location_selector import DictionaryServiceGeographicLocationSelector
from yahoo_search_api_v12.models.dictionary_service_geographic_location_status import DictionaryServiceGeographicLocationStatus
from yahoo_search_api_v12.models.dictionary_service_geographic_location_value import DictionaryServiceGeographicLocationValue
from yahoo_search_api_v12.models.dictionary_service_get_app_link_vendor_response import DictionaryServiceGetAppLinkVendorResponse
from yahoo_search_api_v12.models.dictionary_service_get_disapproval_reason_response import DictionaryServiceGetDisapprovalReasonResponse
from yahoo_search_api_v12.models.dictionary_service_get_geographic_location_response import DictionaryServiceGetGeographicLocationResponse
from yahoo_search_api_v12.models.dictionary_service_lang import DictionaryServiceLang
from yahoo_search_api_v12.models.error import Error
from yahoo_search_api_v12.models.error_detail import ErrorDetail
from yahoo_search_api_v12.models.feed import Feed
from yahoo_search_api_v12.models.feed_item import FeedItem
from yahoo_search_api_v12.models.feed_item_service_approval_status import FeedItemServiceApprovalStatus
from yahoo_search_api_v12.models.feed_item_service_attribute import FeedItemServiceAttribute
from yahoo_search_api_v12.models.feed_item_service_criterion_type_feed_item import FeedItemServiceCriterionTypeFeedItem
from yahoo_search_api_v12.models.feed_item_service_custom_parameter import FeedItemServiceCustomParameter
from yahoo_search_api_v12.models.feed_item_service_custom_parameters import FeedItemServiceCustomParameters
from yahoo_search_api_v12.models.feed_item_service_day_of_week import FeedItemServiceDayOfWeek
from yahoo_search_api_v12.models.feed_item_service_device_preference import FeedItemServiceDevicePreference
from yahoo_search_api_v12.models.feed_item_service_feed_attribute_value import FeedItemServiceFeedAttributeValue
from yahoo_search_api_v12.models.feed_item_service_geo_restriction import FeedItemServiceGeoRestriction
from yahoo_search_api_v12.models.feed_item_service_get_response import FeedItemServiceGetResponse
from yahoo_search_api_v12.models.feed_item_service_is_remove import FeedItemServiceIsRemove
from yahoo_search_api_v12.models.feed_item_service_keyword_match_type import FeedItemServiceKeywordMatchType
from yahoo_search_api_v12.models.feed_item_service_location import FeedItemServiceLocation
from yahoo_search_api_v12.models.feed_item_service_minute_of_hour import FeedItemServiceMinuteOfHour
from yahoo_search_api_v12.models.feed_item_service_multiple_feed_item_attribute import FeedItemServiceMultipleFeedItemAttribute
from yahoo_search_api_v12.models.feed_item_service_page import FeedItemServicePage
from yahoo_search_api_v12.models.feed_item_service_placeholder_field import FeedItemServicePlaceholderField
from yahoo_search_api_v12.models.feed_item_service_placeholder_type import FeedItemServicePlaceholderType
from yahoo_search_api_v12.models.feed_item_service_schedule import FeedItemServiceSchedule
from yahoo_search_api_v12.models.feed_item_service_scheduling import FeedItemServiceScheduling
from yahoo_search_api_v12.models.feed_item_service_selector import FeedItemServiceSelector
from yahoo_search_api_v12.models.feed_item_service_simple_feed_item_attribute import FeedItemServiceSimpleFeedItemAttribute
from yahoo_search_api_v12.models.feed_item_service_targeting_ad_group import FeedItemServiceTargetingAdGroup
from yahoo_search_api_v12.models.feed_item_service_targeting_campaign import FeedItemServiceTargetingCampaign
from yahoo_search_api_v12.models.feed_item_service_targeting_keyword import FeedItemServiceTargetingKeyword
from yahoo_search_api_v12.models.feed_item_service_trademark_status import FeedItemServiceTrademarkStatus
from yahoo_search_api_v12.models.feed_item_service_value import FeedItemServiceValue
from yahoo_search_api_v12.models.feed_service_attribute import FeedServiceAttribute
from yahoo_search_api_v12.models.feed_service_get_response import FeedServiceGetResponse
from yahoo_search_api_v12.models.feed_service_page import FeedServicePage
from yahoo_search_api_v12.models.feed_service_placeholder_field import FeedServicePlaceholderField
from yahoo_search_api_v12.models.feed_service_placeholder_type import FeedServicePlaceholderType
from yahoo_search_api_v12.models.feed_service_selector import FeedServiceSelector
from yahoo_search_api_v12.models.feed_service_value import FeedServiceValue
from yahoo_search_api_v12.models.inline_object import InlineObject
from yahoo_search_api_v12.models.inline_object1 import InlineObject1
from yahoo_search_api_v12.models.keyword_forecast_metrics import KeywordForecastMetrics
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_date_interval import KeywordForecastMetricsServiceDateInterval
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_get_response import KeywordForecastMetricsServiceGetResponse
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_keyword_plan_ad_group import KeywordForecastMetricsServiceKeywordPlanAdGroup
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_keyword_plan_ad_group_keyword import KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_keyword_plan_campaign import KeywordForecastMetricsServiceKeywordPlanCampaign
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_keyword_plan_network import KeywordForecastMetricsServiceKeywordPlanNetwork
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_match_type import KeywordForecastMetricsServiceMatchType
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_page import KeywordForecastMetricsServicePage
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_selector import KeywordForecastMetricsServiceSelector
from yahoo_search_api_v12.models.keyword_forecast_metrics_service_value import KeywordForecastMetricsServiceValue
from yahoo_search_api_v12.models.keyword_plan_idea import KeywordPlanIdea
from yahoo_search_api_v12.models.keyword_plan_idea_service_get_response import KeywordPlanIdeaServiceGetResponse
from yahoo_search_api_v12.models.keyword_plan_idea_service_keyword_and_url_seed import KeywordPlanIdeaServiceKeywordAndUrlSeed
from yahoo_search_api_v12.models.keyword_plan_idea_service_keyword_seed import KeywordPlanIdeaServiceKeywordSeed
from yahoo_search_api_v12.models.keyword_plan_idea_service_page import KeywordPlanIdeaServicePage
from yahoo_search_api_v12.models.keyword_plan_idea_service_seed import KeywordPlanIdeaServiceSeed
from yahoo_search_api_v12.models.keyword_plan_idea_service_seed_type import KeywordPlanIdeaServiceSeedType
from yahoo_search_api_v12.models.keyword_plan_idea_service_selector import KeywordPlanIdeaServiceSelector
from yahoo_search_api_v12.models.keyword_plan_idea_service_site_seed import KeywordPlanIdeaServiceSiteSeed
from yahoo_search_api_v12.models.keyword_plan_idea_service_url_seed import KeywordPlanIdeaServiceUrlSeed
from yahoo_search_api_v12.models.keyword_plan_idea_service_value import KeywordPlanIdeaServiceValue
from yahoo_search_api_v12.models.label import Label
from yahoo_search_api_v12.models.label_service_count_labeled_entity import LabelServiceCountLabeledEntity
from yahoo_search_api_v12.models.label_service_get_response import LabelServiceGetResponse
from yahoo_search_api_v12.models.label_service_mutate_response import LabelServiceMutateResponse
from yahoo_search_api_v12.models.label_service_operation import LabelServiceOperation
from yahoo_search_api_v12.models.label_service_page import LabelServicePage
from yahoo_search_api_v12.models.label_service_return_value import LabelServiceReturnValue
from yahoo_search_api_v12.models.label_service_selector import LabelServiceSelector
from yahoo_search_api_v12.models.label_service_value import LabelServiceValue
from yahoo_search_api_v12.models.offline_conversion_file import OfflineConversionFile
from yahoo_search_api_v12.models.offline_conversion_service_download_selector import OfflineConversionServiceDownloadSelector
from yahoo_search_api_v12.models.offline_conversion_service_get_response import OfflineConversionServiceGetResponse
from yahoo_search_api_v12.models.offline_conversion_service_page import OfflineConversionServicePage
from yahoo_search_api_v12.models.offline_conversion_service_process_status import OfflineConversionServiceProcessStatus
from yahoo_search_api_v12.models.offline_conversion_service_selector import OfflineConversionServiceSelector
from yahoo_search_api_v12.models.offline_conversion_service_sort import OfflineConversionServiceSort
from yahoo_search_api_v12.models.offline_conversion_service_sort_field import OfflineConversionServiceSortField
from yahoo_search_api_v12.models.offline_conversion_service_sort_type import OfflineConversionServiceSortType
from yahoo_search_api_v12.models.offline_conversion_service_upload_response import OfflineConversionServiceUploadResponse
from yahoo_search_api_v12.models.offline_conversion_service_upload_return_value import OfflineConversionServiceUploadReturnValue
from yahoo_search_api_v12.models.offline_conversion_service_upload_source_type import OfflineConversionServiceUploadSourceType
from yahoo_search_api_v12.models.offline_conversion_service_upload_type import OfflineConversionServiceUploadType
from yahoo_search_api_v12.models.offline_conversion_service_value import OfflineConversionServiceValue
from yahoo_search_api_v12.models.page_feed_asset import PageFeedAsset
from yahoo_search_api_v12.models.page_feed_asset_service_add_download_job_operation import PageFeedAssetServiceAddDownloadJobOperation
from yahoo_search_api_v12.models.page_feed_asset_service_add_download_job_response import PageFeedAssetServiceAddDownloadJobResponse
from yahoo_search_api_v12.models.page_feed_asset_service_add_download_job_return_value import PageFeedAssetServiceAddDownloadJobReturnValue
from yahoo_search_api_v12.models.page_feed_asset_service_add_download_job_value import PageFeedAssetServiceAddDownloadJobValue
from yahoo_search_api_v12.models.page_feed_asset_service_approval_status import PageFeedAssetServiceApprovalStatus
from yahoo_search_api_v12.models.page_feed_asset_service_bulk_encoding import PageFeedAssetServiceBulkEncoding
from yahoo_search_api_v12.models.page_feed_asset_service_bulk_lang import PageFeedAssetServiceBulkLang
from yahoo_search_api_v12.models.page_feed_asset_service_bulk_output import PageFeedAssetServiceBulkOutput
from yahoo_search_api_v12.models.page_feed_asset_service_download_job import PageFeedAssetServiceDownloadJob
from yahoo_search_api_v12.models.page_feed_asset_service_download_job_status import PageFeedAssetServiceDownloadJobStatus
from yahoo_search_api_v12.models.page_feed_asset_service_download_selector import PageFeedAssetServiceDownloadSelector
from yahoo_search_api_v12.models.page_feed_asset_service_get_job_status_page import PageFeedAssetServiceGetJobStatusPage
from yahoo_search_api_v12.models.page_feed_asset_service_get_job_status_response import PageFeedAssetServiceGetJobStatusResponse
from yahoo_search_api_v12.models.page_feed_asset_service_get_job_status_selector import PageFeedAssetServiceGetJobStatusSelector
from yahoo_search_api_v12.models.page_feed_asset_service_get_job_status_type import PageFeedAssetServiceGetJobStatusType
from yahoo_search_api_v12.models.page_feed_asset_service_get_job_status_value import PageFeedAssetServiceGetJobStatusValue
from yahoo_search_api_v12.models.page_feed_asset_service_get_response import PageFeedAssetServiceGetResponse
from yahoo_search_api_v12.models.page_feed_asset_service_get_review_summary_page import PageFeedAssetServiceGetReviewSummaryPage
from yahoo_search_api_v12.models.page_feed_asset_service_get_review_summary_response import PageFeedAssetServiceGetReviewSummaryResponse
from yahoo_search_api_v12.models.page_feed_asset_service_get_review_summary_selector import PageFeedAssetServiceGetReviewSummarySelector
from yahoo_search_api_v12.models.page_feed_asset_service_get_review_summary_value import PageFeedAssetServiceGetReviewSummaryValue
from yahoo_search_api_v12.models.page_feed_asset_service_match_type import PageFeedAssetServiceMatchType
from yahoo_search_api_v12.models.page_feed_asset_service_page import PageFeedAssetServicePage
from yahoo_search_api_v12.models.page_feed_asset_service_page_feed_asset_url import PageFeedAssetServicePageFeedAssetUrl
from yahoo_search_api_v12.models.page_feed_asset_service_return_value import PageFeedAssetServiceReturnValue
from yahoo_search_api_v12.models.page_feed_asset_service_review_summary import PageFeedAssetServiceReviewSummary
from yahoo_search_api_v12.models.page_feed_asset_service_selector import PageFeedAssetServiceSelector
from yahoo_search_api_v12.models.page_feed_asset_service_upload_job import PageFeedAssetServiceUploadJob
from yahoo_search_api_v12.models.page_feed_asset_service_upload_job_status import PageFeedAssetServiceUploadJobStatus
from yahoo_search_api_v12.models.page_feed_asset_service_upload_response import PageFeedAssetServiceUploadResponse
from yahoo_search_api_v12.models.page_feed_asset_service_upload_return_value import PageFeedAssetServiceUploadReturnValue
from yahoo_search_api_v12.models.page_feed_asset_service_upload_value import PageFeedAssetServiceUploadValue
from yahoo_search_api_v12.models.page_feed_asset_set import PageFeedAssetSet
from yahoo_search_api_v12.models.page_feed_asset_set_service_get_response import PageFeedAssetSetServiceGetResponse
from yahoo_search_api_v12.models.page_feed_asset_set_service_mutate_response import PageFeedAssetSetServiceMutateResponse
from yahoo_search_api_v12.models.page_feed_asset_set_service_operation import PageFeedAssetSetServiceOperation
from yahoo_search_api_v12.models.page_feed_asset_set_service_page import PageFeedAssetSetServicePage
from yahoo_search_api_v12.models.page_feed_asset_set_service_return_value import PageFeedAssetSetServiceReturnValue
from yahoo_search_api_v12.models.page_feed_asset_set_service_selector import PageFeedAssetSetServiceSelector
from yahoo_search_api_v12.models.page_feed_asset_set_service_value import PageFeedAssetSetServiceValue
from yahoo_search_api_v12.models.report_definition import ReportDefinition
from yahoo_search_api_v12.models.report_definition_service_download_selector import ReportDefinitionServiceDownloadSelector
from yahoo_search_api_v12.models.report_definition_service_field_value import ReportDefinitionServiceFieldValue
from yahoo_search_api_v12.models.report_definition_service_filter_operator import ReportDefinitionServiceFilterOperator
from yahoo_search_api_v12.models.report_definition_service_get_report_fields import ReportDefinitionServiceGetReportFields
from yahoo_search_api_v12.models.report_definition_service_get_report_fields_response import ReportDefinitionServiceGetReportFieldsResponse
from yahoo_search_api_v12.models.report_definition_service_get_response import ReportDefinitionServiceGetResponse
from yahoo_search_api_v12.models.report_definition_service_mutate_response import ReportDefinitionServiceMutateResponse
from yahoo_search_api_v12.models.report_definition_service_operation import ReportDefinitionServiceOperation
from yahoo_search_api_v12.models.report_definition_service_page import ReportDefinitionServicePage
from yahoo_search_api_v12.models.report_definition_service_report_compress_type import ReportDefinitionServiceReportCompressType
from yahoo_search_api_v12.models.report_definition_service_report_date_range import ReportDefinitionServiceReportDateRange
from yahoo_search_api_v12.models.report_definition_service_report_date_range_type import ReportDefinitionServiceReportDateRangeType
from yahoo_search_api_v12.models.report_definition_service_report_decimal_part_display_type import ReportDefinitionServiceReportDecimalPartDisplayType
from yahoo_search_api_v12.models.report_definition_service_report_download_encode import ReportDefinitionServiceReportDownloadEncode
from yahoo_search_api_v12.models.report_definition_service_report_download_format import ReportDefinitionServiceReportDownloadFormat
from yahoo_search_api_v12.models.report_definition_service_report_field_attribute import ReportDefinitionServiceReportFieldAttribute
from yahoo_search_api_v12.models.report_definition_service_report_filter import ReportDefinitionServiceReportFilter
from yahoo_search_api_v12.models.report_definition_service_report_include_deleted import ReportDefinitionServiceReportIncludeDeleted
from yahoo_search_api_v12.models.report_definition_service_report_job_status import ReportDefinitionServiceReportJobStatus
from yahoo_search_api_v12.models.report_definition_service_report_language import ReportDefinitionServiceReportLanguage
from yahoo_search_api_v12.models.report_definition_service_report_skip_column_header import ReportDefinitionServiceReportSkipColumnHeader
from yahoo_search_api_v12.models.report_definition_service_report_skip_report_summary import ReportDefinitionServiceReportSkipReportSummary
from yahoo_search_api_v12.models.report_definition_service_report_sort_field import ReportDefinitionServiceReportSortField
from yahoo_search_api_v12.models.report_definition_service_report_sort_type import ReportDefinitionServiceReportSortType
from yahoo_search_api_v12.models.report_definition_service_report_type import ReportDefinitionServiceReportType
from yahoo_search_api_v12.models.report_definition_service_return_value import ReportDefinitionServiceReturnValue
from yahoo_search_api_v12.models.report_definition_service_selector import ReportDefinitionServiceSelector
from yahoo_search_api_v12.models.report_definition_service_value import ReportDefinitionServiceValue
from yahoo_search_api_v12.models.retargeting_list_service_closing_reason import RetargetingListServiceClosingReason
from yahoo_search_api_v12.models.retargeting_list_service_custom_key import RetargetingListServiceCustomKey
from yahoo_search_api_v12.models.retargeting_list_service_custom_key_page import RetargetingListServiceCustomKeyPage
from yahoo_search_api_v12.models.retargeting_list_service_custom_key_rule_item import RetargetingListServiceCustomKeyRuleItem
from yahoo_search_api_v12.models.retargeting_list_service_default_target_list import RetargetingListServiceDefaultTargetList
from yahoo_search_api_v12.models.retargeting_list_service_get_custom_key_response import RetargetingListServiceGetCustomKeyResponse
from yahoo_search_api_v12.models.retargeting_list_service_get_custom_key_selector import RetargetingListServiceGetCustomKeySelector
from yahoo_search_api_v12.models.retargeting_list_service_get_response import RetargetingListServiceGetResponse
from yahoo_search_api_v12.models.retargeting_list_service_is_all_visitor_rule import RetargetingListServiceIsAllVisitorRule
from yahoo_search_api_v12.models.retargeting_list_service_is_date_specific_rule import RetargetingListServiceIsDateSpecificRule
from yahoo_search_api_v12.models.retargeting_list_service_logical_condition import RetargetingListServiceLogicalCondition
from yahoo_search_api_v12.models.retargeting_list_service_logical_group import RetargetingListServiceLogicalGroup
from yahoo_search_api_v12.models.retargeting_list_service_logical_rule_operand import RetargetingListServiceLogicalRuleOperand
from yahoo_search_api_v12.models.retargeting_list_service_logical_target_list import RetargetingListServiceLogicalTargetList
from yahoo_search_api_v12.models.retargeting_list_service_mutate_response import RetargetingListServiceMutateResponse
from yahoo_search_api_v12.models.retargeting_list_service_operation import RetargetingListServiceOperation
from yahoo_search_api_v12.models.retargeting_list_service_page import RetargetingListServicePage
from yahoo_search_api_v12.models.retargeting_list_service_reach_storage_status import RetargetingListServiceReachStorageStatus
from yahoo_search_api_v12.models.retargeting_list_service_retargeting_account_status import RetargetingListServiceRetargetingAccountStatus
from yahoo_search_api_v12.models.retargeting_list_service_return_value import RetargetingListServiceReturnValue
from yahoo_search_api_v12.models.retargeting_list_service_review_status import RetargetingListServiceReviewStatus
from yahoo_search_api_v12.models.retargeting_list_service_rule_base_target_list import RetargetingListServiceRuleBaseTargetList
from yahoo_search_api_v12.models.retargeting_list_service_rule_group import RetargetingListServiceRuleGroup
from yahoo_search_api_v12.models.retargeting_list_service_rule_item import RetargetingListServiceRuleItem
from yahoo_search_api_v12.models.retargeting_list_service_rule_operator import RetargetingListServiceRuleOperator
from yahoo_search_api_v12.models.retargeting_list_service_rule_type import RetargetingListServiceRuleType
from yahoo_search_api_v12.models.retargeting_list_service_selector import RetargetingListServiceSelector
from yahoo_search_api_v12.models.retargeting_list_service_tag import RetargetingListServiceTag
from yahoo_search_api_v12.models.retargeting_list_service_target_list_owner import RetargetingListServiceTargetListOwner
from yahoo_search_api_v12.models.retargeting_list_service_target_list_type import RetargetingListServiceTargetListType
from yahoo_search_api_v12.models.retargeting_list_service_targeting_list import RetargetingListServiceTargetingList
from yahoo_search_api_v12.models.retargeting_list_service_url_rule_item import RetargetingListServiceUrlRuleItem
from yahoo_search_api_v12.models.retargeting_list_service_url_rule_key import RetargetingListServiceUrlRuleKey
from yahoo_search_api_v12.models.retargeting_list_service_value import RetargetingListServiceValue
from yahoo_search_api_v12.models.shared_criterion import SharedCriterion
from yahoo_search_api_v12.models.shared_criterion_service_get_response import SharedCriterionServiceGetResponse
from yahoo_search_api_v12.models.shared_criterion_service_keyword_match_type import SharedCriterionServiceKeywordMatchType
from yahoo_search_api_v12.models.shared_criterion_service_mutate_response import SharedCriterionServiceMutateResponse
from yahoo_search_api_v12.models.shared_criterion_service_operation import SharedCriterionServiceOperation
from yahoo_search_api_v12.models.shared_criterion_service_page import SharedCriterionServicePage
from yahoo_search_api_v12.models.shared_criterion_service_return_value import SharedCriterionServiceReturnValue
from yahoo_search_api_v12.models.shared_criterion_service_selector import SharedCriterionServiceSelector
from yahoo_search_api_v12.models.shared_criterion_service_use import SharedCriterionServiceUse
from yahoo_search_api_v12.models.shared_criterion_service_value import SharedCriterionServiceValue

