# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class BaseAccount(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'account_name': 'str',
        'account_status': 'BaseAccountServiceAccountStatus',
        'auth_type': 'BaseAccountServiceAuthType',
        'has_admin_auth': 'BaseAccountServiceHasAdminAuth',
        'is_root_mcc_account': 'BaseAccountServiceIsRootMccAccount',
        'is_mcc_account': 'BaseAccountServiceIsMccAccount',
        'is_test_account': 'BaseAccountServiceIsTestAccount'
    }

    attribute_map = {
        'account_id': 'accountId',
        'account_name': 'accountName',
        'account_status': 'accountStatus',
        'auth_type': 'authType',
        'has_admin_auth': 'hasAdminAuth',
        'is_root_mcc_account': 'isRootMccAccount',
        'is_mcc_account': 'isMccAccount',
        'is_test_account': 'isTestAccount'
    }

    def __init__(self, account_id=None, account_name=None, account_status=None, auth_type=None, has_admin_auth=None, is_root_mcc_account=None, is_mcc_account=None, is_test_account=None, local_vars_configuration=None):  # noqa: E501
        """BaseAccount - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._account_name = None
        self._account_status = None
        self._auth_type = None
        self._has_admin_auth = None
        self._is_root_mcc_account = None
        self._is_mcc_account = None
        self._is_test_account = None
        self.discriminator = None

        self.account_id = account_id
        self.account_name = account_name
        self.account_status = account_status
        self.auth_type = auth_type
        self.has_admin_auth = has_admin_auth
        self.is_root_mcc_account = is_root_mcc_account
        self.is_mcc_account = is_mcc_account
        self.is_test_account = is_test_account

    @property
    def account_id(self):
        """Gets the account_id of this BaseAccount.  # noqa: E501

        <div lang=\"ja\"> アカウントIDです。 </div> <div lang=\"en\"> Account ID. </div>   # noqa: E501

        :return: The account_id of this BaseAccount.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this BaseAccount.

        <div lang=\"ja\"> アカウントIDです。 </div> <div lang=\"en\"> Account ID. </div>   # noqa: E501

        :param account_id: The account_id of this BaseAccount.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def account_name(self):
        """Gets the account_name of this BaseAccount.  # noqa: E501

        <div lang=\"ja\"> アカウント名です。 </div> <div lang=\"en\"> Account name. </div>   # noqa: E501

        :return: The account_name of this BaseAccount.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this BaseAccount.

        <div lang=\"ja\"> アカウント名です。 </div> <div lang=\"en\"> Account name. </div>   # noqa: E501

        :param account_name: The account_name of this BaseAccount.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def account_status(self):
        """Gets the account_status of this BaseAccount.  # noqa: E501


        :return: The account_status of this BaseAccount.  # noqa: E501
        :rtype: BaseAccountServiceAccountStatus
        """
        return self._account_status

    @account_status.setter
    def account_status(self, account_status):
        """Sets the account_status of this BaseAccount.


        :param account_status: The account_status of this BaseAccount.  # noqa: E501
        :type: BaseAccountServiceAccountStatus
        """

        self._account_status = account_status

    @property
    def auth_type(self):
        """Gets the auth_type of this BaseAccount.  # noqa: E501


        :return: The auth_type of this BaseAccount.  # noqa: E501
        :rtype: BaseAccountServiceAuthType
        """
        return self._auth_type

    @auth_type.setter
    def auth_type(self, auth_type):
        """Sets the auth_type of this BaseAccount.


        :param auth_type: The auth_type of this BaseAccount.  # noqa: E501
        :type: BaseAccountServiceAuthType
        """

        self._auth_type = auth_type

    @property
    def has_admin_auth(self):
        """Gets the has_admin_auth of this BaseAccount.  # noqa: E501


        :return: The has_admin_auth of this BaseAccount.  # noqa: E501
        :rtype: BaseAccountServiceHasAdminAuth
        """
        return self._has_admin_auth

    @has_admin_auth.setter
    def has_admin_auth(self, has_admin_auth):
        """Sets the has_admin_auth of this BaseAccount.


        :param has_admin_auth: The has_admin_auth of this BaseAccount.  # noqa: E501
        :type: BaseAccountServiceHasAdminAuth
        """

        self._has_admin_auth = has_admin_auth

    @property
    def is_root_mcc_account(self):
        """Gets the is_root_mcc_account of this BaseAccount.  # noqa: E501


        :return: The is_root_mcc_account of this BaseAccount.  # noqa: E501
        :rtype: BaseAccountServiceIsRootMccAccount
        """
        return self._is_root_mcc_account

    @is_root_mcc_account.setter
    def is_root_mcc_account(self, is_root_mcc_account):
        """Sets the is_root_mcc_account of this BaseAccount.


        :param is_root_mcc_account: The is_root_mcc_account of this BaseAccount.  # noqa: E501
        :type: BaseAccountServiceIsRootMccAccount
        """

        self._is_root_mcc_account = is_root_mcc_account

    @property
    def is_mcc_account(self):
        """Gets the is_mcc_account of this BaseAccount.  # noqa: E501


        :return: The is_mcc_account of this BaseAccount.  # noqa: E501
        :rtype: BaseAccountServiceIsMccAccount
        """
        return self._is_mcc_account

    @is_mcc_account.setter
    def is_mcc_account(self, is_mcc_account):
        """Sets the is_mcc_account of this BaseAccount.


        :param is_mcc_account: The is_mcc_account of this BaseAccount.  # noqa: E501
        :type: BaseAccountServiceIsMccAccount
        """

        self._is_mcc_account = is_mcc_account

    @property
    def is_test_account(self):
        """Gets the is_test_account of this BaseAccount.  # noqa: E501


        :return: The is_test_account of this BaseAccount.  # noqa: E501
        :rtype: BaseAccountServiceIsTestAccount
        """
        return self._is_test_account

    @is_test_account.setter
    def is_test_account(self, is_test_account):
        """Sets the is_test_account of this BaseAccount.


        :param is_test_account: The is_test_account of this BaseAccount.  # noqa: E501
        :type: BaseAccountServiceIsTestAccount
        """

        self._is_test_account = is_test_account

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BaseAccount):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BaseAccount):
            return True

        return self.to_dict() != other.to_dict()
