# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class PageFeedAsset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'page_feed_asset_set_id': 'int',
        'page_feed_asset_id': 'int',
        'approval_status': 'PageFeedAssetServiceApprovalStatus',
        'disapproval_reason_codes': 'list[str]',
        'disapproval_reason_comment': 'str',
        'page_feed_asset_custom_label': 'str',
        'page_feed_asset_url': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'page_feed_asset_set_id': 'pageFeedAssetSetId',
        'page_feed_asset_id': 'pageFeedAssetId',
        'approval_status': 'approvalStatus',
        'disapproval_reason_codes': 'disapprovalReasonCodes',
        'disapproval_reason_comment': 'disapprovalReasonComment',
        'page_feed_asset_custom_label': 'pageFeedAssetCustomLabel',
        'page_feed_asset_url': 'pageFeedAssetUrl'
    }

    def __init__(self, account_id=None, page_feed_asset_set_id=None, page_feed_asset_id=None, approval_status=None, disapproval_reason_codes=None, disapproval_reason_comment=None, page_feed_asset_custom_label=None, page_feed_asset_url=None, local_vars_configuration=None):  # noqa: E501
        """PageFeedAsset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._page_feed_asset_set_id = None
        self._page_feed_asset_id = None
        self._approval_status = None
        self._disapproval_reason_codes = None
        self._disapproval_reason_comment = None
        self._page_feed_asset_custom_label = None
        self._page_feed_asset_url = None
        self.discriminator = None

        self.account_id = account_id
        self.page_feed_asset_set_id = page_feed_asset_set_id
        self.page_feed_asset_id = page_feed_asset_id
        self.approval_status = approval_status
        self.disapproval_reason_codes = disapproval_reason_codes
        self.disapproval_reason_comment = disapproval_reason_comment
        self.page_feed_asset_custom_label = page_feed_asset_custom_label
        self.page_feed_asset_url = page_feed_asset_url

    @property
    def account_id(self):
        """Gets the account_id of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this PageFeedAsset.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this PageFeedAsset.

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this PageFeedAsset.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def page_feed_asset_set_id(self):
        """Gets the page_feed_asset_set_id of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットセットID</div> <div lang=\"en\">PageFeedAssetSet ID.</div>   # noqa: E501

        :return: The page_feed_asset_set_id of this PageFeedAsset.  # noqa: E501
        :rtype: int
        """
        return self._page_feed_asset_set_id

    @page_feed_asset_set_id.setter
    def page_feed_asset_set_id(self, page_feed_asset_set_id):
        """Sets the page_feed_asset_set_id of this PageFeedAsset.

        <div lang=\"ja\">ページフィードアセットセットID</div> <div lang=\"en\">PageFeedAssetSet ID.</div>   # noqa: E501

        :param page_feed_asset_set_id: The page_feed_asset_set_id of this PageFeedAsset.  # noqa: E501
        :type: int
        """

        self._page_feed_asset_set_id = page_feed_asset_set_id

    @property
    def page_feed_asset_id(self):
        """Gets the page_feed_asset_id of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットID</div> <div lang=\"en\">PageFeedAsset ID.</div>   # noqa: E501

        :return: The page_feed_asset_id of this PageFeedAsset.  # noqa: E501
        :rtype: int
        """
        return self._page_feed_asset_id

    @page_feed_asset_id.setter
    def page_feed_asset_id(self, page_feed_asset_id):
        """Sets the page_feed_asset_id of this PageFeedAsset.

        <div lang=\"ja\">ページフィードアセットID</div> <div lang=\"en\">PageFeedAsset ID.</div>   # noqa: E501

        :param page_feed_asset_id: The page_feed_asset_id of this PageFeedAsset.  # noqa: E501
        :type: int
        """

        self._page_feed_asset_id = page_feed_asset_id

    @property
    def approval_status(self):
        """Gets the approval_status of this PageFeedAsset.  # noqa: E501


        :return: The approval_status of this PageFeedAsset.  # noqa: E501
        :rtype: PageFeedAssetServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this PageFeedAsset.


        :param approval_status: The approval_status of this PageFeedAsset.  # noqa: E501
        :type: PageFeedAssetServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">審査否認理由コード</div> <div lang=\"en\">Codes of disapproval reason.</div>   # noqa: E501

        :return: The disapproval_reason_codes of this PageFeedAsset.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this PageFeedAsset.

        <div lang=\"ja\">審査否認理由コード</div> <div lang=\"en\">Codes of disapproval reason.</div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this PageFeedAsset.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    @property
    def disapproval_reason_comment(self):
        """Gets the disapproval_reason_comment of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">審査否認理由のコメント</div> <div lang=\"en\">Comment of disapproval reason.</div>   # noqa: E501

        :return: The disapproval_reason_comment of this PageFeedAsset.  # noqa: E501
        :rtype: str
        """
        return self._disapproval_reason_comment

    @disapproval_reason_comment.setter
    def disapproval_reason_comment(self, disapproval_reason_comment):
        """Sets the disapproval_reason_comment of this PageFeedAsset.

        <div lang=\"ja\">審査否認理由のコメント</div> <div lang=\"en\">Comment of disapproval reason.</div>   # noqa: E501

        :param disapproval_reason_comment: The disapproval_reason_comment of this PageFeedAsset.  # noqa: E501
        :type: str
        """

        self._disapproval_reason_comment = disapproval_reason_comment

    @property
    def page_feed_asset_custom_label(self):
        """Gets the page_feed_asset_custom_label of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットのカスタムラベル<br> 複数ある場合はカンマ区切り</div> <div lang=\"en\">Custom label of page feed asset.<br> If multiple, comma separated.</div>   # noqa: E501

        :return: The page_feed_asset_custom_label of this PageFeedAsset.  # noqa: E501
        :rtype: str
        """
        return self._page_feed_asset_custom_label

    @page_feed_asset_custom_label.setter
    def page_feed_asset_custom_label(self, page_feed_asset_custom_label):
        """Sets the page_feed_asset_custom_label of this PageFeedAsset.

        <div lang=\"ja\">ページフィードアセットのカスタムラベル<br> 複数ある場合はカンマ区切り</div> <div lang=\"en\">Custom label of page feed asset.<br> If multiple, comma separated.</div>   # noqa: E501

        :param page_feed_asset_custom_label: The page_feed_asset_custom_label of this PageFeedAsset.  # noqa: E501
        :type: str
        """

        self._page_feed_asset_custom_label = page_feed_asset_custom_label

    @property
    def page_feed_asset_url(self):
        """Gets the page_feed_asset_url of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットのURL</div> <div lang=\"en\">Url of page feed asset.</div>   # noqa: E501

        :return: The page_feed_asset_url of this PageFeedAsset.  # noqa: E501
        :rtype: str
        """
        return self._page_feed_asset_url

    @page_feed_asset_url.setter
    def page_feed_asset_url(self, page_feed_asset_url):
        """Sets the page_feed_asset_url of this PageFeedAsset.

        <div lang=\"ja\">ページフィードアセットのURL</div> <div lang=\"en\">Url of page feed asset.</div>   # noqa: E501

        :param page_feed_asset_url: The page_feed_asset_url of this PageFeedAsset.  # noqa: E501
        :type: str
        """

        self._page_feed_asset_url = page_feed_asset_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageFeedAsset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PageFeedAsset):
            return True

        return self.to_dict() != other.to_dict()
