# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class RetargetingListServiceRuleItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'custom_key_rule_item': 'RetargetingListServiceCustomKeyRuleItem',
        'rule_operator': 'RetargetingListServiceRuleOperator',
        'rule_type': 'RetargetingListServiceRuleType',
        'url_rule_item': 'RetargetingListServiceUrlRuleItem',
        'value': 'str'
    }

    attribute_map = {
        'custom_key_rule_item': 'customKeyRuleItem',
        'rule_operator': 'ruleOperator',
        'rule_type': 'ruleType',
        'url_rule_item': 'urlRuleItem',
        'value': 'value'
    }

    def __init__(self, custom_key_rule_item=None, rule_operator=None, rule_type=None, url_rule_item=None, value=None, local_vars_configuration=None):  # noqa: E501
        """RetargetingListServiceRuleItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._custom_key_rule_item = None
        self._rule_operator = None
        self._rule_type = None
        self._url_rule_item = None
        self._value = None
        self.discriminator = None

        self.custom_key_rule_item = custom_key_rule_item
        self.rule_operator = rule_operator
        self.rule_type = rule_type
        self.url_rule_item = url_rule_item
        self.value = value

    @property
    def custom_key_rule_item(self):
        """Gets the custom_key_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501


        :return: The custom_key_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: RetargetingListServiceCustomKeyRuleItem
        """
        return self._custom_key_rule_item

    @custom_key_rule_item.setter
    def custom_key_rule_item(self, custom_key_rule_item):
        """Sets the custom_key_rule_item of this RetargetingListServiceRuleItem.


        :param custom_key_rule_item: The custom_key_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: RetargetingListServiceCustomKeyRuleItem
        """

        self._custom_key_rule_item = custom_key_rule_item

    @property
    def rule_operator(self):
        """Gets the rule_operator of this RetargetingListServiceRuleItem.  # noqa: E501


        :return: The rule_operator of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: RetargetingListServiceRuleOperator
        """
        return self._rule_operator

    @rule_operator.setter
    def rule_operator(self, rule_operator):
        """Sets the rule_operator of this RetargetingListServiceRuleItem.


        :param rule_operator: The rule_operator of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: RetargetingListServiceRuleOperator
        """

        self._rule_operator = rule_operator

    @property
    def rule_type(self):
        """Gets the rule_type of this RetargetingListServiceRuleItem.  # noqa: E501


        :return: The rule_type of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: RetargetingListServiceRuleType
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """Sets the rule_type of this RetargetingListServiceRuleItem.


        :param rule_type: The rule_type of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: RetargetingListServiceRuleType
        """

        self._rule_type = rule_type

    @property
    def url_rule_item(self):
        """Gets the url_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501


        :return: The url_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: RetargetingListServiceUrlRuleItem
        """
        return self._url_rule_item

    @url_rule_item.setter
    def url_rule_item(self, url_rule_item):
        """Sets the url_rule_item of this RetargetingListServiceRuleItem.


        :param url_rule_item: The url_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: RetargetingListServiceUrlRuleItem
        """

        self._url_rule_item = url_rule_item

    @property
    def value(self):
        """Gets the value of this RetargetingListServiceRuleItem.  # noqa: E501

        <div lang=\"ja\">評価値です。<br> ADDおよびSET時、このフィールドは必須となります。<br> ※括弧（()）、シングルクォート（&#39;）、ダブルクォート（&#34;）、タブ（\\t）は利用できません。<br> ※250文字まで指定可能です。</div> <div lang=\"en\">Evaluation value.<br> *Cannot use: bracket, single quote, double quote, and tab.<br> *Can select up to 250 characters.<br> This field is required in ADD and SET operation.</div>   # noqa: E501

        :return: The value of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this RetargetingListServiceRuleItem.

        <div lang=\"ja\">評価値です。<br> ADDおよびSET時、このフィールドは必須となります。<br> ※括弧（()）、シングルクォート（&#39;）、ダブルクォート（&#34;）、タブ（\\t）は利用できません。<br> ※250文字まで指定可能です。</div> <div lang=\"en\">Evaluation value.<br> *Cannot use: bracket, single quote, double quote, and tab.<br> *Can select up to 250 characters.<br> This field is required in ADD and SET operation.</div>   # noqa: E501

        :param value: The value of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetargetingListServiceRuleItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RetargetingListServiceRuleItem):
            return True

        return self.to_dict() != other.to_dict()
