# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class Asset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'asset_id': 'int',
        'asset_track_id': 'int',
        'asset_data': 'AssetServiceAssetData',
        'approval_status': 'AssetServiceApprovalStatus',
        'disapproval_reason_codes': 'list[str]',
        'invalided_trademarks': 'list[str]',
        'trademark_status': 'AssetServiceTrademarkStatus',
        'custom_parameters': 'AssetServiceCustomParameters',
        'review_custom_parameters': 'AssetServiceCustomParameters',
        'smartphone_final_url': 'str',
        'review_smartphone_final_url': 'str',
        'final_url': 'str',
        'review_final_url': 'str',
        'tracking_url': 'str',
        'review_tracking_url': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'asset_id': 'assetId',
        'asset_track_id': 'assetTrackId',
        'asset_data': 'assetData',
        'approval_status': 'approvalStatus',
        'disapproval_reason_codes': 'disapprovalReasonCodes',
        'invalided_trademarks': 'invalidedTrademarks',
        'trademark_status': 'trademarkStatus',
        'custom_parameters': 'customParameters',
        'review_custom_parameters': 'reviewCustomParameters',
        'smartphone_final_url': 'smartphoneFinalUrl',
        'review_smartphone_final_url': 'reviewSmartphoneFinalUrl',
        'final_url': 'finalUrl',
        'review_final_url': 'reviewFinalUrl',
        'tracking_url': 'trackingUrl',
        'review_tracking_url': 'reviewTrackingUrl'
    }

    def __init__(self, account_id=None, asset_id=None, asset_track_id=None, asset_data=None, approval_status=None, disapproval_reason_codes=None, invalided_trademarks=None, trademark_status=None, custom_parameters=None, review_custom_parameters=None, smartphone_final_url=None, review_smartphone_final_url=None, final_url=None, review_final_url=None, tracking_url=None, review_tracking_url=None, local_vars_configuration=None):  # noqa: E501
        """Asset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._asset_id = None
        self._asset_track_id = None
        self._asset_data = None
        self._approval_status = None
        self._disapproval_reason_codes = None
        self._invalided_trademarks = None
        self._trademark_status = None
        self._custom_parameters = None
        self._review_custom_parameters = None
        self._smartphone_final_url = None
        self._review_smartphone_final_url = None
        self._final_url = None
        self._review_final_url = None
        self._tracking_url = None
        self._review_tracking_url = None
        self.discriminator = None

        self.account_id = account_id
        self.asset_id = asset_id
        self.asset_track_id = asset_track_id
        self.asset_data = asset_data
        self.approval_status = approval_status
        self.disapproval_reason_codes = disapproval_reason_codes
        self.invalided_trademarks = invalided_trademarks
        self.trademark_status = trademark_status
        self.custom_parameters = custom_parameters
        self.review_custom_parameters = review_custom_parameters
        self.smartphone_final_url = smartphone_final_url
        self.review_smartphone_final_url = review_smartphone_final_url
        self.final_url = final_url
        self.review_final_url = review_final_url
        self.tracking_url = tracking_url
        self.review_tracking_url = review_tracking_url

    @property
    def account_id(self):
        """Gets the account_id of this Asset.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The account_id of this Asset.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Asset.

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param account_id: The account_id of this Asset.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def asset_id(self):
        """Gets the asset_id of this Asset.  # noqa: E501

        <div lang=\"ja\">アセットIDです。<br> このフィールドは、SETおよびREMOVE時に必須となり、ADD時に無視されます。</div> <div lang=\"en\">Asset ID.<br>This field is required in SET and REMOVE operation, and will be ignored in ADD operation.</div>   # noqa: E501

        :return: The asset_id of this Asset.  # noqa: E501
        :rtype: int
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this Asset.

        <div lang=\"ja\">アセットIDです。<br> このフィールドは、SETおよびREMOVE時に必須となり、ADD時に無視されます。</div> <div lang=\"en\">Asset ID.<br>This field is required in SET and REMOVE operation, and will be ignored in ADD operation.</div>   # noqa: E501

        :param asset_id: The asset_id of this Asset.  # noqa: E501
        :type: int
        """

        self._asset_id = asset_id

    @property
    def asset_track_id(self):
        """Gets the asset_track_id of this Asset.  # noqa: E501

        <div lang=\"ja\">トラッキング用アセットIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Asset ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The asset_track_id of this Asset.  # noqa: E501
        :rtype: int
        """
        return self._asset_track_id

    @asset_track_id.setter
    def asset_track_id(self, asset_track_id):
        """Sets the asset_track_id of this Asset.

        <div lang=\"ja\">トラッキング用アセットIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Asset ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param asset_track_id: The asset_track_id of this Asset.  # noqa: E501
        :type: int
        """

        self._asset_track_id = asset_track_id

    @property
    def asset_data(self):
        """Gets the asset_data of this Asset.  # noqa: E501


        :return: The asset_data of this Asset.  # noqa: E501
        :rtype: AssetServiceAssetData
        """
        return self._asset_data

    @asset_data.setter
    def asset_data(self, asset_data):
        """Sets the asset_data of this Asset.


        :param asset_data: The asset_data of this Asset.  # noqa: E501
        :type: AssetServiceAssetData
        """

        self._asset_data = asset_data

    @property
    def approval_status(self):
        """Gets the approval_status of this Asset.  # noqa: E501


        :return: The approval_status of this Asset.  # noqa: E501
        :rtype: AssetServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this Asset.


        :param approval_status: The approval_status of this Asset.  # noqa: E501
        :type: AssetServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this Asset.  # noqa: E501

        <div lang=\"ja\">審査否認理由です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Reject reason on editorial review.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The disapproval_reason_codes of this Asset.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this Asset.

        <div lang=\"ja\">審査否認理由です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Reject reason on editorial review.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this Asset.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    @property
    def invalided_trademarks(self):
        """Gets the invalided_trademarks of this Asset.  # noqa: E501

        <div lang=\"ja\">制限された商標です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\">Invalided trademarks.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The invalided_trademarks of this Asset.  # noqa: E501
        :rtype: list[str]
        """
        return self._invalided_trademarks

    @invalided_trademarks.setter
    def invalided_trademarks(self, invalided_trademarks):
        """Sets the invalided_trademarks of this Asset.

        <div lang=\"ja\">制限された商標です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\">Invalided trademarks.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param invalided_trademarks: The invalided_trademarks of this Asset.  # noqa: E501
        :type: list[str]
        """

        self._invalided_trademarks = invalided_trademarks

    @property
    def trademark_status(self):
        """Gets the trademark_status of this Asset.  # noqa: E501


        :return: The trademark_status of this Asset.  # noqa: E501
        :rtype: AssetServiceTrademarkStatus
        """
        return self._trademark_status

    @trademark_status.setter
    def trademark_status(self, trademark_status):
        """Sets the trademark_status of this Asset.


        :param trademark_status: The trademark_status of this Asset.  # noqa: E501
        :type: AssetServiceTrademarkStatus
        """

        self._trademark_status = trademark_status

    @property
    def custom_parameters(self):
        """Gets the custom_parameters of this Asset.  # noqa: E501


        :return: The custom_parameters of this Asset.  # noqa: E501
        :rtype: AssetServiceCustomParameters
        """
        return self._custom_parameters

    @custom_parameters.setter
    def custom_parameters(self, custom_parameters):
        """Sets the custom_parameters of this Asset.


        :param custom_parameters: The custom_parameters of this Asset.  # noqa: E501
        :type: AssetServiceCustomParameters
        """

        self._custom_parameters = custom_parameters

    @property
    def review_custom_parameters(self):
        """Gets the review_custom_parameters of this Asset.  # noqa: E501


        :return: The review_custom_parameters of this Asset.  # noqa: E501
        :rtype: AssetServiceCustomParameters
        """
        return self._review_custom_parameters

    @review_custom_parameters.setter
    def review_custom_parameters(self, review_custom_parameters):
        """Sets the review_custom_parameters of this Asset.


        :param review_custom_parameters: The review_custom_parameters of this Asset.  # noqa: E501
        :type: AssetServiceCustomParameters
        """

        self._review_custom_parameters = review_custom_parameters

    @property
    def smartphone_final_url(self):
        """Gets the smartphone_final_url of this Asset.  # noqa: E501

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADDおよびSET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Landing page URL (Smartphone).<br> This field is optional in ADD and SET operation.</div>   # noqa: E501

        :return: The smartphone_final_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._smartphone_final_url

    @smartphone_final_url.setter
    def smartphone_final_url(self, smartphone_final_url):
        """Sets the smartphone_final_url of this Asset.

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADDおよびSET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Landing page URL (Smartphone).<br> This field is optional in ADD and SET operation.</div>   # noqa: E501

        :param smartphone_final_url: The smartphone_final_url of this Asset.  # noqa: E501
        :type: str
        """

        self._smartphone_final_url = smartphone_final_url

    @property
    def review_smartphone_final_url(self):
        """Gets the review_smartphone_final_url of this Asset.  # noqa: E501

        <div lang=\"ja\">審査中の最終リンク先URL（スマートフォン）です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL (Smartphone) on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_smartphone_final_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._review_smartphone_final_url

    @review_smartphone_final_url.setter
    def review_smartphone_final_url(self, review_smartphone_final_url):
        """Sets the review_smartphone_final_url of this Asset.

        <div lang=\"ja\">審査中の最終リンク先URL（スマートフォン）です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL (Smartphone) on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_smartphone_final_url: The review_smartphone_final_url of this Asset.  # noqa: E501
        :type: str
        """

        self._review_smartphone_final_url = review_smartphone_final_url

    @property
    def final_url(self):
        """Gets the final_url of this Asset.  # noqa: E501

        <div lang=\"ja\">最終リンク先URLです。<br> ADDおよびSET時、assetData.typeがQUICKLINKの場合は必須です。<br> assetData.typeがQUICKLINK以外の場合、リクエストの際に無視されます。</div> <div lang=\"en\">Landing page URL.<br> This field is optional in ADD and SET operation.<br> In ADD and SET operation, If assetData.type is QUICKLINK, this field is required.<br> And will be ignored when assetData.type is the others.</div>   # noqa: E501

        :return: The final_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._final_url

    @final_url.setter
    def final_url(self, final_url):
        """Sets the final_url of this Asset.

        <div lang=\"ja\">最終リンク先URLです。<br> ADDおよびSET時、assetData.typeがQUICKLINKの場合は必須です。<br> assetData.typeがQUICKLINK以外の場合、リクエストの際に無視されます。</div> <div lang=\"en\">Landing page URL.<br> This field is optional in ADD and SET operation.<br> In ADD and SET operation, If assetData.type is QUICKLINK, this field is required.<br> And will be ignored when assetData.type is the others.</div>   # noqa: E501

        :param final_url: The final_url of this Asset.  # noqa: E501
        :type: str
        """

        self._final_url = final_url

    @property
    def review_final_url(self):
        """Gets the review_final_url of this Asset.  # noqa: E501

        <div lang=\"ja\">審査中の最終リンク先URLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_final_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._review_final_url

    @review_final_url.setter
    def review_final_url(self, review_final_url):
        """Sets the review_final_url of this Asset.

        <div lang=\"ja\">審査中の最終リンク先URLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_final_url: The review_final_url of this Asset.  # noqa: E501
        :type: str
        """

        self._review_final_url = review_final_url

    @property
    def tracking_url(self):
        """Gets the tracking_url of this Asset.  # noqa: E501

        <div lang=\"ja\">トラッキングURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.</div>   # noqa: E501

        :return: The tracking_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._tracking_url

    @tracking_url.setter
    def tracking_url(self, tracking_url):
        """Sets the tracking_url of this Asset.

        <div lang=\"ja\">トラッキングURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.</div>   # noqa: E501

        :param tracking_url: The tracking_url of this Asset.  # noqa: E501
        :type: str
        """

        self._tracking_url = tracking_url

    @property
    def review_tracking_url(self):
        """Gets the review_tracking_url of this Asset.  # noqa: E501

        <div lang=\"ja\">審査中のトラッキングURLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Tracking URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_tracking_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._review_tracking_url

    @review_tracking_url.setter
    def review_tracking_url(self, review_tracking_url):
        """Sets the review_tracking_url of this Asset.

        <div lang=\"ja\">審査中のトラッキングURLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Tracking URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_tracking_url: The review_tracking_url of this Asset.  # noqa: E501
        :type: str
        """

        self._review_tracking_url = review_tracking_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Asset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Asset):
            return True

        return self.to_dict() != other.to_dict()
