# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class PageFeedAssetSetServicePage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'total_num_entries': 'int',
        'values': 'list[PageFeedAssetSetServiceValue]'
    }

    attribute_map = {
        'total_num_entries': 'totalNumEntries',
        'values': 'values'
    }

    def __init__(self, total_num_entries=None, values=None, local_vars_configuration=None):  # noqa: E501
        """PageFeedAssetSetServicePage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._total_num_entries = None
        self._values = None
        self.discriminator = None

        if total_num_entries is not None:
            self.total_num_entries = total_num_entries
        self.values = values

    @property
    def total_num_entries(self):
        """Gets the total_num_entries of this PageFeedAssetSetServicePage.  # noqa: E501

        <div lang=\"ja\">取得される項目の総件数です。</div> <div lang=\"en\">Total number of entries in the result that this page is a part of.</div>   # noqa: E501

        :return: The total_num_entries of this PageFeedAssetSetServicePage.  # noqa: E501
        :rtype: int
        """
        return self._total_num_entries

    @total_num_entries.setter
    def total_num_entries(self, total_num_entries):
        """Sets the total_num_entries of this PageFeedAssetSetServicePage.

        <div lang=\"ja\">取得される項目の総件数です。</div> <div lang=\"en\">Total number of entries in the result that this page is a part of.</div>   # noqa: E501

        :param total_num_entries: The total_num_entries of this PageFeedAssetSetServicePage.  # noqa: E501
        :type: int
        """

        self._total_num_entries = total_num_entries

    @property
    def values(self):
        """Gets the values of this PageFeedAssetSetServicePage.  # noqa: E501


        :return: The values of this PageFeedAssetSetServicePage.  # noqa: E501
        :rtype: list[PageFeedAssetSetServiceValue]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this PageFeedAssetSetServicePage.


        :param values: The values of this PageFeedAssetSetServicePage.  # noqa: E501
        :type: list[PageFeedAssetSetServiceValue]
        """

        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageFeedAssetSetServicePage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PageFeedAssetSetServicePage):
            return True

        return self.to_dict() != other.to_dict()
