# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'text': 'str',
        'match_type': 'KeywordForecastMetricsServiceMatchType',
        'cpc': 'int',
        'is_negative': 'bool'
    }

    attribute_map = {
        'text': 'text',
        'match_type': 'matchType',
        'cpc': 'cpc',
        'is_negative': 'isNegative'
    }

    def __init__(self, text=None, match_type=None, cpc=None, is_negative=None, local_vars_configuration=None):  # noqa: E501
        """KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._text = None
        self._match_type = None
        self._cpc = None
        self._is_negative = None
        self.discriminator = None

        self.text = text
        self.match_type = match_type
        self.cpc = cpc
        self.is_negative = is_negative

    @property
    def text(self):
        """Gets the text of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501

        <div lang=\"ja\">キーワードです。</div> <div lang=\"en\">Keyword.</div>   # noqa: E501

        :return: The text of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.

        <div lang=\"ja\">キーワードです。</div> <div lang=\"en\">Keyword.</div>   # noqa: E501

        :param text: The text of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def match_type(self):
        """Gets the match_type of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501


        :return: The match_type of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :rtype: KeywordForecastMetricsServiceMatchType
        """
        return self._match_type

    @match_type.setter
    def match_type(self, match_type):
        """Sets the match_type of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.


        :param match_type: The match_type of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :type: KeywordForecastMetricsServiceMatchType
        """

        self._match_type = match_type

    @property
    def cpc(self):
        """Gets the cpc of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501

        <div lang=\"ja\">最大クリック単価です。<br> isNegativeがTRUEのときにcpcを指定することはできません。</div> <div lang=\"en\">Maximum CPC.<br> When isNegative is TRUE, CPC cannot be specified.</div>   # noqa: E501

        :return: The cpc of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :rtype: int
        """
        return self._cpc

    @cpc.setter
    def cpc(self, cpc):
        """Sets the cpc of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.

        <div lang=\"ja\">最大クリック単価です。<br> isNegativeがTRUEのときにcpcを指定することはできません。</div> <div lang=\"en\">Maximum CPC.<br> When isNegative is TRUE, CPC cannot be specified.</div>   # noqa: E501

        :param cpc: The cpc of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :type: int
        """

        self._cpc = cpc

    @property
    def is_negative(self):
        """Gets the is_negative of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501

        <div lang=\"ja\">除外キーワードです。<br> デフォルト値はfalseです。<br> 除外キーワードのみでのリクエストはできません。</div> <div lang=\"en\">Refine keyword.<br> The default value will be FALSE.<br> Cannot request with only refine keyword.</div>   # noqa: E501

        :return: The is_negative of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :rtype: bool
        """
        return self._is_negative

    @is_negative.setter
    def is_negative(self, is_negative):
        """Sets the is_negative of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.

        <div lang=\"ja\">除外キーワードです。<br> デフォルト値はfalseです。<br> 除外キーワードのみでのリクエストはできません。</div> <div lang=\"en\">Refine keyword.<br> The default value will be FALSE.<br> Cannot request with only refine keyword.</div>   # noqa: E501

        :param is_negative: The is_negative of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :type: bool
        """

        self._is_negative = is_negative

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword):
            return True

        return self.to_dict() != other.to_dict()
