# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class ConversionTrackerServiceSelector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'app_ids': 'list[str]',
        'categories': 'list[ConversionTrackerServiceCategory]',
        'conversion_counting_types': 'list[ConversionTrackerServiceConversionCountingType]',
        'conversion_date_range': 'ConversionTrackerServiceConversionDateRange',
        'conversion_tracker_ids': 'list[int]',
        'conversion_tracker_types': 'list[ConversionTrackerServiceConversionTrackerType]',
        'exclude_from_biddings': 'list[ConversionTrackerServiceExcludeFromBidding]',
        'number_results': 'int',
        'start_index': 'int',
        'statuses': 'list[ConversionTrackerServiceStatus]',
        'tracking_code_types': 'list[ConversionTrackerServiceTrackingCodeType]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'app_ids': 'appIds',
        'categories': 'categories',
        'conversion_counting_types': 'conversionCountingTypes',
        'conversion_date_range': 'conversionDateRange',
        'conversion_tracker_ids': 'conversionTrackerIds',
        'conversion_tracker_types': 'conversionTrackerTypes',
        'exclude_from_biddings': 'excludeFromBiddings',
        'number_results': 'numberResults',
        'start_index': 'startIndex',
        'statuses': 'statuses',
        'tracking_code_types': 'trackingCodeTypes'
    }

    def __init__(self, account_id=None, app_ids=None, categories=None, conversion_counting_types=None, conversion_date_range=None, conversion_tracker_ids=None, conversion_tracker_types=None, exclude_from_biddings=None, number_results=500, start_index=1, statuses=None, tracking_code_types=None, local_vars_configuration=None):  # noqa: E501
        """ConversionTrackerServiceSelector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._app_ids = None
        self._categories = None
        self._conversion_counting_types = None
        self._conversion_date_range = None
        self._conversion_tracker_ids = None
        self._conversion_tracker_types = None
        self._exclude_from_biddings = None
        self._number_results = None
        self._start_index = None
        self._statuses = None
        self._tracking_code_types = None
        self.discriminator = None

        self.account_id = account_id
        self.app_ids = app_ids
        self.categories = categories
        self.conversion_counting_types = conversion_counting_types
        self.conversion_date_range = conversion_date_range
        self.conversion_tracker_ids = conversion_tracker_ids
        self.conversion_tracker_types = conversion_tracker_types
        self.exclude_from_biddings = exclude_from_biddings
        self.number_results = number_results
        self.start_index = start_index
        self.statuses = statuses
        self.tracking_code_types = tracking_code_types

    @property
    def account_id(self):
        """Gets the account_id of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def app_ids(self):
        """Gets the app_ids of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">アプリケーションIDです。</div> <div lang=\"en\">App ID.</div>   # noqa: E501

        :return: The app_ids of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[str]
        """
        return self._app_ids

    @app_ids.setter
    def app_ids(self, app_ids):
        """Sets the app_ids of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">アプリケーションIDです。</div> <div lang=\"en\">App ID.</div>   # noqa: E501

        :param app_ids: The app_ids of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[str]
        """

        self._app_ids = app_ids

    @property
    def categories(self):
        """Gets the categories of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The categories of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceCategory]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this ConversionTrackerServiceSelector.


        :param categories: The categories of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceCategory]
        """

        self._categories = categories

    @property
    def conversion_counting_types(self):
        """Gets the conversion_counting_types of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The conversion_counting_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceConversionCountingType]
        """
        return self._conversion_counting_types

    @conversion_counting_types.setter
    def conversion_counting_types(self, conversion_counting_types):
        """Sets the conversion_counting_types of this ConversionTrackerServiceSelector.


        :param conversion_counting_types: The conversion_counting_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceConversionCountingType]
        """

        self._conversion_counting_types = conversion_counting_types

    @property
    def conversion_date_range(self):
        """Gets the conversion_date_range of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The conversion_date_range of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: ConversionTrackerServiceConversionDateRange
        """
        return self._conversion_date_range

    @conversion_date_range.setter
    def conversion_date_range(self, conversion_date_range):
        """Sets the conversion_date_range of this ConversionTrackerServiceSelector.


        :param conversion_date_range: The conversion_date_range of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: ConversionTrackerServiceConversionDateRange
        """

        self._conversion_date_range = conversion_date_range

    @property
    def conversion_tracker_ids(self):
        """Gets the conversion_tracker_ids of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">コンバージョントラッカーIDです。</div> <div lang=\"en\">Conversion Tracker ID.</div>   # noqa: E501

        :return: The conversion_tracker_ids of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[int]
        """
        return self._conversion_tracker_ids

    @conversion_tracker_ids.setter
    def conversion_tracker_ids(self, conversion_tracker_ids):
        """Sets the conversion_tracker_ids of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">コンバージョントラッカーIDです。</div> <div lang=\"en\">Conversion Tracker ID.</div>   # noqa: E501

        :param conversion_tracker_ids: The conversion_tracker_ids of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[int]
        """

        self._conversion_tracker_ids = conversion_tracker_ids

    @property
    def conversion_tracker_types(self):
        """Gets the conversion_tracker_types of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The conversion_tracker_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceConversionTrackerType]
        """
        return self._conversion_tracker_types

    @conversion_tracker_types.setter
    def conversion_tracker_types(self, conversion_tracker_types):
        """Sets the conversion_tracker_types of this ConversionTrackerServiceSelector.


        :param conversion_tracker_types: The conversion_tracker_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceConversionTrackerType]
        """

        self._conversion_tracker_types = conversion_tracker_types

    @property
    def exclude_from_biddings(self):
        """Gets the exclude_from_biddings of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The exclude_from_biddings of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceExcludeFromBidding]
        """
        return self._exclude_from_biddings

    @exclude_from_biddings.setter
    def exclude_from_biddings(self, exclude_from_biddings):
        """Sets the exclude_from_biddings of this ConversionTrackerServiceSelector.


        :param exclude_from_biddings: The exclude_from_biddings of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceExcludeFromBidding]
        """

        self._exclude_from_biddings = exclude_from_biddings

    @property
    def number_results(self):
        """Gets the number_results of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">ページの最大件数です。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Maximum number of results to return in this page. This field must be greater than or equal to 1. Also see Entity Limits per operation.</div>   # noqa: E501

        :return: The number_results of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._number_results

    @number_results.setter
    def number_results(self, number_results):
        """Sets the number_results of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">ページの最大件数です。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Maximum number of results to return in this page. This field must be greater than or equal to 1. Also see Entity Limits per operation.</div>   # noqa: E501

        :param number_results: The number_results of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                number_results is not None and number_results > 500):  # noqa: E501
            raise ValueError("Invalid value for `number_results`, must be a value less than or equal to `500`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                number_results is not None and number_results < 1):  # noqa: E501
            raise ValueError("Invalid value for `number_results`, must be a value greater than or equal to `1`")  # noqa: E501

        self._number_results = number_results

    @property
    def start_index(self):
        """Gets the start_index of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">ページの先頭のインデックスです。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Index of the first result to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :return: The start_index of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """Sets the start_index of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">ページの先頭のインデックスです。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Index of the first result to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :param start_index: The start_index of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                start_index is not None and start_index < 1):  # noqa: E501
            raise ValueError("Invalid value for `start_index`, must be a value greater than or equal to `1`")  # noqa: E501

        self._start_index = start_index

    @property
    def statuses(self):
        """Gets the statuses of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The statuses of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceStatus]
        """
        return self._statuses

    @statuses.setter
    def statuses(self, statuses):
        """Sets the statuses of this ConversionTrackerServiceSelector.


        :param statuses: The statuses of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceStatus]
        """

        self._statuses = statuses

    @property
    def tracking_code_types(self):
        """Gets the tracking_code_types of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The tracking_code_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceTrackingCodeType]
        """
        return self._tracking_code_types

    @tracking_code_types.setter
    def tracking_code_types(self, tracking_code_types):
        """Sets the tracking_code_types of this ConversionTrackerServiceSelector.


        :param tracking_code_types: The tracking_code_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceTrackingCodeType]
        """

        self._tracking_code_types = tracking_code_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConversionTrackerServiceSelector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConversionTrackerServiceSelector):
            return True

        return self.to_dict() != other.to_dict()
