# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AuditLogServiceEventSelector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'entity_type': 'str',
        'event_types': 'list[AuditLogServiceEventTypes]'
    }

    attribute_map = {
        'entity_type': 'entityType',
        'event_types': 'eventTypes'
    }

    def __init__(self, entity_type=None, event_types=None, local_vars_configuration=None):  # noqa: E501
        """AuditLogServiceEventSelector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._entity_type = None
        self._event_types = None
        self.discriminator = None

        self.entity_type = entity_type
        self.event_types = event_types

    @property
    def entity_type(self):
        """Gets the entity_type of this AuditLogServiceEventSelector.  # noqa: E501

        <div lang=\"ja\">AuditLogServiceEntityTypeオブジェクトは、操作履歴に出力するエンティティの種類を表します。</div> <div lang=\"en\">AuditLogServiceEntityType object describes the type of entities to be output on the data of operation history.</div> <dl class=term>   <dt class=\"term__item\">CAMPAIGN</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンです。</span><span lang=\"en\">Campaign.</span></dd>   <dt class=\"term__item\">NEGATIVE_CAMPAIGN_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外キーワードです（キャンペーン）。</span><span lang=\"en\">Negative keywords (for campaign).</span></dd>   <dt class=\"term__item\">CAMPAIGN_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンのターゲティング設定です。</span><span lang=\"en\">Targeting setting on campaign.</span></dd>   <dt class=\"term__item\">AD_GROUP</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループです。</span><span lang=\"en\">Ad group.</span></dd>   <dt class=\"term__item\">AD_GROUP_BID_MULTIPLIER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループ入札価格調整率です。</span><span lang=\"en\">Bid adjustment for ad group.</span></dd>   <dt class=\"term__item\">BIDDABLE_AD_GROUP_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">入札キーワードです。</span><span lang=\"en\">Bidding keyword.</span></dd>   <dt class=\"term__item\">NEGATIVE_AD_GROUP_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外キーワードです（広告グループ）。</span><span lang=\"en\">Negative keywords (for ad group).</span></dd>   <dt class=\"term__item\">AD</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告です。</span><span lang=\"en\">Ad.</span></dd>   <dt class=\"term__item\">FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">Feedフォルダーです。</span><span lang=\"en\">Feed folder.</span></dd>   <dt class=\"term__item\">FEED_ITEM</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです。</span><span lang=\"en\">Ad display options.</span></dd>   <dt class=\"term__item\">CAMPAIGN_FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです（キャンペーン）。</span><span lang=\"en\">Ad display options for campaign.</span></dd>   <dt class=\"term__item\">AD_GROUP_FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです（広告グループ）。</span><span lang=\"en\">Ad display options for ad group.</span></dd>   <dt class=\"term__item\">SS_IO</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アカウントです。</span><span lang=\"en\">Account.</span></dd>   <dt class=\"term__item\">SS_CONVERSION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">コンバージョントラッカー（コンバージョン測定）です。</span><span lang=\"en\">Conversion tracker for conversion tracking.</span></dd>   <dt class=\"term__item\">BIDDING_STRATEGY</dt>   <dd class=\"term__desc\"><span lang=\"ja\">自動入札設定です。</span><span lang=\"en\">Auto bidding setting.</span></dd>   <dt class=\"term__item\">NEGATIVE_CAMPAIGN_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外ターゲットリストです（キャンペーン）。</span><span lang=\"en\">Exclude target list for campaign.</span></dd>   <dt class=\"term__item\">NEGATIVE_AD_GROUP_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外ターゲットリストです（広告グループ）。</span><span lang=\"en\">Exclude target list for ad group.</span></dd>   <dt class=\"term__item\">AD_GROUP_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ターゲットリストです（広告グループ）。</span><span lang=\"en\">Target list for ad group.</span></dd>   <dt class=\"term__item\">TARGET_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">サイトリターゲテイングのターゲットリストです。</span><span lang=\"en\">Target list of Site Retargeting.</span></dd>   <dt class=\"term__item\">SHARED_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">共有リストです。</span><span lang=\"en\">Shared list.</span></dd>   <dt class=\"term__item\">SHARED_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">共有キーワードです。</span><span lang=\"en\">Shared keywords.</span></dd>   <dt class=\"term__item\">CAMPAIGN_SHARED_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーン共有リストです。</span><span lang=\"en\">Shared list for campaign.</span></dd>   <dt class=\"term__item\">AD_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アドカスタマイザーです。</span><span lang=\"en\">Ad customizer.</span></dd>   <dt class=\"term__item\">EXCLUDE_AD_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アドカスタマイザーを除くすべての履歴です。</span><span lang=\"en\">All operation history excepting ad customizer.</span></dd>   <dt class=\"term__item\">ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アセット（広告表示オプション）です。</span><span lang=\"en\">Assets (Ad display option).</span></dd>   <dt class=\"term__item\">CAMPAIGN_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンとアセット間の設定情報です。</span><span lang=\"en\">Configuration information between campaign and assets.</span></dd>   <dt class=\"term__item\">AD_GROUP_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループとアセット間の設定情報です。</span><span lang=\"en\">Configuration information between ad group and assets.</span></dd>   <dt class=\"term__item\">ACCOUNT_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アカウントとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between account and customizer attributes.</span></dd>   <dt class=\"term__item\">CAMPAIGN_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between campaign and customizer attributes.</span></dd>   <dt class=\"term__item\">AD_GROUP_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between ad group and customizer attributes.</span></dd>   <dt class=\"term__item\">AD_GROUP_CRITERION_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キーワードとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between keyword and customizer attributes.</span></dd>   <dt class=\"term__item\">CUSTOMIZER_ATTRIBUTE</dt>   <dd class=\"term__desc\"><span lang=\"ja\">カスタマイザー属性です。</span><span lang=\"en\">Customizer attributes.</span></dd>   <dt class=\"term__item\">PAGE_FEED_ASSET_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ページフィードアセットセットです。</span><span lang=\"en\">PageFeedAssetSet.</span></dd>   <dt class=\"term__item\">PAGE_FEED_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ページフィードアセットです。</span><span lang=\"en\">PageFeedAsset.</span></dd>   <dt class=\"term__item\">BIDDING_SEASONALITY_ADJUSTMENT</dt>   <dd class=\"term__desc\"><span lang=\"ja\">自動入札のスポット調整です。</span><span lang=\"en\">Bidding Seasonality Adjustment.</span></dd>   <dt class=\"term__item\">CAMPAIGN_BUDGET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーン間の共有予算です。<br>※現在、こちらのEnumは利用できません。</span><span lang=\"en\">Shared budgets.<br>*Currently this Enum is not available.</span></dd>   <dt class=\"term__item\">ALL</dt>   <dd class=\"term__desc\"><span lang=\"ja\">すべての履歴です。</span><span lang=\"en\">All operation history.</span></dd>   <dt class=\"term__item\">UNKNOWN</dt>   <dd class=\"term__desc\"><span lang=\"ja\">未知の値です。</span><span lang=\"en\">Unknown value.</span></dd> </dl>   # noqa: E501

        :return: The entity_type of this AuditLogServiceEventSelector.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this AuditLogServiceEventSelector.

        <div lang=\"ja\">AuditLogServiceEntityTypeオブジェクトは、操作履歴に出力するエンティティの種類を表します。</div> <div lang=\"en\">AuditLogServiceEntityType object describes the type of entities to be output on the data of operation history.</div> <dl class=term>   <dt class=\"term__item\">CAMPAIGN</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンです。</span><span lang=\"en\">Campaign.</span></dd>   <dt class=\"term__item\">NEGATIVE_CAMPAIGN_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外キーワードです（キャンペーン）。</span><span lang=\"en\">Negative keywords (for campaign).</span></dd>   <dt class=\"term__item\">CAMPAIGN_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンのターゲティング設定です。</span><span lang=\"en\">Targeting setting on campaign.</span></dd>   <dt class=\"term__item\">AD_GROUP</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループです。</span><span lang=\"en\">Ad group.</span></dd>   <dt class=\"term__item\">AD_GROUP_BID_MULTIPLIER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループ入札価格調整率です。</span><span lang=\"en\">Bid adjustment for ad group.</span></dd>   <dt class=\"term__item\">BIDDABLE_AD_GROUP_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">入札キーワードです。</span><span lang=\"en\">Bidding keyword.</span></dd>   <dt class=\"term__item\">NEGATIVE_AD_GROUP_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外キーワードです（広告グループ）。</span><span lang=\"en\">Negative keywords (for ad group).</span></dd>   <dt class=\"term__item\">AD</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告です。</span><span lang=\"en\">Ad.</span></dd>   <dt class=\"term__item\">FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">Feedフォルダーです。</span><span lang=\"en\">Feed folder.</span></dd>   <dt class=\"term__item\">FEED_ITEM</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです。</span><span lang=\"en\">Ad display options.</span></dd>   <dt class=\"term__item\">CAMPAIGN_FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです（キャンペーン）。</span><span lang=\"en\">Ad display options for campaign.</span></dd>   <dt class=\"term__item\">AD_GROUP_FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです（広告グループ）。</span><span lang=\"en\">Ad display options for ad group.</span></dd>   <dt class=\"term__item\">SS_IO</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アカウントです。</span><span lang=\"en\">Account.</span></dd>   <dt class=\"term__item\">SS_CONVERSION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">コンバージョントラッカー（コンバージョン測定）です。</span><span lang=\"en\">Conversion tracker for conversion tracking.</span></dd>   <dt class=\"term__item\">BIDDING_STRATEGY</dt>   <dd class=\"term__desc\"><span lang=\"ja\">自動入札設定です。</span><span lang=\"en\">Auto bidding setting.</span></dd>   <dt class=\"term__item\">NEGATIVE_CAMPAIGN_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外ターゲットリストです（キャンペーン）。</span><span lang=\"en\">Exclude target list for campaign.</span></dd>   <dt class=\"term__item\">NEGATIVE_AD_GROUP_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外ターゲットリストです（広告グループ）。</span><span lang=\"en\">Exclude target list for ad group.</span></dd>   <dt class=\"term__item\">AD_GROUP_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ターゲットリストです（広告グループ）。</span><span lang=\"en\">Target list for ad group.</span></dd>   <dt class=\"term__item\">TARGET_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">サイトリターゲテイングのターゲットリストです。</span><span lang=\"en\">Target list of Site Retargeting.</span></dd>   <dt class=\"term__item\">SHARED_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">共有リストです。</span><span lang=\"en\">Shared list.</span></dd>   <dt class=\"term__item\">SHARED_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">共有キーワードです。</span><span lang=\"en\">Shared keywords.</span></dd>   <dt class=\"term__item\">CAMPAIGN_SHARED_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーン共有リストです。</span><span lang=\"en\">Shared list for campaign.</span></dd>   <dt class=\"term__item\">AD_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アドカスタマイザーです。</span><span lang=\"en\">Ad customizer.</span></dd>   <dt class=\"term__item\">EXCLUDE_AD_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アドカスタマイザーを除くすべての履歴です。</span><span lang=\"en\">All operation history excepting ad customizer.</span></dd>   <dt class=\"term__item\">ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アセット（広告表示オプション）です。</span><span lang=\"en\">Assets (Ad display option).</span></dd>   <dt class=\"term__item\">CAMPAIGN_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンとアセット間の設定情報です。</span><span lang=\"en\">Configuration information between campaign and assets.</span></dd>   <dt class=\"term__item\">AD_GROUP_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループとアセット間の設定情報です。</span><span lang=\"en\">Configuration information between ad group and assets.</span></dd>   <dt class=\"term__item\">ACCOUNT_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アカウントとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between account and customizer attributes.</span></dd>   <dt class=\"term__item\">CAMPAIGN_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between campaign and customizer attributes.</span></dd>   <dt class=\"term__item\">AD_GROUP_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between ad group and customizer attributes.</span></dd>   <dt class=\"term__item\">AD_GROUP_CRITERION_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キーワードとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between keyword and customizer attributes.</span></dd>   <dt class=\"term__item\">CUSTOMIZER_ATTRIBUTE</dt>   <dd class=\"term__desc\"><span lang=\"ja\">カスタマイザー属性です。</span><span lang=\"en\">Customizer attributes.</span></dd>   <dt class=\"term__item\">PAGE_FEED_ASSET_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ページフィードアセットセットです。</span><span lang=\"en\">PageFeedAssetSet.</span></dd>   <dt class=\"term__item\">PAGE_FEED_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ページフィードアセットです。</span><span lang=\"en\">PageFeedAsset.</span></dd>   <dt class=\"term__item\">BIDDING_SEASONALITY_ADJUSTMENT</dt>   <dd class=\"term__desc\"><span lang=\"ja\">自動入札のスポット調整です。</span><span lang=\"en\">Bidding Seasonality Adjustment.</span></dd>   <dt class=\"term__item\">CAMPAIGN_BUDGET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーン間の共有予算です。<br>※現在、こちらのEnumは利用できません。</span><span lang=\"en\">Shared budgets.<br>*Currently this Enum is not available.</span></dd>   <dt class=\"term__item\">ALL</dt>   <dd class=\"term__desc\"><span lang=\"ja\">すべての履歴です。</span><span lang=\"en\">All operation history.</span></dd>   <dt class=\"term__item\">UNKNOWN</dt>   <dd class=\"term__desc\"><span lang=\"ja\">未知の値です。</span><span lang=\"en\">Unknown value.</span></dd> </dl>   # noqa: E501

        :param entity_type: The entity_type of this AuditLogServiceEventSelector.  # noqa: E501
        :type: str
        """

        self._entity_type = entity_type

    @property
    def event_types(self):
        """Gets the event_types of this AuditLogServiceEventSelector.  # noqa: E501


        :return: The event_types of this AuditLogServiceEventSelector.  # noqa: E501
        :rtype: list[AuditLogServiceEventTypes]
        """
        return self._event_types

    @event_types.setter
    def event_types(self, event_types):
        """Sets the event_types of this AuditLogServiceEventSelector.


        :param event_types: The event_types of this AuditLogServiceEventSelector.  # noqa: E501
        :type: list[AuditLogServiceEventTypes]
        """

        self._event_types = event_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogServiceEventSelector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLogServiceEventSelector):
            return True

        return self.to_dict() != other.to_dict()
