# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AssetServiceQuickLinkAsset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'link_text': 'str',
        'review_link_text': 'str',
        'description1': 'str',
        'review_description1': 'str',
        'description2': 'str',
        'review_description2': 'str',
        'start_date': 'str',
        'end_date': 'str',
        'schedules': 'list[AssetServiceSchedule]'
    }

    attribute_map = {
        'link_text': 'linkText',
        'review_link_text': 'reviewLinkText',
        'description1': 'description1',
        'review_description1': 'reviewDescription1',
        'description2': 'description2',
        'review_description2': 'reviewDescription2',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'schedules': 'schedules'
    }

    def __init__(self, link_text=None, review_link_text=None, description1=None, review_description1=None, description2=None, review_description2=None, start_date=None, end_date=None, schedules=None, local_vars_configuration=None):  # noqa: E501
        """AssetServiceQuickLinkAsset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._link_text = None
        self._review_link_text = None
        self._description1 = None
        self._review_description1 = None
        self._description2 = None
        self._review_description2 = None
        self._start_date = None
        self._end_date = None
        self._schedules = None
        self.discriminator = None

        self.link_text = link_text
        self.review_link_text = review_link_text
        self.description1 = description1
        self.review_description1 = review_description1
        self.description2 = description2
        self.review_description2 = review_description2
        self.start_date = start_date
        self.end_date = end_date
        self.schedules = schedules

    @property
    def link_text(self):
        """Gets the link_text of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">リンクテキストです。<br> ADDおよびSET時、このフィールドは必須となります。</div> <div lang=\"en\">Link text.<br> This field is required in ADD and SET operation.</div>   # noqa: E501

        :return: The link_text of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._link_text

    @link_text.setter
    def link_text(self, link_text):
        """Sets the link_text of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">リンクテキストです。<br> ADDおよびSET時、このフィールドは必須となります。</div> <div lang=\"en\">Link text.<br> This field is required in ADD and SET operation.</div>   # noqa: E501

        :param link_text: The link_text of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._link_text = link_text

    @property
    def review_link_text(self):
        """Gets the review_link_text of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">審査中のリンクテキストです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Link text on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_link_text of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._review_link_text

    @review_link_text.setter
    def review_link_text(self, review_link_text):
        """Sets the review_link_text of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">審査中のリンクテキストです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Link text on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_link_text: The review_link_text of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._review_link_text = review_link_text

    @property
    def description1(self):
        """Gets the description1 of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">説明文1です。</div> <div lang=\"en\">Description 1.</div>   # noqa: E501

        :return: The description1 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._description1

    @description1.setter
    def description1(self, description1):
        """Sets the description1 of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">説明文1です。</div> <div lang=\"en\">Description 1.</div>   # noqa: E501

        :param description1: The description1 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._description1 = description1

    @property
    def review_description1(self):
        """Gets the review_description1 of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">審査中の説明文1です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Description 1 on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_description1 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._review_description1

    @review_description1.setter
    def review_description1(self, review_description1):
        """Sets the review_description1 of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">審査中の説明文1です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Description 1 on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_description1: The review_description1 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._review_description1 = review_description1

    @property
    def description2(self):
        """Gets the description2 of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">説明文2です。</div> <div lang=\"en\">Description 2.</div>   # noqa: E501

        :return: The description2 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._description2

    @description2.setter
    def description2(self, description2):
        """Sets the description2 of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">説明文2です。</div> <div lang=\"en\">Description 2.</div>   # noqa: E501

        :param description2: The description2 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._description2 = description2

    @property
    def review_description2(self):
        """Gets the review_description2 of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">審査中の説明文2です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Description 2 on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_description2 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._review_description2

    @review_description2.setter
    def review_description2(self, review_description2):
        """Sets the review_description2 of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">審査中の説明文2です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Description 2 on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_description2: The review_description2 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._review_description2 = review_description2

    @property
    def start_date(self):
        """Gets the start_date of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">配信開始日です。<br> ※空で設定すると、既存の配信開始日は削除されます。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">Start date of ad display<br> *On setting blank, existing start date of ad display will be deleted.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :return: The start_date of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">配信開始日です。<br> ※空で設定すると、既存の配信開始日は削除されます。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">Start date of ad display<br> *On setting blank, existing start date of ad display will be deleted.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :param start_date: The start_date of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">配信終了日です。<br> ※空で設定すると、既存の配信終了日は削除されます。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">End date of ad display.<br> *By setting blank, existing end date of ad display will be deleted.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :return: The end_date of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">配信終了日です。<br> ※空で設定すると、既存の配信終了日は削除されます。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">End date of ad display.<br> *By setting blank, existing end date of ad display will be deleted.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :param end_date: The end_date of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def schedules(self):
        """Gets the schedules of this AssetServiceQuickLinkAsset.  # noqa: E501


        :return: The schedules of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: list[AssetServiceSchedule]
        """
        return self._schedules

    @schedules.setter
    def schedules(self, schedules):
        """Sets the schedules of this AssetServiceQuickLinkAsset.


        :param schedules: The schedules of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: list[AssetServiceSchedule]
        """

        self._schedules = schedules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetServiceQuickLinkAsset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssetServiceQuickLinkAsset):
            return True

        return self.to_dict() != other.to_dict()
