# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignExportServiceJob(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'end_date': 'str',
        'export_fields': 'list[str]',
        'job_id': 'int',
        'job_name': 'str',
        'job_status': 'CampaignExportServiceJobStatus',
        'progress': 'int',
        'start_date': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'end_date': 'endDate',
        'export_fields': 'exportFields',
        'job_id': 'jobId',
        'job_name': 'jobName',
        'job_status': 'jobStatus',
        'progress': 'progress',
        'start_date': 'startDate',
        'user_name': 'userName'
    }

    def __init__(self, account_id=None, end_date=None, export_fields=None, job_id=None, job_name=None, job_status=None, progress=None, start_date=None, user_name=None, local_vars_configuration=None):  # noqa: E501
        """CampaignExportServiceJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._end_date = None
        self._export_fields = None
        self._job_id = None
        self._job_name = None
        self._job_status = None
        self._progress = None
        self._start_date = None
        self._user_name = None
        self.discriminator = None

        self.account_id = account_id
        self.end_date = end_date
        self.export_fields = export_fields
        self.job_id = job_id
        self.job_name = job_name
        self.job_status = job_status
        self.progress = progress
        self.start_date = start_date
        self.user_name = user_name

    @property
    def account_id(self):
        """Gets the account_id of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this CampaignExportServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this CampaignExportServiceJob.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this CampaignExportServiceJob.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def end_date(self):
        """Gets the end_date of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブの終了日時です。</div> <div lang=\"en\">End date and time of job setting.</div>   # noqa: E501

        :return: The end_date of this CampaignExportServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブの終了日時です。</div> <div lang=\"en\">End date and time of job setting.</div>   # noqa: E501

        :param end_date: The end_date of this CampaignExportServiceJob.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def export_fields(self):
        """Gets the export_fields of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">エクスポートするフィールドです。</div> <div lang=\"en\">Fields to be exported.</div>   # noqa: E501

        :return: The export_fields of this CampaignExportServiceJob.  # noqa: E501
        :rtype: list[str]
        """
        return self._export_fields

    @export_fields.setter
    def export_fields(self, export_fields):
        """Sets the export_fields of this CampaignExportServiceJob.

        <div lang=\"ja\">エクスポートするフィールドです。</div> <div lang=\"en\">Fields to be exported.</div>   # noqa: E501

        :param export_fields: The export_fields of this CampaignExportServiceJob.  # noqa: E501
        :type: list[str]
        """

        self._export_fields = export_fields

    @property
    def job_id(self):
        """Gets the job_id of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブIDです。</div> <div lang=\"en\">CampaignExportServiceJob ID.</div>   # noqa: E501

        :return: The job_id of this CampaignExportServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブIDです。</div> <div lang=\"en\">CampaignExportServiceJob ID.</div>   # noqa: E501

        :param job_id: The job_id of this CampaignExportServiceJob.  # noqa: E501
        :type: int
        """

        self._job_id = job_id

    @property
    def job_name(self):
        """Gets the job_name of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブ名です。</div> <div lang=\"en\">CampaignExportServiceJob name.<br> ∗ Default: NULL</div>   # noqa: E501

        :return: The job_name of this CampaignExportServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブ名です。</div> <div lang=\"en\">CampaignExportServiceJob name.<br> ∗ Default: NULL</div>   # noqa: E501

        :param job_name: The job_name of this CampaignExportServiceJob.  # noqa: E501
        :type: str
        """

        self._job_name = job_name

    @property
    def job_status(self):
        """Gets the job_status of this CampaignExportServiceJob.  # noqa: E501


        :return: The job_status of this CampaignExportServiceJob.  # noqa: E501
        :rtype: CampaignExportServiceJobStatus
        """
        return self._job_status

    @job_status.setter
    def job_status(self, job_status):
        """Sets the job_status of this CampaignExportServiceJob.


        :param job_status: The job_status of this CampaignExportServiceJob.  # noqa: E501
        :type: CampaignExportServiceJobStatus
        """

        self._job_status = job_status

    @property
    def progress(self):
        """Gets the progress of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">処理進捗です。</div> <div lang=\"en\">Progress of job setting.</div>   # noqa: E501

        :return: The progress of this CampaignExportServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this CampaignExportServiceJob.

        <div lang=\"ja\">処理進捗です。</div> <div lang=\"en\">Progress of job setting.</div>   # noqa: E501

        :param progress: The progress of this CampaignExportServiceJob.  # noqa: E501
        :type: int
        """

        self._progress = progress

    @property
    def start_date(self):
        """Gets the start_date of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブの開始日時です。</div> <div lang=\"en\">Start date and time of job setting.</div>   # noqa: E501

        :return: The start_date of this CampaignExportServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブの開始日時です。</div> <div lang=\"en\">Start date and time of job setting.</div>   # noqa: E501

        :param start_date: The start_date of this CampaignExportServiceJob.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def user_name(self):
        """Gets the user_name of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブ実行者のユーザー名です。</div> <div lang=\"en\">Name of user who run the job.</div>   # noqa: E501

        :return: The user_name of this CampaignExportServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブ実行者のユーザー名です。</div> <div lang=\"en\">Name of user who run the job.</div>   # noqa: E501

        :param user_name: The user_name of this CampaignExportServiceJob.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignExportServiceJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignExportServiceJob):
            return True

        return self.to_dict() != other.to_dict()
