# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "yahoo-search-api-v11"
VERSION = "1.0.4"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    &lt;div lang&#x3D;\&quot;ja\&quot;&gt;Yahoo!広告 検索広告 APIのWebサービスについて説明します。&lt;/div&gt; &lt;div lang&#x3D;\&quot;en\&quot;&gt;Search Ads API Web Services supported in Yahoo! JAPAN Ads API.&lt;/div&gt; &lt;div&gt;&lt;a target&#x3D;\&quot;_blank\&quot; href&#x3D;\&quot;https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\&quot;&gt;OpenAPI Specification&lt;/a&gt;&lt;/div&gt; &lt;div lang&#x3D;\&quot;ja\&quot;&gt;&lt;a target&#x3D;\&quot;_blank\&quot; href&#x3D;\&quot;https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\&quot;&gt;Best Practice&lt;/a&gt;&lt;/div&gt; &lt;div lang&#x3D;\&quot;en\&quot;&gt;&lt;a target&#x3D;\&quot;_blank\&quot; href&#x3D;\&quot;https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\&quot;&gt;Best Practice&lt;/a&gt;&lt;/div&gt;   # noqa: E501
    """
)
