# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroup(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'bidding_strategy_configuration': 'AdGroupServiceBiddingStrategyConfiguration',
        'frequently_run_better_performing_ads_mode': 'AdGroupServiceFrequentlyRunBetterPerformingAdsMode',
        'ad_group_id': 'int',
        'ad_group_name': 'str',
        'ad_group_track_id': 'int',
        'campaign_id': 'int',
        'campaign_name': 'str',
        'campaign_track_id': 'int',
        'custom_parameters': 'AdGroupServiceCustomParameters',
        'labels': 'list[AdGroupServiceLabel]',
        'settings': 'AdGroupServiceSettings',
        'tracking_url': 'str',
        'is_remove_tracking_url': 'AdGroupServiceIsRemoveFlg',
        'url_review_data': 'AdGroupServiceUrlReviewData',
        'user_status': 'AdGroupServiceUserStatus',
        'created_date': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'bidding_strategy_configuration': 'biddingStrategyConfiguration',
        'frequently_run_better_performing_ads_mode': 'frequentlyRunBetterPerformingAdsMode',
        'ad_group_id': 'adGroupId',
        'ad_group_name': 'adGroupName',
        'ad_group_track_id': 'adGroupTrackId',
        'campaign_id': 'campaignId',
        'campaign_name': 'campaignName',
        'campaign_track_id': 'campaignTrackId',
        'custom_parameters': 'customParameters',
        'labels': 'labels',
        'settings': 'settings',
        'tracking_url': 'trackingUrl',
        'is_remove_tracking_url': 'isRemoveTrackingUrl',
        'url_review_data': 'urlReviewData',
        'user_status': 'userStatus',
        'created_date': 'createdDate'
    }

    def __init__(self, account_id=None, bidding_strategy_configuration=None, frequently_run_better_performing_ads_mode=None, ad_group_id=None, ad_group_name=None, ad_group_track_id=None, campaign_id=None, campaign_name=None, campaign_track_id=None, custom_parameters=None, labels=None, settings=None, tracking_url=None, is_remove_tracking_url=None, url_review_data=None, user_status=None, created_date=None, local_vars_configuration=None):  # noqa: E501
        """AdGroup - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._bidding_strategy_configuration = None
        self._frequently_run_better_performing_ads_mode = None
        self._ad_group_id = None
        self._ad_group_name = None
        self._ad_group_track_id = None
        self._campaign_id = None
        self._campaign_name = None
        self._campaign_track_id = None
        self._custom_parameters = None
        self._labels = None
        self._settings = None
        self._tracking_url = None
        self._is_remove_tracking_url = None
        self._url_review_data = None
        self._user_status = None
        self._created_date = None
        self.discriminator = None

        self.account_id = account_id
        self.bidding_strategy_configuration = bidding_strategy_configuration
        self.frequently_run_better_performing_ads_mode = frequently_run_better_performing_ads_mode
        self.ad_group_id = ad_group_id
        self.ad_group_name = ad_group_name
        self.ad_group_track_id = ad_group_track_id
        self.campaign_id = campaign_id
        self.campaign_name = campaign_name
        self.campaign_track_id = campaign_track_id
        self.custom_parameters = custom_parameters
        self.labels = labels
        self.settings = settings
        self.tracking_url = tracking_url
        self.is_remove_tracking_url = is_remove_tracking_url
        self.url_review_data = url_review_data
        self.user_status = user_status
        self.created_date = created_date

    @property
    def account_id(self):
        """Gets the account_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The account_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AdGroup.

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param account_id: The account_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def bidding_strategy_configuration(self):
        """Gets the bidding_strategy_configuration of this AdGroup.  # noqa: E501


        :return: The bidding_strategy_configuration of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceBiddingStrategyConfiguration
        """
        return self._bidding_strategy_configuration

    @bidding_strategy_configuration.setter
    def bidding_strategy_configuration(self, bidding_strategy_configuration):
        """Sets the bidding_strategy_configuration of this AdGroup.


        :param bidding_strategy_configuration: The bidding_strategy_configuration of this AdGroup.  # noqa: E501
        :type: AdGroupServiceBiddingStrategyConfiguration
        """

        self._bidding_strategy_configuration = bidding_strategy_configuration

    @property
    def frequently_run_better_performing_ads_mode(self):
        """Gets the frequently_run_better_performing_ads_mode of this AdGroup.  # noqa: E501


        :return: The frequently_run_better_performing_ads_mode of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceFrequentlyRunBetterPerformingAdsMode
        """
        return self._frequently_run_better_performing_ads_mode

    @frequently_run_better_performing_ads_mode.setter
    def frequently_run_better_performing_ads_mode(self, frequently_run_better_performing_ads_mode):
        """Sets the frequently_run_better_performing_ads_mode of this AdGroup.


        :param frequently_run_better_performing_ads_mode: The frequently_run_better_performing_ads_mode of this AdGroup.  # noqa: E501
        :type: AdGroupServiceFrequentlyRunBetterPerformingAdsMode
        """

        self._frequently_run_better_performing_ads_mode = frequently_run_better_performing_ads_mode

    @property
    def ad_group_id(self):
        """Gets the ad_group_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">広告グループIDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時は必須となります。</div> <div lang=\"en\">Ad group ID.<br> This field will be ignored in ADD operation, and will be required in SET and REMOVE operation.</div>   # noqa: E501

        :return: The ad_group_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._ad_group_id

    @ad_group_id.setter
    def ad_group_id(self, ad_group_id):
        """Sets the ad_group_id of this AdGroup.

        <div lang=\"ja\">広告グループIDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時は必須となります。</div> <div lang=\"en\">Ad group ID.<br> This field will be ignored in ADD operation, and will be required in SET and REMOVE operation.</div>   # noqa: E501

        :param ad_group_id: The ad_group_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._ad_group_id = ad_group_id

    @property
    def ad_group_name(self):
        """Gets the ad_group_name of this AdGroup.  # noqa: E501

        <div lang=\"ja\">広告グループ名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Ad group name.<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :return: The ad_group_name of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._ad_group_name

    @ad_group_name.setter
    def ad_group_name(self, ad_group_name):
        """Sets the ad_group_name of this AdGroup.

        <div lang=\"ja\">広告グループ名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Ad group name.<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :param ad_group_name: The ad_group_name of this AdGroup.  # noqa: E501
        :type: str
        """

        self._ad_group_name = ad_group_name

    @property
    def ad_group_track_id(self):
        """Gets the ad_group_track_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">トラッキング用広告グループIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Ad group ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The ad_group_track_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._ad_group_track_id

    @ad_group_track_id.setter
    def ad_group_track_id(self, ad_group_track_id):
        """Sets the ad_group_track_id of this AdGroup.

        <div lang=\"ja\">トラッキング用広告グループIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Ad group ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param ad_group_track_id: The ad_group_track_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._ad_group_track_id = ad_group_track_id

    @property
    def campaign_id(self):
        """Gets the campaign_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">キャンペーンIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Campaign ID.<br> This field is required in any cases.</div>   # noqa: E501

        :return: The campaign_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this AdGroup.

        <div lang=\"ja\">キャンペーンIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Campaign ID.<br> This field is required in any cases.</div>   # noqa: E501

        :param campaign_id: The campaign_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._campaign_id = campaign_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this AdGroup.  # noqa: E501

        <div lang=\"ja\">キャンペーン名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign name.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The campaign_name of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this AdGroup.

        <div lang=\"ja\">キャンペーン名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign name.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param campaign_name: The campaign_name of this AdGroup.  # noqa: E501
        :type: str
        """

        self._campaign_name = campaign_name

    @property
    def campaign_track_id(self):
        """Gets the campaign_track_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">トラッキング用キャンペーンIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The campaign_track_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._campaign_track_id

    @campaign_track_id.setter
    def campaign_track_id(self, campaign_track_id):
        """Sets the campaign_track_id of this AdGroup.

        <div lang=\"ja\">トラッキング用キャンペーンIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param campaign_track_id: The campaign_track_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._campaign_track_id = campaign_track_id

    @property
    def custom_parameters(self):
        """Gets the custom_parameters of this AdGroup.  # noqa: E501


        :return: The custom_parameters of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceCustomParameters
        """
        return self._custom_parameters

    @custom_parameters.setter
    def custom_parameters(self, custom_parameters):
        """Sets the custom_parameters of this AdGroup.


        :param custom_parameters: The custom_parameters of this AdGroup.  # noqa: E501
        :type: AdGroupServiceCustomParameters
        """

        self._custom_parameters = custom_parameters

    @property
    def labels(self):
        """Gets the labels of this AdGroup.  # noqa: E501


        :return: The labels of this AdGroup.  # noqa: E501
        :rtype: list[AdGroupServiceLabel]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AdGroup.


        :param labels: The labels of this AdGroup.  # noqa: E501
        :type: list[AdGroupServiceLabel]
        """

        self._labels = labels

    @property
    def settings(self):
        """Gets the settings of this AdGroup.  # noqa: E501


        :return: The settings of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceSettings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this AdGroup.


        :param settings: The settings of this AdGroup.  # noqa: E501
        :type: AdGroupServiceSettings
        """

        self._settings = settings

    @property
    def tracking_url(self):
        """Gets the tracking_url of this AdGroup.  # noqa: E501

        <div lang=\"ja\">トラッキングURLです。<br> このフィールドは、省略可能となります。<br> ※キャンペーンがアプリキャンペーンでAndroidの場合、設定はできません。<br> ※SET時、こちらが審査中の場合、編集はできません。また、変更がない場合、審査対象とはなりません。</div> <div lang=\"en\">Tracking URL.<br> This field is optional.<br> *Cannot set for a Mobile App campaign for Android OS.<br> *In SET operation, cannot update it when this field is in editorial review. In addition, if there is no change, it will not to be reviewed.</div>   # noqa: E501

        :return: The tracking_url of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._tracking_url

    @tracking_url.setter
    def tracking_url(self, tracking_url):
        """Sets the tracking_url of this AdGroup.

        <div lang=\"ja\">トラッキングURLです。<br> このフィールドは、省略可能となります。<br> ※キャンペーンがアプリキャンペーンでAndroidの場合、設定はできません。<br> ※SET時、こちらが審査中の場合、編集はできません。また、変更がない場合、審査対象とはなりません。</div> <div lang=\"en\">Tracking URL.<br> This field is optional.<br> *Cannot set for a Mobile App campaign for Android OS.<br> *In SET operation, cannot update it when this field is in editorial review. In addition, if there is no change, it will not to be reviewed.</div>   # noqa: E501

        :param tracking_url: The tracking_url of this AdGroup.  # noqa: E501
        :type: str
        """

        self._tracking_url = tracking_url

    @property
    def is_remove_tracking_url(self):
        """Gets the is_remove_tracking_url of this AdGroup.  # noqa: E501


        :return: The is_remove_tracking_url of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceIsRemoveFlg
        """
        return self._is_remove_tracking_url

    @is_remove_tracking_url.setter
    def is_remove_tracking_url(self, is_remove_tracking_url):
        """Sets the is_remove_tracking_url of this AdGroup.


        :param is_remove_tracking_url: The is_remove_tracking_url of this AdGroup.  # noqa: E501
        :type: AdGroupServiceIsRemoveFlg
        """

        self._is_remove_tracking_url = is_remove_tracking_url

    @property
    def url_review_data(self):
        """Gets the url_review_data of this AdGroup.  # noqa: E501


        :return: The url_review_data of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceUrlReviewData
        """
        return self._url_review_data

    @url_review_data.setter
    def url_review_data(self, url_review_data):
        """Sets the url_review_data of this AdGroup.


        :param url_review_data: The url_review_data of this AdGroup.  # noqa: E501
        :type: AdGroupServiceUrlReviewData
        """

        self._url_review_data = url_review_data

    @property
    def user_status(self):
        """Gets the user_status of this AdGroup.  # noqa: E501


        :return: The user_status of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceUserStatus
        """
        return self._user_status

    @user_status.setter
    def user_status(self, user_status):
        """Sets the user_status of this AdGroup.


        :param user_status: The user_status of this AdGroup.  # noqa: E501
        :type: AdGroupServiceUserStatus
        """

        self._user_status = user_status

    @property
    def created_date(self):
        """Gets the created_date of this AdGroup.  # noqa: E501

        <div lang=\"ja\">広告グループが作成された日です。<br>※フォーマット：yyyyMMdd</div> <div lang=\"en\">Date of ad group made.<br>* Format: yyyyMMdd</div>   # noqa: E501

        :return: The created_date of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this AdGroup.

        <div lang=\"ja\">広告グループが作成された日です。<br>※フォーマット：yyyyMMdd</div> <div lang=\"en\">Date of ad group made.<br>* Format: yyyyMMdd</div>   # noqa: E501

        :param created_date: The created_date of this AdGroup.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroup):
            return True

        return self.to_dict() != other.to_dict()
