# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class FeedItemServicePlaceholderField(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    LINK_TEXT = "LINK_TEXT"
    LINK_DESCRIPTION_1 = "LINK_DESCRIPTION_1"
    LINK_DESCRIPTION_2 = "LINK_DESCRIPTION_2"
    ADVANCED_URL = "ADVANCED_URL"
    ADVANCED_MOBILE_URL = "ADVANCED_MOBILE_URL"
    TRACKING_URL = "TRACKING_URL"
    CALL_PHONE_NUMBER = "CALL_PHONE_NUMBER"
    AD_CUSTOMIZER_INTEGER = "AD_CUSTOMIZER_INTEGER"
    AD_CUSTOMIZER_PRICE = "AD_CUSTOMIZER_PRICE"
    AD_CUSTOMIZER_DATE = "AD_CUSTOMIZER_DATE"
    AD_CUSTOMIZER_STRING = "AD_CUSTOMIZER_STRING"
    CALLOUT_TEXT = "CALLOUT_TEXT"
    ADDITIONAL_ADVANCED_URLS = "ADDITIONAL_ADVANCED_URLS"
    ADDITIONAL_ADVANCED_MOBILE_URLS = "ADDITIONAL_ADVANCED_MOBILE_URLS"
    STRUCTURED_SNIPPET_HEADER = "STRUCTURED_SNIPPET_HEADER"
    STRUCTURED_SNIPPET_VALUES = "STRUCTURED_SNIPPET_VALUES"
    UNKNOWN = "UNKNOWN"

    allowable_values = [LINK_TEXT, LINK_DESCRIPTION_1, LINK_DESCRIPTION_2, ADVANCED_URL, ADVANCED_MOBILE_URL, TRACKING_URL, CALL_PHONE_NUMBER, AD_CUSTOMIZER_INTEGER, AD_CUSTOMIZER_PRICE, AD_CUSTOMIZER_DATE, AD_CUSTOMIZER_STRING, CALLOUT_TEXT, ADDITIONAL_ADVANCED_URLS, ADDITIONAL_ADVANCED_MOBILE_URLS, STRUCTURED_SNIPPET_HEADER, STRUCTURED_SNIPPET_VALUES, UNKNOWN]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """FeedItemServicePlaceholderField - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedItemServicePlaceholderField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeedItemServicePlaceholderField):
            return True

        return self.to_dict() != other.to_dict()
