# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupAdServiceDescriptionTextAsset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'text': 'str',
        'pinned_field': 'AdGroupAdServiceDescriptionPinnedField',
        'active_status': 'AdGroupAdServiceTextAssetActiveStatus',
        'approval_status': 'AdGroupAdServiceApprovalStatus',
        'disapproval_reason_codes': 'list[str]'
    }

    attribute_map = {
        'text': 'text',
        'pinned_field': 'pinnedField',
        'active_status': 'activeStatus',
        'approval_status': 'approvalStatus',
        'disapproval_reason_codes': 'disapprovalReasonCodes'
    }

    def __init__(self, text=None, pinned_field=None, active_status=None, approval_status=None, disapproval_reason_codes=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceDescriptionTextAsset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._text = None
        self._pinned_field = None
        self._active_status = None
        self._approval_status = None
        self._disapproval_reason_codes = None
        self.discriminator = None

        self.text = text
        self.pinned_field = pinned_field
        self.active_status = active_status
        self.approval_status = approval_status
        self.disapproval_reason_codes = disapproval_reason_codes

    @property
    def text(self):
        """Gets the text of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501

        <div lang=\"ja\">テキストです。<br>ADDおよびSET時、このフィールドは必須となります。</div> <div lang=\"en\">Text of parameter.<br>This field is required in ADD and SET operation.</div>   # noqa: E501

        :return: The text of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this AdGroupAdServiceDescriptionTextAsset.

        <div lang=\"ja\">テキストです。<br>ADDおよびSET時、このフィールドは必須となります。</div> <div lang=\"en\">Text of parameter.<br>This field is required in ADD and SET operation.</div>   # noqa: E501

        :param text: The text of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def pinned_field(self):
        """Gets the pinned_field of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501


        :return: The pinned_field of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: AdGroupAdServiceDescriptionPinnedField
        """
        return self._pinned_field

    @pinned_field.setter
    def pinned_field(self, pinned_field):
        """Sets the pinned_field of this AdGroupAdServiceDescriptionTextAsset.


        :param pinned_field: The pinned_field of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: AdGroupAdServiceDescriptionPinnedField
        """

        self._pinned_field = pinned_field

    @property
    def active_status(self):
        """Gets the active_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501


        :return: The active_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: AdGroupAdServiceTextAssetActiveStatus
        """
        return self._active_status

    @active_status.setter
    def active_status(self, active_status):
        """Sets the active_status of this AdGroupAdServiceDescriptionTextAsset.


        :param active_status: The active_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: AdGroupAdServiceTextAssetActiveStatus
        """

        self._active_status = active_status

    @property
    def approval_status(self):
        """Gets the approval_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501


        :return: The approval_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: AdGroupAdServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this AdGroupAdServiceDescriptionTextAsset.


        :param approval_status: The approval_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: AdGroupAdServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501

        <div lang=\"ja\">審査否認の理由コードです。<br> (コード詳細は、DictionaryServiceのgetDisapprovalReasonのレスポンスを参照)<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Code of Disapproval reason.<br> (Refer to DictionaryService getDisapprovalReason response for details) <br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The disapproval_reason_codes of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this AdGroupAdServiceDescriptionTextAsset.

        <div lang=\"ja\">審査否認の理由コードです。<br> (コード詳細は、DictionaryServiceのgetDisapprovalReasonのレスポンスを参照)<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Code of Disapproval reason.<br> (Refer to DictionaryService getDisapprovalReason response for details) <br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceDescriptionTextAsset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceDescriptionTextAsset):
            return True

        return self.to_dict() != other.to_dict()
